@@ -382,12 +382,21 @@ void TMainForm::FormCreate(GtkWidget *Sender) {
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (RemoveBtn);
 
+  /*
   appbar1 = gtk_statusbar_new ();
   gtk_widget_ref (appbar1);
   gtk_object_set_data_full (GTK_OBJECT (main_window), "appbar1", appbar1,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (appbar1);
   gtk_box_pack_start (GTK_BOX (vbox1), appbar1, FALSE, FALSE, 0);
+  */
+
+  appbar1 = gtk_progress_bar_new ();
+  gtk_widget_ref (appbar1);
+  gtk_object_set_data_full (GTK_OBJECT (main_window), "appbar1", appbar1,
+                            (GtkDestroyNotify) gtk_widget_unref);
+  gtk_widget_show (appbar1);
+  gtk_box_pack_start (GTK_BOX (vbox1), appbar1, FALSE, FALSE, 0);
 
 
   gtk_signal_connect (GTK_OBJECT (localTree->nativeControl), "button_press_event",
@@ -605,6 +614,11 @@ void TMainForm::fillInstallTree()
 		nodeName += mods->second->Description();
 		node = installTree->Items->AddChildObject(node, nodeName.c_str(), mods->second->Name());
 	}
+	for (node = installTree->Items->GetFirstNode(); node; node = node->getNextSibling())
+		node->Expand(true);
+	node = installTree->Items->GetFirstNode();
+//	if (node)
+//		node->MakeVisible();
 }
 
 
@@ -655,6 +669,11 @@ void TMainForm::fillSourceTree(const char *sourceConf, TTreeView *tree)
 		else {
 			secName = "Other";
 		}
+
+		string misc1 = ((entry = sections->second.find("Category")) != sections->second.end()) ? (*entry).second : (string)"";
+          if (misc1.length() > 0)
+             secName = misc1;
+
 		entry = sections->second.find("Description");
 		if (entry != sections->second.end())
 			modDesc = entry->second.c_str();
@@ -680,7 +699,6 @@ void TMainForm::fillSourceTree(const char *sourceConf, TTreeView *tree)
 				targetVersion = entry->second;
 		}
 
-
 		if (VersionInfo(sourceVersion.c_str()) > VersionInfo(targetVersion.c_str())) {
 			for (node = tree->Items->GetFirstNode(); node; node = node->getNextSibling()) {
 				if (!strcmp(string(node->Text).c_str(), secName.c_str())) {
@@ -715,6 +733,11 @@ void TMainForm::fillSourceTree(const char *sourceConf, TTreeView *tree)
 			node->StateIndex = 0;
 		}
 	}
+	for (node = tree->Items->GetFirstNode(); node; node = node->getNextSibling())
+		node->Expand(true);
+	node = tree->Items->GetFirstNode();
+//	if (node)
+//		node->MakeVisible();
 }
 
 
@@ -1167,6 +1190,8 @@ void TMainForm::Button2Click(GtkWidget *Sender)	// INSTALL
 	TTreeNode *node;
 	int count = 0;
 	int abort = 0;
+	//gtk temporary
+	float position = 0;
 
 /*
 	class TWaitCursor {
@@ -1198,6 +1223,8 @@ void TMainForm::Button2Click(GtkWidget *Sender)	// INSTALL
 		
 //	progressBar->Max = count;
 //	progressBar->Position = 0;
+     gtk_progress_bar_update(GTK_PROGRESS_BAR(appbar1), 0);
+     gtk_progress_set_show_text(GTK_PROGRESS(appbar1), 1);
 
 	for (node = tree->Items->GetFirstNode(); node; node = node->GetNext()) {
 		if (node->StateIndex == 1) {	// if selected for install
@@ -1207,6 +1234,9 @@ void TMainForm::Button2Click(GtkWidget *Sender)	// INSTALL
 			}
 				// install module
 //			statusBar->Caption = "Installing: " + node->Text + "...";
+			string statusText = "Installing: " + string(node->Text) + "...";
+			gtk_progress_set_format_string(GTK_PROGRESS(appbar1), statusText.c_str());
+			
 //			statusBar->Repaint();
 			if (tree == localTree)
 				abort = installModule((const char *)(void *)node->Data);
@@ -1214,6 +1244,9 @@ void TMainForm::Button2Click(GtkWidget *Sender)	// INSTALL
 			if (abort)
 				break;
 //			progressBar->Position++;
+			position++;
+			gtk_progress_bar_update(GTK_PROGRESS_BAR(appbar1), position/count);
+			while (g_main_iteration(FALSE));	// force refresh
 		}
 	}
 	delete manager;
@@ -1222,6 +1255,8 @@ void TMainForm::Button2Click(GtkWidget *Sender)	// INSTALL
 	fillAllSourceTrees();
 //	statusBar->Caption = "";
 //	progressBar->Position = 0;
+	gtk_progress_set_format_string(GTK_PROGRESS(appbar1), "");
+	gtk_progress_bar_update(GTK_PROGRESS_BAR(appbar1), 0);
 }
 
 
