@@ -293,6 +293,98 @@ TTreeNode *TTreeNode::GetNext() {
 }
 
 
+/*
+procedure TTreeNode.ExpandItem(Expand: Boolean; Recurse: Boolean);
+var
+  Flag: Integer;
+  Node: TTreeNode;
+begin
+  if Recurse then
+  begin
+    Node := Self;
+    repeat
+      Node.ExpandItem(Expand, False);
+      Node := Node.GetNext;
+    until (Node = nil) or (not Node.HasAsParent(Self));
+  end
+  else begin
+    TreeView.FManualNotify := True;
+    try
+      Flag := 0;
+      if Expand then
+      begin
+        if DoCanExpand(True) then
+        begin
+          Flag := TVE_EXPAND;
+          DoExpand(True);
+        end;
+      end
+      else begin
+        if DoCanExpand(False) then
+        begin
+          Flag := TVE_COLLAPSE;
+          DoExpand(False);
+        end;
+      end;
+      if Flag <> 0 then TreeView_Expand(Handle, ItemId, Flag);
+    finally
+      TreeView.FManualNotify := False;
+    end;
+  end;
+end;
+*/
+
+void TTreeNode::ExpandItem(bool Expand, bool Recurse) {
+	TTreeNode *Node;
+
+	if (Recurse) {
+		Node = this;
+		do {
+			Node->ExpandItem(Expand, false);
+			Node = Node->GetNext();
+		}
+		while ((Node) /*and (Node.HasAsParent(Self)*/);
+	}
+	else {
+		gtk_tree_item_expand(nativeControl);
+
+/*
+		TreeView.FManualNotify := True;
+    try
+      Flag := 0;
+      if Expand then
+      begin
+        if DoCanExpand(True) then
+        begin
+          Flag := TVE_EXPAND;
+          DoExpand(True);
+        end;
+      end
+      else begin
+        if DoCanExpand(False) then
+        begin
+          Flag := TVE_COLLAPSE;
+          DoExpand(False);
+        end;
+      end;
+      if Flag <> 0 then TreeView_Expand(Handle, ItemId, Flag);
+    finally
+      TreeView.FManualNotify := False;
+    end;
+*/
+	}
+}
+
+/*
+procedure TTreeNode.Expand(Recurse: Boolean);
+begin
+  ExpandItem(True, Recurse);
+end;
+*/
+
+void TTreeNode::Expand(bool Recurse) {
+	ExpandItem(true, Recurse);
+}
 
 /*
 
@@ -453,50 +545,6 @@ begin
   end;
 end;
 
-procedure TTreeNode.ExpandItem(Expand: Boolean; Recurse: Boolean);
-var
-  Flag: Integer;
-  Node: TTreeNode;
-begin
-  if Recurse then
-  begin
-    Node := Self;
-    repeat
-      Node.ExpandItem(Expand, False);
-      Node := Node.GetNext;
-    until (Node = nil) or (not Node.HasAsParent(Self));
-  end
-  else begin
-    TreeView.FManualNotify := True;
-    try
-      Flag := 0;
-      if Expand then
-      begin
-        if DoCanExpand(True) then
-        begin
-          Flag := TVE_EXPAND;
-          DoExpand(True);
-        end;
-      end
-      else begin
-        if DoCanExpand(False) then
-        begin
-          Flag := TVE_COLLAPSE;
-          DoExpand(False);
-        end;
-      end;
-      if Flag <> 0 then TreeView_Expand(Handle, ItemId, Flag);
-    finally
-      TreeView.FManualNotify := False;
-    end;
-  end;
-end;
-
-procedure TTreeNode.Expand(Recurse: Boolean);
-begin
-  ExpandItem(True, Recurse);
-end;
-
 procedure TTreeNode.Collapse(Recurse: Boolean);
 begin
   ExpandItem(False, Recurse);
