@@ -25,8 +25,16 @@
 #include <swmgr.h>
 #include <versekey.h>
 #include <regex.h>
+#include <gbfplain.h>
+#include <thmlplain.h>
+#include <string.h>
+
 
 MainWindow *cheatahWindow = NULL;
+
+/*	I'm going to try commenting out get_widget() - it no longer seems to be used	*/
+/*	Note: this doesn't seem to have caused any problems so far.			*/
+/*
 GtkWidget*
 get_widget                             (GtkWidget       *widget,
                                         gchar           *widget_name)
@@ -40,7 +48,8 @@ get_widget                             (GtkWidget       *widget,
   if (!found_widget)
     g_warning ("Widget not found: %s", widget_name);
   return found_widget;
-}
+}		
+*/
 
 /* This is an internally used function to set notebook tab widgets. */
 void
@@ -88,6 +97,17 @@ GtkWidget* create_mainWindow () {
 	return retWidget;
 }
 
+/*								*/
+/*	Note: this seems to be a poor choice of a name for this function .	*/
+/*	When  I accidentally left off the  parenthesis when trying to call it,	*/
+/*	the compiler didn't complain, but it didn't execute, either.		*/
+/* 	Could there be a macro or something by the same name?		*/
+/*	At any rate, be careful with it.				*/
+/*								*/
+void destroy_mainWindow () {
+	delete cheatahWindow;
+}
+
 GtkWidget *MainWindow::create() {
 	mainWindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_object_set_data (GTK_OBJECT (mainWindow), "mainWindow", mainWindow);
@@ -120,19 +140,19 @@ GtkWidget *MainWindow::create() {
   gtk_widget_show (menubar4);
   gtk_container_add (GTK_CONTAINER (handlebox3), menubar4);
 
-  File3 = gtk_menu_item_new_with_label ("File");
-  gtk_object_set_data (GTK_OBJECT (mainWindow), "File3", File3);
-  gtk_widget_show (File3);
-  gtk_container_add (GTK_CONTAINER (menubar4), File3);
+  File = gtk_menu_item_new_with_label ("File");
+  gtk_object_set_data (GTK_OBJECT (mainWindow), "File", File);
+  gtk_widget_show (File);
+  gtk_container_add (GTK_CONTAINER (menubar4), File);
 
-  menu13 = gtk_menu_new ();
-  gtk_object_set_data (GTK_OBJECT (mainWindow), "menu13", menu13);
-  gtk_menu_item_set_submenu (GTK_MENU_ITEM (File3), menu13);
+  menuFile = gtk_menu_new ();
+  gtk_object_set_data (GTK_OBJECT (mainWindow), "menuFile", menuFile);
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (File), menuFile);
 
   Exit3 = gtk_menu_item_new_with_label ("Exit");
   gtk_object_set_data (GTK_OBJECT (mainWindow), "Exit3", Exit3);
   gtk_widget_show (Exit3);
-  gtk_container_add (GTK_CONTAINER (menu13), Exit3);
+  gtk_container_add (GTK_CONTAINER (menuFile), Exit3);
   gtk_signal_connect (GTK_OBJECT (Exit3), "activate",
                       GTK_SIGNAL_FUNC (gtk_main_quit),
                       NULL);
@@ -177,14 +197,14 @@ GtkWidget *MainWindow::create() {
                       NULL);
   gtk_menu_item_right_justify (GTK_MENU_ITEM (Help));
 
-  menu14 = gtk_menu_new ();
-  gtk_object_set_data (GTK_OBJECT (mainWindow), "menu14", menu14);
-  gtk_menu_item_set_submenu (GTK_MENU_ITEM (Help), menu14);
+  menuHelp = gtk_menu_new ();
+  gtk_object_set_data (GTK_OBJECT (mainWindow), "menuHelp", menuHelp);
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (Help), menuHelp);
 
   About = gtk_menu_item_new_with_label ("About");
   gtk_object_set_data (GTK_OBJECT (mainWindow), "About", About);
   gtk_widget_show (About);
-  gtk_container_add (GTK_CONTAINER (menu14), About);
+  gtk_container_add (GTK_CONTAINER (menuHelp), About);
   gtk_signal_connect (GTK_OBJECT (About), "activate",
                       GTK_SIGNAL_FUNC (on_About_activate),
                       NULL);
@@ -383,6 +403,50 @@ void MainWindow::initSWORD() {
 	char *font;
 	SWModule *curMod;
 
+/*	First, check and see whether SWMgr found any installed books.  If not, tell the user what the problem is.	*/
+/*	Print a short notice to stderr, for use when the program is invoked from the command line,		*/
+/*	and also put  a bit longer message into the spot where bible text would otherwise show up. 		*/
+/*	Then, return out of this function, because there's nothing left to do.					*/
+
+	if (mainMgr->Modules.empty()==TRUE) {
+		fprintf(stderr,"SWMgr: Can't find 'mods.conf' or 'mods.d'.  Try setting:\n\tSWORD_PATH=<directory containing mods.conf>\n\tOr see the README file for a full description of setup options.\n\t");
+
+		gtk_text_set_point(GTK_TEXT(moduleText), 0);
+		gtk_text_forward_delete (GTK_TEXT (moduleText), gtk_text_get_length((GTK_TEXT(moduleText))));
+		int curPos = 0;
+		gtk_text_freeze (GTK_TEXT(moduleText));
+		gtk_text_insert(GTK_TEXT(moduleText), NULL, &moduleText->style->black, NULL, "\nCheatah was unable to find any books installed!\n\n", -1);
+		gtk_text_insert(GTK_TEXT(moduleText), NULL, &moduleText->style->black, NULL, "They should be listed in a configuration file named either: ", -1);
+		gtk_text_insert(GTK_TEXT(moduleText), NULL, &moduleText->style->black, NULL, "'mods.conf' or 'mods.d'. \n\n", -1);
+		gtk_text_insert(GTK_TEXT(moduleText), NULL, &moduleText->style->black, NULL, "Try setting:\n\tSWORD_PATH=<directory containing mods.conf>\n\t",-1);
+		gtk_text_insert(GTK_TEXT(moduleText), NULL, &moduleText->style->black, NULL, "Or see the README file for a full description of setup options.\n", -1);
+		gtk_text_set_point(GTK_TEXT(moduleText), curPos);
+		gtk_text_thaw(GTK_TEXT(moduleText));
+						
+		return;
+	}
+
+/*
+* Create filters to use, depending on the needs of the installed modules.
+* Right now, basically just handling GBF files and converting them to plain
+* text for display.  So far, I haven't found any modules that specify
+* anything other than GBF, but I've dropped in code to 
+* install the thtml to plain filter just in case, since it's available.
+* Question: I'm installing this as a display filter - would it make more
+* sense to install it is a raw filter, so that I could use "plain" as the
+* base for any strip filters we may need?  Or is that used for something else,
+* like compression or decyphering locked books?
+*/
+
+	gbftoplain = new GBFPlain();
+	thmlplain = new ThMLPlain();
+
+/*
+*	Next, if SWMgr did find  some book modules installed , hook them up to any filters needed
+*	and set up the menues to reflect them.
+*	Pick a default module to show on startup.
+*/
+		
 	for (it = mainMgr->Modules.begin(); it != mainMgr->Modules.end(); it++) {
 		curMod = (*it).second;
 		menuChoice = gtk_menu_item_new_with_label (curMod->Name());
@@ -393,10 +457,21 @@ void MainWindow::initSWORD() {
 			      GTK_SIGNAL_FUNC (on_viewMod_activate),
 			      g_strdup(curMod->Name()));
 
+		if ((sit = mainMgr->config->Sections.find(curMod->Name())) != mainMgr->config->Sections.end()) {
+			if ((eit = (*sit).second.find("SourceType")) != (*sit).second.end()) {
+				if (!strcasecmp((*eit).second.c_str(), "GBF")) {
+					curMod->AddRenderFilter(gbftoplain);
+				}
+				else if (!strcasecmp((*eit).second.c_str(), "ThML")) {
+					curMod->AddRenderFilter(thmlplain);
+				}
+			}
+		}
+
 		if (!strcmp((*it).second->Type(), "Biblical Texts")) {
 			gtk_container_add (GTK_CONTAINER (menuView), menuChoice);
 			font = 0;
-			if ((sit = mainMgr->config->Sections.find((*it).second->Name())) != mainMgr->config->Sections.end()) {
+			if ((sit = mainMgr->config->Sections.find(curMod->Name())) != mainMgr->config->Sections.end()) {
 				if ((eit = (*sit).second.find("Font")) != (*sit).second.end()) {
 					font = (char *)(*eit).second.c_str();
 				}
@@ -408,11 +483,11 @@ void MainWindow::initSWORD() {
 		}
 		else	{
 			curMod->Disp(entryDisplay);	// set our GTKEntryDisp object up for the diplayer of each module other than Biblical Texts
-			if (!strcmp((*it).second->Type(), "Commentaries")) {
+			if (!strcmp(curMod->Type(), "Commentaries")) {
 				gtk_container_add (GTK_CONTAINER (menuCommentaries), menuChoice);
 	//			CreateCommentPane((*it).second);
 			}
-			if (!strcmp((*it).second->Type(), "Lexicons / Dictionaries")) {
+			if (!strcmp(curMod->Type(), "Lexicons / Dictionaries")) {
 				gtk_container_add (GTK_CONTAINER (menuDictionaries), menuChoice);
 	//			CreateLDPane((*it).second);
 			}
@@ -422,8 +497,12 @@ void MainWindow::initSWORD() {
 	}
 	gtk_container_add (GTK_CONTAINER (menuView), commentaries);
 	gtk_container_add (GTK_CONTAINER (menuView), dictionaries);
-	if (!this->curMod) 	// set currently selected module for app to first module from SWMgr
-		this->curMod = curMod;
+
+	if (!this->curMod)			// We didn't find a bible text, so set currently selected module for app to first module from SWMgr
+		this->curMod = curMod;	// Should be o.k. to do this, because we've already tested to see if SWMgr thinks it found something
+	assert(this->curMod!=NULL);
+	if(this->curMod!=NULL)		// Go ahead and display default module
+		lookupTextChanged();
 }
 
 
@@ -506,6 +585,13 @@ void MainWindow::resultListSelectionChanged(GtkWidget *clist, gint row, gint col
 GdkColor GTKEntryDisp::colourBlue;
 GdkColor GTKEntryDisp::colourGreen;
 
+/*										*/
+/*	Note: we have a warning that should be fixed here.  GTKEntryDisp::Display() is defined	*/
+/*	as returning char, but doesn't have a return statement				*/
+/*	What was intended - a return code?  That doesn't seem right, because those are	*/
+/*	usually int's.  But it isn't defined as returning a char*, so it doesn't seem		*/
+/*	likely that it's intended to return the text involved.					*/
+/*										*/
 char GTKEntryDisp::Display(SWModule &imodule) {
 	char tmpBuf[255];
 
@@ -521,6 +607,13 @@ char GTKEntryDisp::Display(SWModule &imodule) {
 	gtk_text_thaw(GTK_TEXT(gtkText));
 }
 
+/*											*/
+/*	Note: we have a warning that should be fixed here.  GTKChapDisp::Display() is defined		*/
+/*	as returning char, but doesn't have a return statement.					*/
+/*	What was intended - a return code?  That doesn't seem right, because those are		*/
+/*	usually int's.  But it isn't defined as returning a char*, so it doesn't seem			*/
+/*	likely that it's intended to return the text involved.						*/
+/*											*/
 
 char GTKChapDisp::Display(SWModule &imodule) {
 	char tmpBuf[255];
