@@ -1,25 +1,45 @@
 #!/usr/bin/perl
 
-#version 4.0
-
-$diatheke = "nice /usr/bin/diatheke";  # location of diatheke command line program -- if you are using a MS Windows server, you might need to remove the "nice"
-$defaultfontface = "Arial, Helvetica, sans-serif"; # default font name
+# Typical Linux/Unix settings
+$err = "2> /dev/null";
 $sword_path = "/home/sword";  # SWORD_PATH environment variable you want to use
+$diatheke = "nice /usr/bin/diatheke";  # location of diatheke command line program
+
+# Typical Windows settings
+#$err = "";
+#$sword_path = "C:\\Program Files\\CrossWire\\The SWORD Project";  # SWORD_PATH environment variable you want to use
+#$diatheke = "$sword_path\\diatheke.exe";  # location of diatheke command line program
+
+$cgiurl = "http:\/\/bible.gotjesus.org\/cgi-bin";
+
+$scriptname = "diatheke.pl";
+$defaultfontface = "Times New Roman, Times, Roman, serif"; # default font name
 $maxverses = 50; # maximum number of verses diatheke will return per query (prevents people from asking for Gen1:1-Rev22:21)
 $defaultbook = "KJV"; # book to query when none is selected, but a verse/search is entered
-$deflocale = en;  # this is just the default for cases where user has not selected a locale and his browser does not reveal one -- you can also set locale using locael=<locale> in the GET URL
-
-sub plussifyaddress  {
-    ($ver = @_[0]) =~ tr/ /+/; 
-    $newline = "<a href=\"diatheke.pl?verse=$ver&@_[1]=on\">";
-    return $newline;
-}
+$deflocale = "abbr";  # this is just the default for cases where user has not selected a locale and his browser does not reveal one -- you can also set locale using locale=<locale> in the GET URL
 
 ###############################################################################
 ## You should not need to edit anything below this line.
 ## Unless you want to modify functionality of course. :)
 ###############################################################################
 
+$version = "4.2";
+
+sub plussifyaddress  {
+    ($p_ver = @_[0]) =~ tr/ /+/; 
+    $p_newline = "<a href=\"$scriptname?verse=$p_ver&@_[1]=on\">";
+    return $p_newline;
+}
+
+sub urlvers {
+    $u_verse = @_[0];
+    $u_version = @_[1];
+    $u_oldverse = $u_verse;
+    $u_verse =~ tr/ /+/;
+    $u_newline = "<a href=\"$scriptname?verse=$u_verse&$u_version=on\">$u_oldverse</a>";
+    return $u_newline;
+}
+
 $ENV{'SWORD_PATH'} = $sword_path;
 
 print "Content-type: text/html\n\n";
@@ -40,21 +60,22 @@ if ($defversion eq "") {
 }
 if ($locale eq "") {
     $locale = $ENV{'HTTP_ACCEPT_LANGUAGE'};
+    $locale =~ s/(..).*/$1/;
     if ($locale eq "") {
 	$locale = $deflocale;
     }
+    elsif ($locale eq "en") {
+	$locale = "abbr";
+    }
 }
 
-$locale =~ s/(..).*/$1/;
-
 $hostname = $ENV{'REMOTE_ADDR'};
 @values = split(/\&/,$ENV{'QUERY_STRING'});
 $n = 0;
 $palm = 0;
-$footnotes = 0;
-$strongs = 0;
-$headings = 0;
-$morph = 0;
+
+$latinxlit = "";
+
 $optionfilters = "";
 $debug=0;
 foreach $i (@values) {
@@ -68,22 +89,45 @@ foreach $i (@values) {
 	elsif ($varname eq "search" && $mydata ne "" && $mydata ne "off") {
 	    $search = "-s $mydata";
 	}
+
 	elsif ($varname eq "strongs") {
 	    $optionfilters .= "n";
-	    $strongs = 1;
 	}
 	elsif ($varname eq "footnotes") {
 	    $optionfilters .= "f";
-	    $footnotes = 1;
 	}
 	elsif ($varname eq "headings") {
 	    $optionfilters .= "h";
-	    $headings = 1;
 	}
 	elsif ($varname eq "morph") {
 	    $optionfilters .= "m";
-	    $morph = 1;
 	}	
+	elsif ($varname eq "hebcant") {
+	    $optionfilters .= "c";
+	}
+	elsif ($varname eq "hebvowels") {
+	    $optionfilters .= "v";
+	}
+	elsif ($varname eq "grkacc") {
+	    $optionfilters .= "a";
+	}
+	elsif ($varname eq "lemmas") {
+	    $optionfilters .= "l";
+	}	
+	elsif ($varname eq "scriprefs") {
+	    $optionfilters .= "s";
+	}
+	elsif ($varname eq "arshape") {
+	    $optionfilters .= "r";
+	}
+	elsif ($varname eq "bidi") {
+	    $optionfilters .= "b";
+	}
+
+	elsif ($varname eq "latinxlit") {
+	    $latinxlit = "-t Latin";
+	}	
+
 	elsif ($varname eq "palm") {
 	    $palm = 1;
 	}
@@ -93,6 +137,9 @@ foreach $i (@values) {
 	elsif ($varname eq "locale") {
 	    $locale = $mydata;
 	}
+	elsif ($varname eq "maxverses") {
+	    $maxverses = $mydata;
+	}
 	elsif ($mydata eq "on" || $mydata eq "ON") {
 	    $versions[$n] = $varname;
 	    $n++;
@@ -112,35 +159,71 @@ if ($n == 0) {
 
 if ($verse eq "") {
 
-    @versionlist = `$diatheke -b system -k modulelist 2> /dev/null`;    
+    @versionlist = `$diatheke -b system -k modulelist $err`;    
     @versionlist2 = @versionlist;
-    @localelist = `$diatheke -b system -k localelist 2> /dev/null`;
+    @localelist = `$diatheke -b system -k localelist $err`;
 
     print <<DEF1;
 <html>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
-<title>Diatheke Insta-Interlinear Bible</title>
+<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
+<title>Diatheke Online Bible</title>
 </head>
 
 <body>
 
-<form method="get" action="diatheke.pl">
+<form method="get" action="$scriptname">
   <p /><input type="radio" name="search" checked value="" /><font face="Arial, Helvetica, sans-serif">Verse/Commentary Lookup&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
   Verse or Search key:</font><input type="text" name="verse" size="20"><input type="submit" name="Submit" value="Submit"><input type="reset" name="Reset" value="Reset"><br />
   <input type="radio" name="search" value="phrase" /><font face="Arial, Helvetica, sans-serif">Phrase Search</font><br />
   <input type="radio" name="search" value="multiword" /><font face="Arial, Helvetica, sans-serif">Multiple Word Search</font><br />
   <input type="radio" name="search" value="regex" /><font face="Arial, Helvetica, sans-serif">Regular Expression Search</font><br />
-
-  <p /><input type="checkbox" name="strongs" value="on"><font size="-1" face="Arial, Helvetica, sans-serif">Show
-  Stong's Numbers when available (Strong's numbered modules are marked by *)</font>
-  <p /><input type="checkbox" name="footnotes" value="on"><font size="-1" face="Arial, Helvetica, sans-serif">Show
-  Footnotes when available</font>
-  <p /><input type="checkbox" name="morph" value="on"><font size="-1" face="Arial, Helvetica, sans-serif">Show
-  Morphological tags when available</font>
-  <p /><input type="checkbox" name="headings" value="on"><font size="-1" face="Arial, Helvetica, sans-serif">Show
-  Section Headings when available</font><br />
-  &nbsp;
+  <table width="100%" border="0">
+    <tr> 
+      <td width="50%"> 
+        <input type="checkbox" name="strongs" value="on" checked>
+        <font size="-1" face="Arial, Helvetica, sans-serif">Show Strong's Numbers</font></td>
+      <td width="50%"> 
+        <input type="checkbox" name="headings" value="on" checked>
+        <font size="-1" face="Arial, Helvetica, sans-serif">Show Section Headings</font></td>
+    </tr>
+    <tr> 
+      <td width="50%"> 
+        <input type="checkbox" name="footnotes" value="on" checked>
+        <font size="-1" face="Arial, Helvetica, sans-serif">Show Footnotes</font></td>
+      <td width="50%"> 
+        <input type="checkbox" name="scriprefs" value="on" checked>
+        <font size="-1" face="Arial, Helvetica, sans-serif">Show Scripture Cross-References</font></td>
+    </tr>
+    <tr> 
+      <td width="50%"> 
+        <input type="checkbox" name="morph" value="on" checked>
+        <font size="-1" face="Arial, Helvetica, sans-serif">Show Morphology</font></td>
+      <td width="50%"> 
+        <input type="checkbox" name="hebvowels" value="on" checked>
+        <font size="-1" face="Arial, Helvetica, sans-serif">Show Hebrew Vowels</font></td>
+    </tr>
+    <tr> 
+      <td width="50%"> 
+        <input type="checkbox" name="lemmas" value="on" checked>
+        <font size="-1" face="Arial, Helvetica, sans-serif">Show Lemmas</font></td>
+      <td width="50%"> 
+        <input type="checkbox" name="hebcant" value="on">
+        <font size="-1" face="Arial, Helvetica, sans-serif">Show Hebrew Cantillation 
+        Marks </font></td>
+    </tr>
+    <tr> 
+      <td width="50%"> 
+        <input type="checkbox" name="latinxlit" value="on">
+        <font face="Arial, Helvetica, sans-serif" size="-1">Latin Transliterate</font> 
+      </td>
+      <td width="50%"> 
+        <input type="checkbox" name="grkacc" value="on" checked>
+        <font size="-1" face="Arial, Helvetica, sans-serif">Show Greek Accents</font> 
+      </td>
+    </tr>
+  </table>
+  <br />
   <table BORDER="0" WIDTH="100%">
 DEF1
     
@@ -215,12 +298,12 @@ print <<END;
 
 <html><head>
 <title>Diatheke Interlinear Bible</title>
-<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
 <meta name="palmcomputingplatform" content="true">
 <meta name="historylisttext" content="Diatheke">
 <style type="text/css">
 #divBottom{position:absolute; visibility:hidden; font-family:arial,helvetica; height:30; width:100; font-size:10pt; font-weight:bold}
-#A:link, A:visited, A:active{text-decoration: none}
+A:link, A:visited, A:active{text-decoration: none}
 </style>
 <script type="text/javascript" language="JavaScript">
 /********************************************************************************
@@ -233,7 +316,7 @@ I will also appriciate any links you could give me.
 function checkBrowser(){
     this.ver=navigator.appVersion;
     this.dom=document.getElementById?1:0;
-    this.ie5=(this.ver.indexOf("MSIE 5")>-1 && this.dom)?1:0;
+    this.ie5=( (this.ver.indexOf("MSIE 6")>-1 || this.ver.indexOf("MSIE 5")>-1) && this.dom)?1:0;
     this.ie4=(document.all && !this.dom)?1:0;
     this.ns5=(this.dom && parseInt(this.ver) >= 5) ?1:0;
     this.ns4=(document.layers && !this.dom)?1:0;
@@ -301,7 +384,7 @@ function resized(){
 if(bw.bw && !bw.ns5) onload=geoInit;
 
 //Here we will write the div out so that lower browser won't see it.'
-if(bw.bw && !bw.ns5) document.write('<div id="divBottom"><center>Powered by<br /><img src="http://www.crosswire.org/sword/pbsword.gif"><br /><a href="http://www.crosswire.org/">www.crosswire.org</a></center></div>')
+if(bw.bw && !bw.ns5) document.write('<div id="divBottom"><table><tr><td align="center">Powered by<br /><img src="http://www.crosswire.org/sword/pbsword.gif"><br /><a href="http://www.crosswire.org/">www.crosswire.org</td></tr></table></div>')
 </script>
 
 </head>
@@ -309,13 +392,13 @@ if(bw.bw && !bw.ns5) document.write('<div id="divBottom"><center>Powered by<br /
 <body bgcolor="#FFFFFF"><font face="$defaultfontface">
 
 END
-							      }
+}
 else {
 print <<END
 
 <html><head>
 <title>HANDiatheke</title>
-<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
 <meta name="palmcomputingplatform" content="true">
 <meta name="historylisttext" content="HANDiatheke">
 </head>
@@ -324,40 +407,33 @@ END
 }
 for ($i = 0; $i < $n; $i++) {
     
+    $line = "$diatheke $search $optionfilters $latinxlit -l $locale -m $maxverses -f cgi -b $versions[$i] -k \"$verse\" $err";
+
     if ($debug) {
-	print "command line: $diatheke $search $optionfilters -l $locale -m $maxverses -f thml -b $versions[$i] -k \"$verse\"\n<br />";
+	print "command line: $line\n<br />";
     }
-    $line = `$diatheke $search $optionfilters -l $locale -m $maxverses -f thml -b $versions[$i] -k \"$verse\" 2> /dev/null`;
+    $line = `$line`;
 
     chomp($line);
 
+    $line =~ s/!DIATHEKE_URL!/$scriptname\?/g;
+
 #    Parse and link to Strong's references if present
     
-    $line =~ s/<sync type=\"Strongs\" value=\"\w?H([0-9]+)\" \/>/<a href=\"diatheke.pl?verse=$1&StrongsHebrew=on\">&lt;$1&gt;\<\/a\>/g;
-    $line =~ s/<sync type=\"Strongs\" value=\"\w?G([0-9]+)\" \/>/<a href=\"diatheke.pl?verse=$1&&StrongsGreek=on\">&lt;$1&gt;\<\/a\>/g;
-    $line =~ s/<sync type=\"Morph\" value=\"\w?H([0-9]+)\" \/>/<a href=\"diatheke.pl?verse=$1&StrongsHebrew=on\">&lt;T$1&gt;\<\/a\>/g;
-    $line =~ s/<sync type=\"Morph\" value=\"\w?G([0-9]+)\" \/>/<a href=\"diatheke.pl?verse=$1&&StrongsGreek=on\">&lt;T$1&gt;\<\/a\>/g;
-    $line =~ s/<sync type=\"Morph\" value=\"([^\"]+)\" \/>/<a href=\"diatheke.pl?verse=$1&Packard=on\">&lt;$1&gt;\<\/a\>/g;
-    
-    $info = `$diatheke -b info -k $versions[$i] 2> /dev/null`;
-    $info =~ /([^\;]+)\;(.*)/;
+    $info = `$diatheke -b info -k $versions[$i] $err`;
+    $info =~ /([^\;]+)\;([^\;]+)/;
     $format = $1;
     $type = $2;
     
     if ($versions[$i] eq "StrongsHebrew") {
-	$line =~ s/(see HEBREW for )([0-9]+)/<a href=\"diatheke.pl?verse=$2&StrongsHebrew=on\">$1$2\<\/a\>/g;
+	$line =~ s/(see HEBREW for )([0-9]+)/<a href=\"$scriptname?verse=$2&StrongsHebrew=on\">$1$2\<\/a\>/g;
     }
     elsif($versions[$i] eq "StrongsGreek") {
-	$line =~ s/(see GREEK for )([0-9]+)/<a href=\"diatheke.pl?verse=$2&StrongsGreek=on\">$1$2\<\/a\>/g;
+	$line =~ s/(see GREEK for )([0-9]+)/<a href=\"$scriptname?verse=$2&StrongsGreek=on\">$1$2\<\/a\>/g;
     }
-    elsif ($versions[$i] eq "BDB" || $versions[$i] eq "Thayer") {
-	$line =~ s/([0-9][0-9][0-9][0-9]+)/<a href=\"diatheke.pl?verse=$1&$versions[$i]=on\">$1\<\/a\>/g;
-    }
-    
-    #case for ThML format texts
-    elsif($format eq "ThML") {
-	$line =~ s/<scripRef version=\"([^\"]+)\" passage=\"([^\"]+)\">/&plussifyaddress($2,$1)/ge;
-	$line =~ s/<\/scripRef>/<\/a>/g;
+    #case for searches
+    elsif($search ne "") {
+	$line =~ s/<entry>([^<]+)<\/entry>/urlvers($1, $versions[$i])/eg;
     }
     #case for non-ThML, non-Bible texts
     elsif($type ne "Biblical Texts") {
@@ -365,219 +441,23 @@ for ($i = 0; $i < $n; $i++) {
 	$book =~ s/^([A-Za-z0-9]+) [0-9]+:[0-9]+.*/$1/;
 	$chapter = $verse;
 	$chapter =~ s/[A-Za-z0-9]+ ([0-9]+):[0-9]+.*/$1/;
-	
-	$line =~ s/\#*([1-9]*[A-Z][a-z]+\.*) ([0-9]+):([0-9]+-*,*[0-9]*)\|*/<a href=\"diatheke.pl?verse=$1+$2%3A$3&$defversion=on\">$1 $2:$3\<\/a\>/g;
-	$line =~ s/\#([0-9]+):([0-9]+-*,*[0-9]*)\|*/<a href=\"diatheke.pl?verse=$book+$1%3A$2&$defversion=on\">$book $1:$2\<\/a\>/g;
-	$line =~ s/\#([0-9]+-*,*[0-9]*)\|*/<a href=\"diatheke.pl?verse=$book+$chapter%3A$1&$defversion=on\">$book $chapter:$1\<\/a\>/g;
+	$line =~ s/\#*([1-9]*[A-Z][a-z]+\.*) ([0-9]+):([0-9]+-*,*[0-9]*)\|*/<a href=\"$scriptname?verse=$1+$2%3A$3&$defversion=on\">$1 $2:$3\<\/a\>/g;
+	$line =~ s/\#([0-9]+):([0-9]+-*,*[0-9]*)\|*/<a href=\"$scriptname?verse=$book+$1%3A$2&$defversion=on\">$book $1:$2\<\/a\>/g;
+	$line =~ s/\#([0-9]+-*,*[0-9]*)\|*/<a href=\"$scriptname?verse=$book+$chapter%3A$1&$defversion=on\">$book $chapter:$1\<\/a\>/g;
     }
-#--------- Change full book names to abbreviations
-#>>
-    if ($search eq "") {
-	$line =~ s/^Genesis/Gen/g;
-	$line =~ s/^Exodus/Ex/g;
-	$line =~ s/^Leviticus/Lev/g;
-	$line =~ s/^Numbers/Num/g;
-	$line =~ s/^Deuteronomy/Deut/g;
-	$line =~ s/^Joshua/Jos/g;
-	$line =~ s/^Judges/Jdg/g;
-	$line =~ s/^II Samuel/2Sam/g;
-	$line =~ s/^I Samuel/1Sam/g;
-	$line =~ s/^II Kings/2Kgs/g;
-	$line =~ s/^I Kings/1Kgs/g;
-	$line =~ s/^II Chronicles/2Chr/g;
-	$line =~ s/^I Chronicles/1Chr/g;
-	$line =~ s/^Nehemiah/Neh/g;
-	$line =~ s/^Psalms/Ps/g;
-	$line =~ s/^Proverbs/Prov/g;
-	$line =~ s/^Ecclesiastes/Eccl/g;
-	$line =~ s/^Song of Solomon/Song/g;
-	$line =~ s/^Isaiah/Isa/g;
-	$line =~ s/^Jeremiah/Jer/g;
-	$line =~ s/^Lamentations/Lam/g;
-	$line =~ s/^Ezekiel/Ezek/g;
-	$line =~ s/^Daniel/Dan/g;
-	$line =~ s/^Hosea/Hos/g;
-	$line =~ s/^Obadiah/Obad/g;
-	$line =~ s/^Jonah/Jnh/g;
-	$line =~ s/^Nahum/Nah/g;
-	$line =~ s/^Habakkuk/Hab/g;
-	$line =~ s/^Zephaniah/Zeph/g;
-	$line =~ s/^Haggai/Hag/g;
-	$line =~ s/^Zechariah/Zech/g;
-	$line =~ s/^Malachi/Mal/g;
-	
-	$line =~ s/^Revelation of John/Rev/g;
-	$line =~ s/^Matthew/Mt/g;
-	$line =~ s/^Mark/Mk/g;
-	$line =~ s/^Luke/Lk/g;
-	$line =~ s/^John/Jn/g;
-	$line =~ s/^Romans/Rom/g;
-	$line =~ s/^II Corinthians/2Cor/g;
-	$line =~ s/^I Corinthians/1Cor/g;
-	$line =~ s/^Galatians/Gal/g;
-	$line =~ s/^Ephesians/Eph/g;
-	$line =~ s/^Philippians/Php/g;
-	$line =~ s/^Colossians/Col/g;
-	$line =~ s/^II Thessalonians/2Thes/g;
-	$line =~ s/^I Thessalonians/1Thes/g;
-	$line =~ s/^II Timothy/2Tim/g;
-	$line =~ s/^I Timothy/1Tim/g;
-	$line =~ s/^Titus/Tit/g;
-	$line =~ s/^Philemon/Phlm/g;
-	$line =~ s/^Hebrews/Heb/g;
-	$line =~ s/^James/Jas/g;
-	$line =~ s/^II Peter/2Pet/g;
-	$line =~ s/^I Peter/1Pet/g;
-	$line =~ s/^III John/3Jn/g;
-	$line =~ s/^II John/2Jn/g;
-	$line =~ s/^I John/1Jn/g;
 
-	$line =~ s/\nGenesis/Gen/g;
-	$line =~ s/\nExodus/Ex/g;
-	$line =~ s/\nLeviticus/Lev/g;
-	$line =~ s/\nNumbers/Num/g;
-	$line =~ s/\nDeuteronomy/Deut/g;
-	$line =~ s/\nJoshua/Jos/g;
-	$line =~ s/\nJudges/Jdg/g;
-	$line =~ s/\nII Samuel/2Sam/g;
-	$line =~ s/\nI Samuel/1Sam/g;
-	$line =~ s/\nII Kings/2Kgs/g;
-	$line =~ s/\nI Kings/1Kgs/g;
-	$line =~ s/\nII Chronicles/2Chr/g;
-	$line =~ s/\nI Chronicles/1Chr/g;
-	$line =~ s/\nNehemiah/Neh/g;
-	$line =~ s/\nPsalms/Ps/g;
-	$line =~ s/\nProverbs/Prov/g;
-	$line =~ s/\nEcclesiastes/Eccl/g;
-	$line =~ s/\nSong of Solomon/Song/g;
-	$line =~ s/\nIsaiah/Isa/g;
-	$line =~ s/\nJeremiah/Jer/g;
-	$line =~ s/\nLamentations/Lam/g;
-	$line =~ s/\nEzekiel/Ezek/g;
-	$line =~ s/\nDaniel/Dan/g;
-	$line =~ s/\nHosea/Hos/g;
-	$line =~ s/\nObadiah/Obad/g;
-	$line =~ s/\nJonah/Jnh/g;
-	$line =~ s/\nNahum/Nah/g;
-	$line =~ s/\nHabakkuk/Hab/g;
-	$line =~ s/\nZephaniah/Zeph/g;
-	$line =~ s/\nHaggai/Hag/g;
-	$line =~ s/\nZechariah/Zech/g;
-	$line =~ s/\nMalachi/Mal/g;
-	
-	$line =~ s/\nRevelation of John/Rev/g;
-	$line =~ s/\nMatthew/Mt/g;
-	$line =~ s/\nMark/Mk/g;
-	$line =~ s/\nLuke/Lk/g;
-	$line =~ s/\nJohn/Jn/g;
-	$line =~ s/\nRomans/Rom/g;
-	$line =~ s/\nII Corinthians/2Cor/g;
-	$line =~ s/\nI Corinthians/1Cor/g;
-	$line =~ s/\nGalatians/Gal/g;
-	$line =~ s/\nEphesians/Eph/g;
-	$line =~ s/\nPhilippians/Php/g;
-	$line =~ s/\nColossians/Col/g;
-	$line =~ s/\nII Thessalonians/2Thes/g;
-	$line =~ s/\nI Thessalonians/1Thes/g;
-	$line =~ s/\nII Timothy/2Tim/g;
-	$line =~ s/\nI Timothy/1Tim/g;
-	$line =~ s/\nTitus/Tit/g;
-	$line =~ s/\nPhilemon/Phlm/g;
-	$line =~ s/\nHebrews/Heb/g;
-	$line =~ s/\nJames/Jas/g;
-	$line =~ s/\nII Peter/2Pet/g;
-	$line =~ s/\nI Peter/1Pet/g;
-	$line =~ s/\nIII John/3Jn/g;
-	$line =~ s/\nII John/2Jn/g;
-	$line =~ s/\nI John/1Jn/g;
-	
+    if ($locale ne "abbr") {
+	$line =~ s/href=\"$scriptname([^\"]+)\"/href=\"$scriptname$1&locale=$locale\"/g;
     }
-    elsif ($format ne "ThML") {
-
-	$line =~ s/Genesis/Gen/g;
-	$line =~ s/Exodus/Ex/g;
-	$line =~ s/Leviticus/Lev/g;
-	$line =~ s/Numbers/Num/g;
-	$line =~ s/Deuteronomy/Deut/g;
-	$line =~ s/Joshua/Jos/g;
-	$line =~ s/Judges/Jdg/g;
-	$line =~ s/II Samuel/2Sam/g;
-	$line =~ s/I Samuel/1Sam/g;
-	$line =~ s/II Kings/2Kgs/g;
-	$line =~ s/I Kings/1Kgs/g;
-	$line =~ s/II Chronicles/2Chr/g;
-	$line =~ s/I Chronicles/1Chr/g;
-	$line =~ s/Nehemiah/Neh/g;
-	$line =~ s/Psalms/Ps/g;
-	$line =~ s/Proverbs/Prov/g;
-	$line =~ s/Ecclesiastes/Eccl/g;
-	$line =~ s/Song of Solomon/Song/g;
-	$line =~ s/Isaiah/Isa/g;
-	$line =~ s/Jeremiah/Jer/g;
-	$line =~ s/Lamentations/Lam/g;
-	$line =~ s/Ezekiel/Ezek/g;
-	$line =~ s/Daniel/Dan/g;
-	$line =~ s/Hosea/Hos/g;
-	$line =~ s/Obadiah/Obad/g;
-	$line =~ s/Jonah/Jnh/g;
-	$line =~ s/Nahum/Nah/g;
-	$line =~ s/Habakkuk/Hab/g;
-	$line =~ s/Zephaniah/Zeph/g;
-	$line =~ s/Haggai/Hag/g;
-	$line =~ s/Zechariah/Zech/g;
-	$line =~ s/Malachi/Mal/g;
-	
-	$line =~ s/Revelation of John/Rev/g;
-	$line =~ s/Matthew/Mt/g;
-	$line =~ s/Mark/Mk/g;
-	$line =~ s/Luke/Lk/g;
-	$line =~ s/John/Jn/g;
-	$line =~ s/Romans/Rom/g;
-	$line =~ s/II Corinthians/2Cor/g;
-	$line =~ s/I Corinthians/1Cor/g;
-	$line =~ s/Galatians/Gal/g;
-	$line =~ s/Ephesians/Eph/g;
-	$line =~ s/Philippians/Php/g;
-	$line =~ s/Colossians/Col/g;
-	$line =~ s/II Thessalonians/2Thes/g;
-	$line =~ s/I Thessalonians/1Thes/g;
-	$line =~ s/II Timothy/2Tim/g;
-	$line =~ s/I Timothy/1Tim/g;
-	$line =~ s/Titus/Tit/g;
-	$line =~ s/Philemon/Phlm/g;
-	$line =~ s/Hebrews/Heb/g;
-	$line =~ s/James/Jas/g;
-	$line =~ s/II Peter/2Pet/g;
-	$line =~ s/I Peter/1Pet/g;
-	$line =~ s/III John/3Jn/g;
-	$line =~ s/II John/2Jn/g;
-	$line =~ s/I John/1Jn/g;
-
-	$line =~ s/([0-9]*[A-Za-z]+) ([0-9]+):([0-9]+)/<a href=\"diatheke.pl?verse=$1+$2%3A$3&$versions[$i]=on\">$1 $2:$3\<\/a\>/g;
-    }
-#<<
-
-# for the old HREFCom version of JFB
-#    if ($versions[$i] eq "JFB") {
-#	$line =~ s/(http:[^ ]+) /<a href="$1">$1<\/a>/g;
-#    }
-
     if ($palm == 1) {
-	$line =~ s/href=\"diatheke.pl([^\"]+)\"/href=\"http:\/\/bible.gotjesus.org\/cgi-bin\/diatheke.pl$1&palm=on\"/g;
+	$line =~ s/href=\"$scriptname([^\"]+)\"/href=\"$cgiurl\/$scriptname$1&palm=on\"/g;
     }
 
-    if ($footnotes == 0) {
-	$line =~ s/<note[^<]+<\/note>//g;
-    }
-    if ($strongs == 0) {
-	$line =~ s/<a href=[^>]+Strongs(Greek|Hebrew)[^<]+<\/a>//g;
-    }
-    
     print "$line <br /><br />\n";
 }
 
 if ($palm == 1) {
-    print "<hr>Powered by Diatheke (bible.gotjesus.org) and the SWORD Project (www.crosswire.org).";
+    print "<hr>Powered by Diatheke (http:\/\/www.gotjesus.org\/sword\/diatheke) and the SWORD Project (http:\/\/www.crosswire.org\/sword).";
 }
 
 print "<br /><br /><br /><br /></font></body></html>";
