@@ -10,6 +10,6 @@ int read(int fd, void* buf, size_t count);
 int write(int fd, const void * buf, size_t count);
 off_t lseek(int fildes, off_t offset, int whence);
 int access(const char* path, int mode);
-#define unlink remove
+#define unlink ::remove
 
 #endif
