@@ -60,6 +60,10 @@ __fastcall TForm1::~TForm1()
 		if (ctrlstates[loop]);
 			delete ctrlstates[loop];
 	}
+	list <ModState *>::iterator mit;
+	for (mit = modstates.begin(); mit != modstates.end(); mit++) {
+		delete (*mit);
+	}
 }
 //---------------------------------------------------------------------------
 void TForm1::BuildRTFHeader(char *buf, char *font, int max)
@@ -115,8 +119,9 @@ char TForm1::CreateTextPane(SWModule *mod, char *font) {
 		if ((*sit).second.find("FontSize") != (*sit).second.end())
 			newrtf->FontSize = atoi((*(*sit).second.find("FontSize")).second.c_str());
 	}
-
-	mod->Disp(*displays.insert(displays.begin(), new RTFDisp(newrtf)));
+	SWDisplay *disp = new RTFDisp(newrtf);
+	mod->Disp(disp);
+	displays.insert(displays.begin(), disp);
 	mod->SetKey(DefaultVSKey);
 
 	return 0;
@@ -131,7 +136,8 @@ char TForm1::CreateCommentPane(SWModule *mod) {
 //		if (mainmgr->config->Sections[mod->Name()]["External"] == "1") {
 			newrtf = new TPanel(this);
 			((TPanel *)newrtf)->Caption = "Syncronizing to External Viewer";
-			mod->Disp(*displays.insert(displays.begin(), new DispExternal()));
+			SWDisplay *disp = new DispExternal();
+			mod->Disp(*displays.insert(displays.begin(), disp));
 /*
 		}
 		else {
@@ -150,7 +156,8 @@ char TForm1::CreateCommentPane(SWModule *mod) {
 			if ((*sit).second.find("FontSize") != (*sit).second.end())
 				((SWDispRTF *)newrtf)->FontSize = atoi((*(*sit).second.find("FontSize")).second.c_str());
 		}
-		mod->Disp(*displays.insert(displays.begin(), new RTFDisp((SWDispRTF *)newrtf)));
+		SWDisplay *disp = new RTFDisp((SWDispRTF *)newrtf);
+		mod->Disp(*displays.insert(displays.begin(), disp));
 		((SWDispRTF *)newrtf)->ScrollBars = ssVertical;
 		((SWDispRTF *)newrtf)->ReadOnly = true;
 
@@ -193,7 +200,8 @@ char TForm1::CreateLDPane(SWModule *mod) {
 		if ((*sit).second.find("FontSize") != (*sit).second.end())
 			newrtf->FontSize = atoi((*(*sit).second.find("FontSize")).second.c_str());
 	}
-	mod->Disp(*displays.insert(displays.begin(), new RTFDisp(newrtf)));
+	SWDisplay *disp = new RTFDisp(newrtf);
+	mod->Disp(*displays.insert(displays.begin(), disp));
 	mod->SetKey(DefaultStrKey);
 	return 0;
 }
@@ -348,7 +356,8 @@ void __fastcall TForm1::verseLookupClick(TObject *Sender)
 		rtf->SelLength = 0;
 	}
 	else	freeHandLookup->Text = Trim(rtf->SelText);
-	freeHandLookupoldKeyPress(Sender, '\r');
+	char ret = '\r';
+	freeHandLookupoldKeyPress(Sender, ret);
 }
 //---------------------------------------------------------------------------
 void __fastcall TForm1::SaveLayout1Click(TObject *Sender)
@@ -490,7 +499,8 @@ void __fastcall TForm1::FormShow(TObject *Sender)
 
 		if ((eit = (*sit).second.find("LastVerse")) != (*sit).second.end()) {
 			freeHandLookup->Text = (*eit).second.c_str();
-			freeHandLookupoldKeyPress(0, '\r');
+			char ret = '\r';
+			freeHandLookupoldKeyPress(0, ret);
 		}
 	}
 }
@@ -632,7 +642,16 @@ void __fastcall TForm1::Copy1Click(TObject *Sender)
 void __fastcall TForm1::BookmarkItemClick(TObject *Sender)
 {
 	TMenuItem *menuchoice = (TMenuItem *)Sender;
-	DefaultVSKey = menuchoice->Caption.c_str();	
+	const char *source = menuchoice->Caption.c_str();
+	char *value = new char [strlen(source) + 1];
+	int k = 0;
+	for (unsigned int j = 0; j < strlen(source); j++) {
+		if (source[j] != '&')
+			value[k++] = source[j];
+	}
+	value[k] = 0;
+	DefaultVSKey = value;	
+	delete [] value;
 	TextKeyChanged();
 }
 
@@ -915,7 +934,7 @@ void __fastcall TForm1::createVerseList(TObject *Sender)
 void __fastcall TForm1::freeHandLookupoldKeyPress(TObject *Sender, char &Key)
 {
 	if (Key == '\r') {
-		ListKey &tmpVerseList = VerseKey::ParseVerseList(freeHandLookup->Text.c_str(), DefaultVSKey);
+		ListKey tmpVerseList = VerseKey::ParseVerseList(freeHandLookup->Text.c_str(), DefaultVSKey);
 
 		if (tmpVerseList.Count()) {
 			int index = freeHandLookup->Items->IndexOf(freeHandLookup->Text);
@@ -1012,9 +1031,25 @@ void __fastcall TForm1::LinktoVerse1Click(TObject *Sender)
 void __fastcall TForm1::GlobalOptionChange(TObject *Sender)
 {
 	TMenuItem *menuchoice = (TMenuItem *)Sender;
-	string value = menuchoice->Caption.c_str();
-	string option = menuchoice->Parent->Caption.c_str();
-	mainmgr->setGlobalOption(option.c_str(), value.c_str());
+	const char *source = menuchoice->Caption.c_str();
+	char *value = new char [strlen(source) + 1];
+	int k = 0;
+	for (unsigned int j = 0; j < strlen(source); j++) {
+		if (source[j] != '&')
+			value[k++] = source[j];
+	}
+	value[k] = 0;
+	source = menuchoice->Parent->Caption.c_str();
+	char *option = new char [strlen(source) + 1];
+	k = 0;
+	for (unsigned int j = 0; j < strlen(source); j++) {
+		if (source[j] != '&')
+			option[k++] = source[j];
+	}
+	option[k] = 0;
+	mainmgr->setGlobalOption(option, value);
+	delete [] option;
+	delete [] value;
 	TextKeyChanged();
 }
 //---------------------------------------------------------------------------
@@ -1026,11 +1061,30 @@ void __fastcall TForm1::OptionShowVals(TObject *Sender)
 	TMenuItem *menuChoice = (TMenuItem *)Sender;
 
 	string option = menuChoice->Caption.c_str();
-	string value = mainmgr->getGlobalOption(option.c_str());
+	int k = 0;
+	const char *source = option.c_str();
+	char *caption = new char [strlen(source) + 1];
+	for (unsigned int j = 0; j < strlen(source); j++) {
+		if (source[j] != '&')
+			caption[k++] = source[j];
+	}
+	caption[k] = 0;
+		
+	string value = mainmgr->getGlobalOption(caption);
+	delete [] caption;
 	for (int i = 0; i < menuChoice->Count; i++) {
-		if (!stricmp(menuChoice->Items[i]->Caption.c_str(), value.c_str()))
+		int k = 0;
+		char *source = menuChoice->Items[i]->Caption.c_str();
+		char *caption = new char [strlen(source) + 1];
+		for (unsigned int j = 0; j < strlen(source); j++) {
+			if (source[j] != '&')
+				caption[k++] = source[j];
+		}
+		caption[k] = 0;
+		if (!stricmp(caption, value.c_str()))
 			menuChoice->Items[i]->Checked = true;
 		else	menuChoice->Items[i]->Checked = false;                            
+		delete [] caption;
 	}
 }
 //---------------------------------------------------------------------------
@@ -1042,9 +1096,13 @@ void __fastcall TForm1::Contents1Click(TObject *Sender)
 	if (it != optionsconf->Sections["Help"].end())
 		helpDir = (*it).second;
 	else helpDir = ".\\help";
-	helpDir += "\\index.html";
+
+	string helpExe = helpDir + "\\sword.chm";
 	
-	ShellExecute(this->Handle, "open", helpDir.c_str(), NULL, NULL, SW_SHOWNORMAL);	
+	if ((int)ShellExecute(this->Handle, "open", helpExe.c_str(), NULL, NULL, SW_SHOWNORMAL) < 33) {
+		helpExe = helpDir + "\\index.html";
+		ShellExecute(this->Handle, "open", helpExe.c_str(), NULL, NULL, SW_SHOWNORMAL);
+	}
 }
 //---------------------------------------------------------------------------
 
