@@ -31,6 +31,9 @@ __published:	// IDE-managed Components
 	TLabel *Label3;
 	TUpDown *UpDown1;
 	TEdit *fontSize;
+	TPanel *Panel4;
+	TGroupBox *GroupBox3;
+	TCheckBox *HintPopups;
 	void __fastcall ChooseColorbtnClick(TObject *Sender);
 	
 private:	// User declarations
