@@ -8,7 +8,7 @@ USEFORM("StatusFrm.cpp", StatusForm);
 USEFORM("RemoteMntFrm.cpp", RemoteMntForm);
 USEFORM("InfoFrm.cpp", InfoForm);
 USEFORM("cipherfrm.cpp", CipherForm);
-USEFORM("..\BibleCS\UninstallFrm.cpp", UninstallForm);
+USEFORM("UninstallFrm.cpp", UninstallForm);
 //---------------------------------------------------------------------------
 WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
 {
