@@ -13,7 +13,8 @@
 #include <strkey.h>
 #include <regex.h>
 #include <listkey.h>
-#include <swdisprtfchap.h>
+#include <swgenbook.h>
+#include "swdisprtfchap.h"
 #include <vcl\Buttons.hpp>
 #include <vcl\Menus.hpp>
 #include <vcl\DdeMan.hpp>
@@ -24,12 +25,14 @@
 #include <ImgList.hpp>
 #include <jpeg.hpp>
 #include "RxRichEd.hpp"
+//#include "MOZILLACONTROLLib_OCX.h"
+#include "SHDocVw_OCX.h"
 
 #ifndef USEOLDRTF
 #include "RxRichEd.hpp"
 #else
 #define TRxRichEdit TRichEdit
-#endif
+#endif    	
 
 #include <list>
 #include <vector>
@@ -44,17 +47,61 @@ public:
 	}
 };
 
-/*
 class HREFDisp : public SWDisplay {
-	THTML *edit;
+	TCppWebBrowser *edit;
 public:
-	HREFDisp(THTML *iedit) { edit = iedit; }
+	HREFDisp(TCppWebBrowser *iedit) { edit = iedit; }
 	HREFDisp() {}
 	char Display(SWModule &imodule) {
-		edit->RequestDoc((char *)imodule);
+
+		TMemoryStream *stm = new TMemoryStream();
+
+		if ( stm == NULL )
+			return 1;
+
+		stm->Clear();
+		string modText = (string)"<HTML><BODY>" + (string)imodule.RenderText() + (string)"</BODY></HTML>";
+		stm->WriteBuffer(modText.c_str(), modText.length());
+
+		IPersistStreamInit *psi = NULL;
+
+		stm->Seek( 0, 0 );
+
+		// If you pass soOwned instead, the stream will be freed for you
+		TStreamAdapter *sa = new TStreamAdapter( stm, soReference );
+
+		if ( sa == NULL ) {
+			delete stm;
+			return 1;
+		}
+
+		_di_IDispatch doc = edit->Document;
+		if ( doc == NULL ) {
+			TVariant url = "about:blank";
+			edit->Navigate2( &url );
+			while ( doc == NULL ) {
+				Application->ProcessMessages();
+				doc = edit->Document;
+			}
+		}
+
+//		if ( doc->QueryInterface(IID_IPersistStreamInit, (void**)&psi ) == S_OK ) {
+		HRESULT result = doc->QueryInterface(IID_IPersistStreamInit, (void**)&psi );
+		if (result == S_OK) {
+//		if ( doc->QueryInterface(IID_IWrite, (void**)"test" ) == S_OK ) {
+			if ( psi )
+				psi->Load( *sa );
+		}
+		else
+			delete sa;
+
+		delete stm;
+	
+//		edit->SetTextBuf("yo mama");
+//		edit->RequestDoc((char *)imodule);
+		return 0;
 	}
 };
-*/
 
 class DispExternal : public SWDisplay {
 public:
@@ -65,7 +112,7 @@ public:
 		info.fMask = SEE_MASK_NOCLOSEPROCESS; //SEE_MASK_CLASSNAME;
 		info.hwnd = GetFocus();
 		info.lpVerb = "open";
-		info.lpFile = (char *)imodule;
+		info.lpFile = (const char *)imodule;
 		info.lpParameters = NULL;
 		info.lpDirectory = NULL;
 		info.nShow = 0;
@@ -161,6 +208,9 @@ __published:	// IDE-managed Components
 	TListBox *lbDictKeys;
 	TPopupMenu *PopupMenu4;
 	TMenuItem *HideShowModules1;
+        TMenuItem *DevotionaloftheDay1;
+	TMenuItem *Tools1;
+	TMenuItem *InstallManager1;
 	void __fastcall PageControl1Change(TObject *Sender);
 	void __fastcall btnLookupClick(TObject *Sender);
 	void __fastcall PageControl2Change(TObject *Sender);
@@ -212,6 +262,7 @@ __published:	// IDE-managed Components
 	void __fastcall EditEntry1Click(TObject *Sender);
 	void __fastcall DeleteEntry1Click(TObject *Sender);
 	void __fastcall LinktoVerse1Click(TObject *Sender);
+	void __fastcall BookTOCChange(TObject* Sender, TTreeNode* Node);
 	
 	void __fastcall GlobalOptionChange(TObject *Sender);
 	
@@ -222,6 +273,12 @@ __published:	// IDE-managed Components
 	void __fastcall lbDictKeysClick(TObject *Sender);
 	void __fastcall verseLookupClick(TObject *Sender);
 	void __fastcall HideShowModules1Click(TObject *Sender);
+     void __fastcall DevotionaloftheDay1Click(TObject *Sender);
+	void __fastcall CppWebBrowser1BeforeNavigate2(TObject *Sender,
+		LPDISPATCH pDisp, TVariant *URL, TVariant *Flags,
+		TVariant *TargetFrameName, TVariant *PostData, TVariant *Headers,
+		TOLEBOOL *Cancel);
+	void __fastcall InstallManager1Click(TObject *Sender);
 private:	// User declarations
 	list <SWDisplay *> displays;	// so we can delete each display we create
 	list <ModState *> modstates;
@@ -229,22 +286,25 @@ private:	// User declarations
 	bool logmodstate;
 	bool freshdict;
 
+	void fillTreeTOC(TreeKeyIdx treeKey, TTreeView *tree, TTreeNode *parent);
 	char CreateTextPane(SWModule *mod, char *font = 0);
-	char CreateCommentPane(SWModule *mod);
-	char CreateLDPane(SWModule *mod);
+	char CreateCommentPane(SWModule *mod, char *font = 0);
+	char CreateLDPane(SWModule *mod, char *font = 0);
+	char CreateBookPane(SWModule *mod, char *font = 0);
 	void PushState();
 	void BackState();
 	void ForwardState();
-	void BuildRTFHeader(char *buf, char *font, int max);
+	void BuildRTFHeader(char *buf, char *font, int max, char *type = "Text");
 	void AddSectionToMenu(TMenu *menu, TMenuItem *item, TTreeNode *tree);
 	void FillDictKeys();
 	void AddVerseChoices(TPopupMenu *menu, const char *buf, TRxRichEdit *rtf);
 	void fillVKeySelector(VerseKey *vk);
 	static bool hasFeature(SWMgr *mgr, const char *modName, const char *feature);
+        void NavigateVerseURL(char* verStr);
 
 public:		// User declarations
-	VerseKey DefaultVSKey;
-	SWKey DefaultStrKey;
+	VerseKey *DefaultVSKey;
+	SWKey *DefaultStrKey;
 	SWMgr *mainmgr;
 	SWConfig *layoutconf;
 	SWConfig *optionsconf;
@@ -255,7 +315,8 @@ public:		// User declarations
 	void RefreshBookmarksMenu(TMenu *menu, TTreeView *tree);
 	void RestoreState(ModState *state);
 	static String TrimJunk(String src);
-     
+	static void TColorToRGB(const TColor& color, int& red, int& green, int& blue);
+        void __fastcall AppMessage(tagMSG &Msg, bool &Handled);     
 	ListKey tmpVerseList;
 	String tmpVerseListCaption;
 };
