@@ -109,7 +109,7 @@ void __fastcall TForm2::ListBox1DblClick(TObject *Sender)
 			Form1->DictKeyEdit->Text = resultsLV->Items->Item[row]->Caption.c_str();
 		}
 		else {
-			Form1->DefaultVSKey = resultsLV->Items->Item[row]->Caption.c_str();
+			*(Form1->DefaultVSKey) = resultsLV->Items->Item[row]->Caption.c_str();
 			Form1->TextKeyChanged();
 		}
 	}
@@ -121,12 +121,20 @@ void __fastcall TForm2::ListBox1Click(TObject *Sender)
      
 	if (target != Form1->mainmgr->Modules.end()) {
 		SWKey *savekey = (SWKey *)*(*target).second;
+		SWKey saveKeyText;
+		bool pKey = false;
+		if (savekey->Persist()) {
+			pKey = true;
+		}
+		else {
+			saveKeyText = target->second->KeyText();
+		}
 		TListItem *focused = resultsLV->ItemFocused;
 		if (focused) {
 			int row = focused->Index;
 			(*target).second->SetKey(resultsLV->Items->Item[row]->Caption.c_str());
 			pvrtf->Display(*(*target).second);
-			(*target).second->SetKey(*savekey);
+			(*target).second->SetKey((pKey)?*savekey:saveKeyText);
 		}
 	}
 }
