@@ -11,12 +11,10 @@ USEUNIT("..\..\..\..\src\modules\comments\rawcom\rawcom.cpp");
 USEUNIT("..\..\..\..\src\modules\comments\swcom.cpp");
 USEUNIT("..\..\..\..\src\modules\common\rawverse.cpp");
 USEUNIT("..\..\..\..\src\modules\common\rawstr.cpp");
-USEUNIT("..\..\..\..\src\modules\filters\rwprtf.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\gbfrtf.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\gbfplain.cpp");
 USEUNIT("..\..\..\..\src\modules\lexdict\rawld\rawld.cpp");
 USEUNIT("..\..\..\..\src\modules\lexdict\swld.cpp");
-USEUNIT("..\..\..\..\src\modules\texts\rawgbf\rawgbf.cpp");
 USEUNIT("..\..\..\..\src\modules\texts\rawtext\rawtext.cpp");
 USEUNIT("..\..\..\..\src\modules\texts\swtext.cpp");
 USEUNIT("..\..\..\..\src\modules\swmodule.cpp");
@@ -48,7 +46,6 @@ USEUNIT("..\..\..\..\src\modules\filters\gbfthml.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\plainfootnotes.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\plainhtml.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\rtfhtml.cpp");
-USEUNIT("..\..\..\..\src\modules\filters\rwphtml.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\thmlgbf.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\thmlhtml.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\thmlplain.cpp");
@@ -77,6 +74,44 @@ USEUNIT("..\..\..\..\src\modules\filters\unicodertf.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\gbfmorph.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\thmlolb.cpp");
 USEUNIT("..\..\..\..\src\utilfuns\roman.c");
+USEUNIT("..\..\..\..\src\modules\filters\gbfhtmlhref.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\latin1utf8.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\latin1utf16.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\scsuutf8.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\swbasicfilter.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\thmlhtmlhref.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8cantillation.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8greekaccents.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8hebrewpoints.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8transliterator.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8utf16.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf16utf8.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8latin1.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8html.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\thmlscripref.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\thmlheadings.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\thmllemma.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\thmlmorph.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\thmlfootnotes.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\thmlstrongs.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8nfkd.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8nfc.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8bidireorder.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\utf8arshaping.cpp");
+USEUNIT("..\..\..\..\src\mgr\markupfiltmgr.cpp");
+USEUNIT("..\..\..\..\src\mgr\encfiltmgr.cpp");
+USEUNIT("..\..\..\..\src\mgr\swfiltermgr.cpp");
+USEUNIT("..\..\..\..\src\utilfuns\swversion.cpp");
+USEUNIT("..\..\..\..\src\modules\lexdict\zld\zld.cpp");
+USEUNIT("..\..\..\..\src\modules\common\zstr.cpp");
+USEUNIT("..\..\..\..\src\modules\common\entriesblk.cpp");
+USEUNIT("..\..\..\..\src\modules\genbook\swgenbook.cpp");
+USEUNIT("..\..\..\..\src\modules\genbook\rawgenbook\rawgenbook.cpp");
+USEUNIT("..\..\..\..\src\keys\treekey.cpp");
+USEUNIT("..\..\..\..\src\keys\treekeyidx.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\thmlvariants.cpp");
+USEUNIT("..\..\..\..\src\mgr\swcacher.cpp");
+USEUNIT("..\..\..\..\src\modules\filters\greeklexattribs.cpp");
 //---------------------------------------------------------------------------
 #define Library
 
