@@ -3,13 +3,13 @@
 #pragma hdrstop
 USERES("InstallMgr.res");
 USEFORM("MainFrm.cpp", MainForm);
-USELIB("..\BibleCS\swordlib.lib");
 USEFORM("StatusFrm.cpp", StatusForm);
 USEFORM("RemoteMntFrm.cpp", RemoteMntForm);
 USEFORM("InfoFrm.cpp", InfoForm);
 USEFORM("cipherfrm.cpp", CipherForm);
 USEFORM("UninstallFrm.cpp", UninstallForm);
 USELIB("zlib.lib");
+USELIB("..\..\..\..\lib\swordlib.lib");
 //---------------------------------------------------------------------------
 WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
 {
@@ -18,12 +18,12 @@ WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
 		Application->Initialize();
 		Application->Title = "Install Manager";
 		Application->CreateForm(__classid(TMainForm), &MainForm);
-		Application->CreateForm(__classid(TStatusForm), &StatusForm);
-		Application->CreateForm(__classid(TRemoteMntForm), &RemoteMntForm);
-		Application->CreateForm(__classid(TInfoForm), &InfoForm);
-		Application->CreateForm(__classid(TCipherForm), &CipherForm);
-		Application->CreateForm(__classid(TUninstallForm), &UninstallForm);
-		Application->Run();
+                 Application->CreateForm(__classid(TStatusForm), &StatusForm);
+                 Application->CreateForm(__classid(TRemoteMntForm), &RemoteMntForm);
+                 Application->CreateForm(__classid(TInfoForm), &InfoForm);
+                 Application->CreateForm(__classid(TCipherForm), &CipherForm);
+                 Application->CreateForm(__classid(TUninstallForm), &UninstallForm);
+                 Application->Run();
 	}
 	catch (Exception &exception)
 	{
