@@ -23,7 +23,7 @@ extern "C" {
 #include <io.h>
 #include <sys/stat.h>
 #include <dir.h>
-
+#include <FileCtrl.hpp>
 
 TMainForm *MainForm;
 
@@ -207,11 +207,16 @@ void TMainForm::setLocalDir(const char *idir)
 //---------------------------------------------------------------------------
 void __fastcall TMainForm::LocalPath1Click(TObject *Sender)
 {
+     AnsiString Dir = "C:";
+     WideString Root = getLocalDir();
+     SelectDirectory("Select Local Path", Root , Dir);
+
+/*
 	localPathDlg->Title = "Select a file in the directory to choose";
 	localPathDlg->InitialDir = getLocalDir();
 	if (localPathDlg->Execute()) {
 		char *buf = new char [ strlen(localPathDlg->FileName.c_str()) + 1 ];
-	
+
 		strcpy(buf, localPathDlg->FileName.c_str());
 		int end = strlen(buf) - 1;
 		while (end) {
@@ -223,7 +228,10 @@ void __fastcall TMainForm::LocalPath1Click(TObject *Sender)
 		setLocalDir(buf);
 		delete [] buf;
 	}
-	
+*/
+
+        setLocalDir(Dir.c_str());
+
 	installConf->Save();
 	fillSourceTree(getLocalDir(), localTree);
 }
@@ -314,7 +322,7 @@ void TMainForm::fillSourceTree(const char *sourceConf, TTreeView *tree)
 		}
 		
 		mods = mgr->Modules.find(sections->first.c_str());
-		if (mods != mgr->Modules.end())
+                if (mods != mgr->Modules.end())
 			secName = mods->second->Type();
 		else {
 			secName = "Other";
@@ -454,11 +462,10 @@ void __fastcall TMainForm::Button6Click(TObject *Sender)	// SELECT ALL
 void __fastcall TMainForm::Image1Click(TObject *Sender)
 {
 	ShellExecute(this->Handle, "open", "http://www.crosswire.org", NULL, NULL, SW_SHOWNORMAL);
-	
+
 }
 //---------------------------------------------------------------------------
 
-
 int TMainForm::removeModule(const char *modName)
 {
 	SectionMap::iterator module;
@@ -495,7 +502,7 @@ int TMainForm::removeModule(const char *modName)
 				modDir = entry->second.c_str();
 				entry = module->second.find("ModDrv");
 				if (entry != module->second.end()) {
-					if (!strcmp(entry->second.c_str(), "RawLD")) {
+					if (!strcmp(entry->second.c_str(), "RawLD") || !strcmp(entry->second.c_str(), "RawLD4") || !strcmp(entry->second.c_str(), "zLD") || !strcmp(entry->second.c_str(), "RawGenBook") || !strcmp(entry->second.c_str(), "zGenBook")) {
 						char *buf = new char [ strlen(modDir.c_str()) + 1 ];
 	
 						strcpy(buf, modDir.c_str());
@@ -697,7 +704,7 @@ int TMainForm::installModule(const char *modName, InstallSourceTab *ist)
 				modDir = entry->second.c_str();
 				entry = module->second.find("ModDrv");
 				if (entry != module->second.end()) {
-					if (!strcmp(entry->second.c_str(), "RawLD")) {
+					if (!strcmp(entry->second.c_str(), "RawLD") || !strcmp(entry->second.c_str(), "RawLD4") || !strcmp(entry->second.c_str(), "zLD") || !strcmp(entry->second.c_str(), "RawGenBook") || !strcmp(entry->second.c_str(), "zGenBook")) {
 						char *buf = new char [ strlen(modDir.c_str()) + 1 ];
 	
 						strcpy(buf, modDir.c_str());
@@ -880,9 +887,9 @@ int TMainForm::FTPCopy(InstallSourceTab *ist, const char *src, const char *dest,
 	StatusForm->ist = ist;
 	StatusForm->src = src;
 	StatusForm->dest = dest;
-     StatusForm->suffix = suffix;
+        StatusForm->suffix = suffix;
 	StatusForm->dirTransfer = dirTransfer;
-     StatusForm->passive = passive;
+        StatusForm->passive = passive;
 	Application->ProcessMessages();
 	if (StatusForm->ShowModal() == mrCancel)
 		return -1;
@@ -1096,13 +1103,8 @@ void __fastcall TMainForm::Contents1Click(TObject *Sender)
 		helpDir = (*it).second;
 	else helpDir = ".\\help";
 
-	string helpExe = helpDir + "\\sword.chm";
-	
-	if ((int)ShellExecute(this->Handle, "open", helpExe.c_str(), NULL, NULL, SW_SHOWNORMAL) < 33) {
-		helpExe = helpDir + "\\index.html";
-		ShellExecute(this->Handle, "open", helpExe.c_str(), NULL, NULL, SW_SHOWNORMAL);
-	}
-	
+	string helpExe = helpDir + "\\Sword.chm::modulesh.html#instmgr";
+	ShellExecute(this->Handle, "open", "hh", helpExe.c_str(), NULL, SW_SHOWNORMAL);
 }
 //---------------------------------------------------------------------------
 
