@@ -56,7 +56,7 @@ void __fastcall TStatusForm::TFTPThread::Execute()
 	StatusForm->ftpCon->Passive = passive;
 	
 	try {
-		StatusForm->ftpCon->Connect(true);
+		StatusForm->ftpCon->Connect(true, -1);
 		StatusForm->ftpCon->TransferType = ftBinary;
 		StatusForm->ftpCon->ChangeDir(ist->Directory.c_str());
 	}
@@ -70,10 +70,10 @@ void __fastcall TStatusForm::TFTPThread::Execute()
 			StatusForm->ftpCon->ChangeDir(src.c_str());
                TStringList *dirText = new TStringList();
                StatusForm->ftpCon->List(dirText, "*", true);
-               TIdFTPList *dirList = StatusForm->ftpCon->DirectoryListing;
+               TIdFTPListItems *dirList = StatusForm->ftpCon->DirectoryListing;
 			for (int i = 0; i < dirList->Count; i++) {
-				if (!dirList->Items[i]->IsDirectory) {
-					buffer = dest + "/" + dirList->Items[i]->ItemName.c_str();
+				if (dirList->Items[i]->ItemType != ditDirectory) {
+					buffer = dest + "/" + (dirList->Items[i]->FileName.c_str() /*+ 55*/);
 //                           files->Strings[i].c_str();
 					if (!strcmp(&buffer.c_str()[buffer.length()-suffix.length()], suffix.c_str())) {
 						buffer2 = "Downloading (";
@@ -81,13 +81,13 @@ void __fastcall TStatusForm::TFTPThread::Execute()
 						buffer2 += " of ";
 						buffer2 += IntToStr(dirList->Count).c_str();
 						buffer2 += "): ";
-						buffer2 += dirList->Items[i]->ItemName.c_str();
+						buffer2 += (dirList->Items[i]->FileName.c_str() /*+ 55*/);
 		//				SWLog::systemlog->LogInformation("%s", buffer.c_str());
 						TMainForm::createParent(buffer.c_str());	// make sure parent directory exists
 						Synchronize((TThreadMethod)&PreDownload1);
 						try {
 							StatusForm->currentFileSize = dirList->Items[i]->Size;
-							StatusForm->ftpCon->Get(dirList->Items[i]->ItemName.c_str(), buffer.c_str(), true, false);
+							StatusForm->ftpCon->Get(dirList->Items[i]->FileName.c_str() /* + 55*/, buffer.c_str(), true, false);
 						}
 						catch(...) {
 							MessageBox(0, "Can't download file.  If you have not done so recently, you might try pressing the Refresh from Remote Source button.", "Download Error", MB_OK);
