@@ -2,7 +2,8 @@
 #include <vcl\vcl.h>
 #pragma hdrstop
 
-#include <swdisprtfchap.h>
+#include "biblecsmgr.h"
+#include "swdisprtfchap.h"
 //---------------------------------------------------------------------------
 static inline SWDispRTFChap *ValidCtrCheck()
 {
@@ -16,6 +17,12 @@ __fastcall SWDispRTFChap::SWDispRTFChap(TComponent* Owner)
 	FCurVerseMrk = true;
 	FMarkCurrentVerse = true;
 	FAutoPosition     = true;
+
+        OSVERSIONINFO osvi;
+        memset(&osvi, 0, sizeof(OSVERSIONINFO));
+        osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
+        GetVersionEx(&osvi);
+        platformID = osvi.dwPlatformId;        
 }
 
 __fastcall SWDispRTFChap::~SWDispRTFChap()
@@ -41,36 +48,48 @@ char SWDispRTFChap::Display(SWModule &Module)
 	key->Verse(1);
 	newtext = RTFHeader;
 	newtext = newtext + RTFChapterMarkPre + IntToStr(chap) + RTFChapterMarkPost;
+        newtext = newtext + "\\pard\\f0\\nowidctlpar\\cf7 ";
+        if (Module.Direction() == DIRECTION_RTL) {
+                        newtext = newtext + "\\qr ";
+        }
+        if (Module.Direction() == DIRECTION_RTL && (platformID == WINNT && (!strnicmp(Module.Lang(), "he", 2) || !strnicmp(Module.Lang(), "ar", 2)))) {
+                        newtext = newtext + "\\rtlpar ";
+        }
+
 	Module.Error(); // clear error;
 	while ((key->Book() == book) && (key->Chapter() == chap) && (Module.Error() == 0)) {
-		if (key->Verse() == verse) {
-			if (MarkCurrentVerse == true) //	{This does not work for shading background of current verse, but should }
-				newtext = newtext + "\\pard \\nowidctlpar \\shading2000 \\cf2\\f0 "; // \cf2 = second color in color table
-			else newtext = newtext + "\\pard \\nowidctlpar \\cf0\\f0 ";
-		}
-		else newtext = newtext + "\\pard \\nowidctlpar \\cf0 ";
+                newtext = newtext + "{";
+		if (key->Verse() == verse && MarkCurrentVerse == true)
+			newtext = newtext + "\\cf2 "; // \cf2 = second color in color table
 
 		tmptext = "";
-		for (char *loop = (char *)Module; *loop; loop++) {
+		for (const char *loop = (const char *)Module; *loop; loop++) {
 			if (*loop == '\n')
 				tmptext += "\\par ";
 			else	tmptext += *loop;
 		}
 		if (tmptext.Length() > 3) {	// make sure we have an entry
-			newtext = newtext + RTFVerseMarkPre + IntToStr(key->Verse()) + RTFVerseMarkPost;
-			newtext = newtext + RTFVersePre + tmptext + RTFVersePost;
+                        if (Module.Direction() == DIRECTION_RTL && (platformID == WIN9X || (Module.Lang() && strnicmp(Module.Lang(), "he", 2) && strnicmp(Module.Lang(), "ar", 2)))) {
+        			newtext = newtext + RTFVersePre + tmptext + RTFVersePost;
+	        		newtext = newtext + RTFVerseMarkPre + IntToStr(key->Verse()) + RTFVerseMarkPost;
+                                newtext = newtext + "\\par ";
+                        } else {
+	        		newtext = newtext + RTFVerseMarkPre + IntToStr(key->Verse()) + RTFVerseMarkPost;
+        			newtext = newtext + RTFVersePre + tmptext + RTFVersePost;
+                        }
 		}
 		if ((key->Verse() == verse) && (AutoPosition == true)) {
 			tmptext = newtext + RTFTrailer;
 			RTFStream->Clear();
 			RTFStream->WriteBuffer(tmptext.c_str(), tmptext.Length());
 			RTFStream->Position = 0;
-			FMarkCurrentVerse = true;
+//			FMarkCurrentVerse = true;
 			Lines->LoadFromStream(RTFStream);
 			PlainText = true;
 			versepos = GetTextLen(); //RTFStream.Position;
 			PlainText = false;
 		}
+                newtext = newtext + "}";                
 		Module++;
 	}
 	newtext = newtext + RTFTrailer;
