@@ -8,17 +8,27 @@
 #define IDS_ACTIVEDIATHEKE_PPG_CAPTION  200
 #define IDD_PROPPAGE_ACTIVEDIATHEKE     200
 #define IDC_MAXVERSES                   205
+#define IDC_VARIANTS                    206
 #define IDC_LOCALE                      208
+#define IDC_SCRIPT                      209
 #define IDV_SEARCHTYPE                  210
 #define IDC_OUTPUTFORMAT                211
+#define IDC_OUTPUTENCODING              212
 #define IDC_KEY                         213
 #define IDC_BOOK                        214
 #define IDC_SPIN1                       215
+#define IDC_SPIN2                       216
 #define IDC_STRONGS                     217
 #define IDC_FOOTNOTES                   218
 #define IDC_HEADINGS                    219
 #define IDC_AUTOUPDATE                  220
 #define IDC_MORPHOLOGY                  221
+#define IDC_GREEKACCENTS                222
+#define IDC_HEBREWPOINTS                223
+#define IDC_HEBREWCANTILLATION          224
+#define IDC_SCRIPREF                    226
+#define IDC_ARSHAPE                     227
+#define IDC_BIDIREORDER                 228
 
 // Next default values for new objects
 // 
