@@ -33,5 +33,19 @@ int main(int argc, char **argv)
 	cout << target->StripText();
 	cout << "\n";
 	cout << "==========================\n";
+	cout << "Entry Attributes:\n\n";
+	AttributeTypeList::iterator i1;
+	AttributeList::iterator i2;
+	AttributeValue::iterator i3;
+	for (i1 = target->getEntryAttributes().begin(); i1 != target->getEntryAttributes().end(); i1++) {
+		cout << "[ " << i1->first << " ]\n";
+		for (i2 = i1->second.begin(); i2 != i1->second.end(); i2++) {
+			cout << "\t[ " << i2->first << " ]\n";
+			for (i3 = i2->second.begin(); i3 != i2->second.end(); i3++) {
+				cout << "\t\t" << i3->first << " = " << i3->second << "\n";
+			}
+		}
+	}
+	cout << endl;
 	return 0;
 }
