@@ -1,7 +1,7 @@
 /******************************************************************************
  * canon.h - Canonical text information to be included by VerseKey.cpp
  *
- * $Id: canon.h,v 1.7 2001/06/18 01:09:44 chrislit Exp $
+ * $Id: canon.h,v 1.8 2002/02/17 00:50:29 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -26,76 +26,76 @@
 
 struct sbook
   VerseKey::otbooks[] = {
-  {"Genesis", 50},
-  {"Exodus", 40},
-  {"Leviticus", 27},
-  {"Numbers", 36},
-  {"Deuteronomy", 34},
-  {"Joshua", 24},
-  {"Judges", 21},
-  {"Ruth", 4},
-  {"I Samuel", 31},
-  {"II Samuel", 24},
-  {"I Kings", 22},
-  {"II Kings", 25},
-  {"I Chronicles", 29},
-  {"II Chronicles", 36},
-  {"Ezra", 10},
-  {"Nehemiah", 13},
-  {"Esther", 10},
-  {"Job", 42},
-  {"Psalms", 150},
-  {"Proverbs", 31},
-  {"Ecclesiastes", 12},
-  {"Song of Solomon", 8},
-  {"Isaiah", 66},
-  {"Jeremiah", 52},
-  {"Lamentations", 5},
-  {"Ezekiel", 48},
-  {"Daniel", 12},
-  {"Hosea", 14},
-  {"Joel", 3},
-  {"Amos", 9},
-  {"Obadiah", 1},
-  {"Jonah", 4},
-  {"Micah", 7},
-  {"Nahum", 3},
-  {"Habakkuk", 3},
-  {"Zephaniah", 3},
-  {"Haggai", 2},
-  {"Zechariah", 14},
-  {"Malachi", 4}
+  {"Genesis", "Gen", 50},
+  {"Exodus", "Exod", 40},
+  {"Leviticus", "Lev", 27},
+  {"Numbers", "Num", 36},
+  {"Deuteronomy", "Deut", 34},
+  {"Joshua", "Josh", 24},
+  {"Judges", "Judg", 21},
+  {"Ruth", "Ruth", 4},
+  {"I Samuel", "I Sam", 31},
+  {"II Samuel", "II Sam", 24},
+  {"I Kings", "I Kin", 22},
+  {"II Kings", "II Kin", 25},
+  {"I Chronicles", "I Chr", 29},
+  {"II Chronicles", "II Chr", 36},
+  {"Ezra", "Ezra", 10},
+  {"Nehemiah", "Neh", 13},
+  {"Esther", "Esth", 10},
+  {"Job", "Job", 42},
+  {"Psalms", "Psa", 150},
+  {"Proverbs", "Prov", 31},
+  {"Ecclesiastes", "Eccl", 12},
+  {"Song of Solomon", "Song", 8},
+  {"Isaiah", "Isa", 66},
+  {"Jeremiah", "Jer", 52},
+  {"Lamentations", "Lam", 5},
+  {"Ezekiel", "Ezek", 48},
+  {"Daniel", "Dan", 12},
+  {"Hosea", "Hos", 14},
+  {"Joel", "Joel", 3},
+  {"Amos", "Amos", 9},
+  {"Obadiah", "Obad", 1},
+  {"Jonah", "Jonah", 4},
+  {"Micah", "Mic", 7},
+  {"Nahum", "Nah", 3},
+  {"Habakkuk", "Hab", 3},
+  {"Zephaniah", "Zeph", 3},
+  {"Haggai", "Hag", 2},
+  {"Zechariah", "Zech", 14},
+  {"Malachi", "Mal", 4}
 };
 
 struct sbook
   VerseKey::ntbooks[] = {
-  {"Matthew", 28},
-  {"Mark", 16},
-  {"Luke", 24},
-  {"John", 21},
-  {"Acts", 28},
-  {"Romans", 16},
-  {"I Corinthians", 16},
-  {"II Corinthians", 13},
-  {"Galatians", 6},
-  {"Ephesians", 6},
-  {"Philippians", 4},
-  {"Colossians", 4},
-  {"I Thessalonians", 5},
-  {"II Thessalonians", 3},
-  {"I Timothy", 6},
-  {"II Timothy", 4},
-  {"Titus", 3},
-  {"Philemon", 1},
-  {"Hebrews", 13},
-  {"James", 5},
-  {"I Peter", 5},
-  {"II Peter", 3},
-  {"I John", 5},
-  {"II John", 1},
-  {"III John", 1},
-  {"Jude", 1},
-  {"Revelation of John", 22}
+  {"Matthew", "Mat", 28},
+  {"Mark", "Mark", 16},
+  {"Luke", "Luke", 24},
+  {"John", "John", 21},
+  {"Acts", "Acts", 28},
+  {"Romans", "Rom", 16},
+  {"I Corinthians", "I Cor", 16},
+  {"II Corinthians", "II Cor", 13},
+  {"Galatians", "Gal", 6},
+  {"Ephesians", "Eph", 6},
+  {"Philippians", "Philip", 4},
+  {"Colossians", "Col", 4},
+  {"I Thessalonians", "I Thes", 5},
+  {"II Thessalonians", "II Thes", 3},
+  {"I Timothy", "I Tim", 6},
+  {"II Timothy", "II Tim", 4},
+  {"Titus", "Titus", 3},
+  {"Philemon", "Philem", 1},
+  {"Hebrews", "Heb", 13},
+  {"James", "Jas", 5},
+  {"I Peter", "I Pet", 5},
+  {"II Peter", "II Pet", 3},
+  {"I John", "I Jo", 5},
+  {"II John", "II Jo", 1},
+  {"III John", "III Jo", 1},
+  {"Jude", "Jude", 1},
+  {"Revelation of John", "Rev", 22}
 };
 
 
