@@ -1,6 +1,6 @@
 /*
  *
- * $Id: cipherfil.h,v 1.6 2001/02/09 15:38:51 jansorg Exp $
+ * $Id: cipherfil.h,v 1.7 2001/12/11 22:35:10 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -32,7 +32,7 @@ class SWDLLEXPORT CipherFilter:public SWFilter
 public:
     CipherFilter (const char *key);
     virtual ~ CipherFilter ();
-  virtual char ProcessText (char *text, int maxlen, const SWKey * key);
+  virtual char ProcessText (char *text, int maxlen, const SWKey * key, const SWModule * = 0);
   virtual SWCipher *getCipher ();
 };
 
