@@ -2,7 +2,7 @@
  *  echomod.h  - code for class 'EchoMod' - a test module that just echo back
  *		 text of key.
  *
- * $Id: echomod.h,v 1.1.1.1 1999/05/04 22:03:36 scribe Exp $
+ * $Id: echomod.h,v 1.2 2001/02/09 15:38:51 jansorg Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -26,11 +26,12 @@
 #include <swtext.h>
 #include <versekey.h>
 
-class EchoMod : public SWText {
+class EchoMod:public SWText
+{
 public:
-	EchoMod();
-	virtual ~EchoMod();
-	virtual operator const char*();
+  EchoMod ();
+  virtual ~ EchoMod ();
+  virtual operator const char *();
 };
 
 
