@@ -1,7 +1,7 @@
 /******************************************************************************
  *  filemgr.h   - definition of class FileMgr used for pooling file handles
  *
- * $Id: filemgr.h,v 1.10 2001/05/13 00:43:43 chrislit Exp $
+ * $Id: filemgr.h,v 1.14 2002/03/13 06:55:39 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,6 +23,7 @@
 #define FILEMGR_H
 
 #include <sys/stat.h>
+#include <fcntl.h>
 
 #include <defs.h>
 
@@ -33,18 +34,19 @@ class SWDLLEXPORT FileDesc
 
   friend class FileMgr;
 
-  char *path;
-  int mode;
-  int perms;
   long offset;
   int fd;			// -77 closed;
   FileMgr *parent;
   FileDesc *next;
 
 public:
-   FileDesc (FileMgr * parent, char *path, int mode, int perms);
+   FileDesc (FileMgr * parent, char *path, int mode, int perms, bool tryDowngrade);
    virtual ~FileDesc ();
   int getFd ();
+  char *path;
+  int mode;
+  int perms;
+  bool tryDowngrade;
 };
 
 
@@ -59,15 +61,16 @@ public:
 
     FileMgr (int maxFiles = 35);
    ~FileMgr ();
-  FileDesc *open (char *path, int mode, int perms = S_IREAD | S_IWRITE);
+  FileDesc *open (char *path, int mode, bool tryDowngrade);
+  FileDesc *open (char *path, int mode, int perms = S_IREAD | S_IWRITE, bool tryDowngrade = false);
   void close (FileDesc *);
 
-  static char existsFile (const char *ipath, const char *ifileName = 0);
-  static char existsDir (const char *ipath, const char *idirName = 0);
+  static signed char existsFile (const char *ipath, const char *ifileName = 0);
+  static signed char existsDir (const char *ipath, const char *idirName = 0);
   // to truncate a file at its current position
   // leaving byte at current possition intact
   // deleting everything afterward.
-  char trunc (FileDesc *);
+  signed char trunc (FileDesc *);
 
   int maxFiles;
   static FileMgr systemFileMgr;
