@@ -1,6 +1,6 @@
 /*
  *
- * $Id: gbfplain.h,v 1.7 2001/02/20 02:08:53 scribe Exp $
+ * $Id: gbfplain.h,v 1.8 2001/12/11 22:35:10 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -31,7 +31,7 @@ class SWDLLEXPORT GBFPlain:public SWFilter
 {
 public:
   GBFPlain ();
-  virtual char ProcessText (char *text, int maxlen, const SWKey *key);
+  virtual char ProcessText (char *text, int maxlen, const SWKey *key, const SWModule * = 0);
 };
 
 #endif
