@@ -16,8 +16,8 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Header: /usr/local/cvsroot/sword/include/plainhtml.h,v 1.6 2001/02/19 16:59:51 mgruner Exp $ */
-/* $Revision: 1.6 $ */
+/* $Header: /usr/local/cvsroot/sword/include/plainhtml.h,v 1.7 2001/12/11 22:35:10 scribe Exp $ */
+/* $Revision: 1.7 $ */
 
 #ifndef PLAINHTML_H
 #define PLAINHTML_H
@@ -32,7 +32,7 @@ class SWDLLEXPORT PLAINHTML:public SWFilter
 {
 public:
   PLAINHTML ();
-  virtual char ProcessText (char *text, int maxlen, const SWKey * key);
+  virtual char ProcessText (char *text, int maxlen, const SWKey * key, const SWModule * = 0);
 };
 
 #endif
