@@ -2,7 +2,7 @@
  *  rawcom.h   - code for class 'RawCom'- a module that reads raw commentary
  *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: rawcom.h,v 1.5 2001/06/17 21:20:08 scribe Exp $
+ * $Id: rawcom.h,v 1.14 2002/03/14 16:56:49 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -29,21 +29,27 @@
 #include <defs.h>
 
 class SWDLLEXPORT RawCom:public RawVerse, public SWCom {
-	char *versebuf;
 
 public:
   
     
 	RawCom (const char *ipath, const char *iname = 0, const char *idesc = 0,
-		SWDisplay * idisp = 0, bool unicode = false);
+		SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN, SWTextDirection dir = DIRECTION_LTR, SWTextMarkup markup = FMT_UNKNOWN,
+                const char* ilang = 0);
      virtual ~ RawCom ();
      virtual char *getRawEntry ();
 
      virtual SWModule & operator += (int increment);
-     virtual SWModule & operator -= (int decrement) {
-     	return this->operator += (-decrement);
-     }
+     virtual SWModule & operator -= (int decrement) { return this->operator += (-decrement); }
+
+	// write interface ----------------------------
+	virtual bool isWritable () { return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & O_RDWR) == O_RDWR)); }
+	static char createModule (const char *path) { return RawVerse::createModule (path); }
+	virtual SWModule & setentry (const char *inbuf, long len);	// Modify current module entry
+	virtual SWModule & operator << (const char *inbuf);	// Modify current module entry
+	virtual SWModule & operator << (const SWKey * linkKey);	// Link current module entry to other module entry
+	virtual void deleteEntry ();	// Delete current module entry
+	// end write interface ------------------------
+
 };
-
-
 #endif
