@@ -3,7 +3,7 @@
  *			pointing to actual text desired.  Uses standard
  *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: rawfiles.h,v 1.7 2001/06/17 21:20:08 scribe Exp $
+ * $Id: rawfiles.h,v 1.14 2002/03/14 16:56:49 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -31,7 +31,6 @@
 
 class SWDLLEXPORT RawFiles:public RawVerse, public SWCom
 {
-  char *versebuf;
 
   char *getnextfilename ();
 
@@ -39,7 +38,8 @@ public:
   
     
     RawFiles (const char *ipath, const char *iname = 0, const char *idesc =
-	      0, SWDisplay * idisp = 0, bool unicode = false);
+	      0, SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN, SWTextDirection dir = DIRECTION_LTR, SWTextMarkup markup = FMT_UNKNOWN,
+              const char* ilang = 0);
     virtual ~RawFiles ();
   virtual char *getRawEntry ();
 
@@ -47,9 +47,7 @@ public:
   /** Is the module writable? :)
   * @return yes or no
   */
-  virtual bool isWritable () {
-    return true;
-  }
+	virtual bool isWritable () { return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & O_RDWR) == O_RDWR)); }
   
   /** Creates a new module
   * @param path The first parameter is path of the new module
