@@ -2,7 +2,7 @@
  *  rawld.cpp - code for class 'RawLD'- a module that reads raw lexicon and
  *				dictionary files: *.dat *.idx
  *
- * $Id: rawld4.h,v 1.2 2001/06/17 21:20:08 scribe Exp $
+ * $Id: rawld4.h,v 1.9 2002/03/14 16:56:49 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -37,7 +37,8 @@ public:
   
     
     RawLD4(const char *ipath, const char *iname = 0, const char *idesc =
-	   0, SWDisplay * idisp = 0, bool unicode = false);
+	   0, SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN, SWTextDirection dir = DIRECTION_LTR, SWTextMarkup markup = FMT_UNKNOWN,
+           const char* ilang = 0);
     virtual ~RawLD4();
   virtual char *getRawEntry();
 
@@ -47,10 +48,12 @@ public:
     return this->operator +=(-decrement);
   }
   // write interface ----------------------------
-  virtual bool isWritable() { return true; }
-  static char createModule (const char *path) {
-    return RawStr4::createModule (path);
-  }
+	virtual bool isWritable () { return ((idxfd->getFd() > 0) && ((idxfd->mode & O_RDWR) == O_RDWR)); }
+	static char createModule (const char *path) {
+		return RawStr4::createModule (path);
+	}
+
+  virtual SWModule & setentry (const char *inbuf, long len);	// Modify current module entry
   virtual SWModule & operator << (const char *inbuf);	// Modify current module entry
   virtual SWModule & operator << (const SWKey * linkKey);	// Link current module entry to other module entry
   virtual void deleteEntry ();	// Delete current module entry
