@@ -4,7 +4,7 @@
  *			and provides lookup and parsing functions based on
  *			class StrKey
  *
- * $Id: rawstr.h,v 1.6 2001/02/09 15:38:51 jansorg Exp $
+ * $Id: rawstr.h,v 1.11 2002/03/13 06:55:39 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -29,28 +29,26 @@
 
 #include <defs.h>
 
-class SWDLLEXPORT RawStr
-{
-  static int instance;		// number of instantiated RawStr objects or derivitives
-  FileDesc *idxfd;
-  FileDesc *datfd;
-  char *path;
-  long lastoff;
+class SWDLLEXPORT RawStr {
+	static int instance;		// number of instantiated RawStr objects or derivitives
+	char *path;
+	long lastoff;
 
 protected:
-  void preptext (char *buf);
-  void settext (const char *key, const char *buf);
-  void linkentry (const char *destkey, const char *srckey);
+	FileDesc *idxfd;
+	FileDesc *datfd;
+	void settext(const char *key, const char *buf, long len = 0);
+	void linkentry(const char *destkey, const char *srckey);
 public:
-  char nl;
-    RawStr (const char *ipath, int fileMode = -1);
-    virtual ~ RawStr ();
-  void getidxbuf (long ioffset, char **buf);
-  void getidxbufdat (long ioffset, char **buf);
-  char findoffset (const char *key, long *start, unsigned short *size,
-		   long away = 0, long *idxoff = 0);
-  void gettext (long start, unsigned short size, char *idxbuf, char *buf);
-  static char createModule (const char *path);
+	static void preptext(char *buf);
+	static char nl;
+	RawStr(const char *ipath, int fileMode = -1);
+	virtual ~RawStr ();
+	void getidxbuf(long ioffset, char **buf);
+	void getidxbufdat(long ioffset, char **buf);
+	signed char findoffset(const char *key, long *start, unsigned short *size, long away = 0, long *idxoff = 0);
+	void gettext(long start, unsigned short size, char *idxbuf, char *buf);
+	static signed char createModule(const char *path);
 };
 
 #endif
