@@ -4,7 +4,7 @@
  *			and provides lookup and parsing functions based on
  *			class StrKey
  *
- * $Id: rawstr4.h,v 1.1 2001/05/04 22:42:13 scribe Exp $
+ * $Id: rawstr4.h,v 1.4 2002/03/13 06:55:39 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -32,14 +32,14 @@
 class SWDLLEXPORT RawStr4
 {
   static int instance;		// number of instantiated RawStr4 objects or derivitives
-  FileDesc *idxfd;
-  FileDesc *datfd;
   char *path;
   long lastoff;
 
 protected:
+  FileDesc *idxfd;
+  FileDesc *datfd;
   void preptext (char *buf);
-  void settext (const char *key, const char *buf);
+  void settext (const char *key, const char *buf, long len = 0);
   void linkentry (const char *destkey, const char *srckey);
 public:
   char nl;
@@ -47,10 +47,10 @@ public:
     virtual ~ RawStr4();
   void getidxbuf (long ioffset, char **buf);
   void getidxbufdat (long ioffset, char **buf);
-  char findoffset (const char *key, long *start, unsigned long *size,
+  signed char findoffset (const char *key, long *start, unsigned long *size,
 		   long away = 0, long *idxoff = 0);
   void gettext (long start, unsigned long size, char *idxbuf, char *buf);
-  static char createModule (const char *path);
+  static signed char createModule (const char *path);
 };
 
 #endif
