@@ -2,7 +2,7 @@
  *  swdisp.h  - code for base class 'swdisp'.  swdisp is the basis for all
  *		types of displays (e.g. raw textout, curses, xwindow, etc.)
  *
- * $Id: swdisp.h,v 1.1.1.1 1999/05/04 22:03:36 scribe Exp $
+ * $Id: swdisp.h,v 1.5 2001/03/23 22:15:14 jansorg Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,11 +23,24 @@
 #ifndef SWDISP_H
 #define SWDISP_H
 
+#include <defs.h>
+
 class SWModule;
 
-class SWDisplay {
+/** swdisp is the basis for all types of displays
+* (e.g. raw textout, curses, xwindow, etc.)
+*/
+class SWDLLEXPORT SWDisplay
+{
 public:
-	SWDisplay() {};
-	virtual char Display(SWModule &imodule);
+  SWDisplay () {};
+  /** casts a module to a character pointer and displays it to
+  * raw output (overriden for different display types and
+  * module types if necessary)
+  *
+  * @param imodule module to display
+  * @return error status
+  */
+  virtual char Display (SWModule & imodule);
 };
 #endif
