@@ -23,10 +23,15 @@
 
 #include <swfilter.h>
 
-class ThMLGBF : public SWFilter {
+#include <defs.h>
+
+  /** this filter converts ThML text to GBF text
+  */
+class SWDLLEXPORT ThMLGBF:public SWFilter
+{
 public:
-	ThMLGBF();
-	virtual char ProcessText(char *text, int maxlen = -1);
+  ThMLGBF ();
+  virtual char ProcessText (char *text, int maxlen = -1);
 };
 
 #endif
