@@ -23,15 +23,15 @@
 
 #include <swfilter.h>
 
-class ThMLPlain : public SWFilter {
+#include <defs.h>
+
+  /** this filter converts ThML text to plain text
+  */
+class SWDLLEXPORT ThMLPlain:public SWFilter
+{
 public:
-	ThMLPlain();
-	virtual char ProcessText(char *text, int maxlen = -1);
+  ThMLPlain ();
+  virtual char ProcessText (char *text, int maxlen = -1);
 };
 
 #endif
-
-
-
-
-
