@@ -1,7 +1,7 @@
 /******************************************************************************
  *  swcomprs.h   - definition of Class SWCompress used for data compression
  *
- * $Id: zipcomprs.h,v 1.1 2000/01/19 19:13:04 scribe Exp $
+ * $Id: zipcomprs.h,v 1.3 2001/02/09 15:38:51 jansorg Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,13 +24,16 @@
 
 #include <swcomprs.h>
 
-class ZipCompress : public SWCompress {
+#include <defs.h>
+
+class SWDLLEXPORT ZipCompress:public SWCompress
+{
 protected:
 public:
-	ZipCompress();
-	virtual ~ZipCompress();
-	virtual void Encode(void);
-	virtual void Decode(void);
+  ZipCompress ();
+  virtual ~ ZipCompress ();
+  virtual void Encode (void);
+  virtual void Decode (void);
 };
 
 #endif
