@@ -2,7 +2,7 @@
  *  ztext.h   - code for class 'zText'- a module that reads compressed text
  *				files: ot and nt using indexs ??.vss
  *
- * $Id: ztext.h,v 1.12 2001/06/17 21:20:08 scribe Exp $
+ * $Id: ztext.h,v 1.22 2002/03/16 04:18:34 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -34,7 +34,6 @@
 * It should not be used in frontends, unless you are doing very special things.
 */
 class SWDLLEXPORT zText:public zVerse, public SWText {
-     char *versebuf;
      VerseKey *lastWriteKey;
      bool sameBlock (VerseKey * lastWriteKey, VerseKey * key);
 	int blockType;
@@ -43,19 +42,29 @@ public:
     
 	zText(const char *ipath, const char *iname = 0, const char *idesc =
 	   0, int blockType = CHAPTERBLOCKS, SWCompress * icomp =
-	   0, SWDisplay * idisp = 0, bool unicode = false);
+	   0, SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN, SWTextDirection dir = DIRECTION_LTR, SWTextMarkup markup = FMT_UNKNOWN,
+           const char* ilang = 0);
 	virtual ~zText ();
  	virtual char *getRawEntry();
 
+     virtual SWModule & operator += (int increment);
+     virtual SWModule & operator -= (int decrement) { return this->operator += (-decrement); }
+
   // write interface ----------------------------
-	virtual bool isWritable() { return true; }
+	virtual bool isWritable () { return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & O_RDWR) == O_RDWR)); }
 	static char createModule (const char *path, int blockBound) {
 		return zVerse::createModule (path, blockBound);
 	}
+
+     virtual SWModule & setentry (const char *inbuf, long len);	// Modify current module entry
      virtual SWModule & operator << (const char *inbuf);	// Modify current module entry
      virtual SWModule & operator << (const SWKey * linkKey);	// Link current module entry to other module entry
      virtual void deleteEntry ();	// Delete current module entry
   // end write interface ------------------------
+  
+	// swcacher interface ----------------------
+	virtual void flush() { flushCache(); }
+	// end swcacher interface ----------------------
 };
 
 #endif
