@@ -2,7 +2,7 @@
 
 #include <stdarg.h>
 #include <stdio.h>
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 #include <iostream.h>
 #endif
 #include "swlog.h"
@@ -33,7 +33,7 @@ void SWLog::LogWarning(char *fmt, ...)
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 		cerr << msg;
 		cerr << "\n";
 #endif
@@ -51,7 +51,7 @@ void SWLog::LogError(char *fmt, ...)
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 		cerr << msg;
 		cerr << "\n";
 #endif
@@ -69,7 +69,7 @@ void SWLog::LogTimedInformation(char *fmt, ...)
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 		cout << msg;
 		cout << "\n";
 #endif
@@ -87,7 +87,7 @@ void SWLog::LogInformation(char *fmt, ...)
 		vsprintf(msg, fmt, argptr);
 		va_end(argptr);
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 		cout << msg;
 		cout << "\n";
 #endif
