@@ -8,7 +8,6 @@
 #include <stdio.h>
 #include <fcntl.h>
 #include <stdlib.h>
-#include <ctype.h>
 
 #ifndef __GNUC__
 #include <io.h>
@@ -16,7 +15,9 @@
 #include <unistd.h>
 #endif
 
+#include <utilstr.h>
 #include <swkey.h>
+#include <swlog.h>
 #include <versekey.h>
 #include <localemgr.h>
 extern "C" {
@@ -58,6 +59,7 @@ void VerseKey::init() {
 	book = 0;
 	chapter = 0;
 	verse = 0;
+	locale = 0;
 
 	setLocale(LocaleMgr::systemLocaleMgr.getDefaultLocaleName());
 }
@@ -111,7 +113,7 @@ VerseKey::VerseKey(const char *min, const char *max) : SWKey()
 	init();
 	LowerBound(min);
 	UpperBound(max);
-	(*this) = TOP;
+	setPosition(TOP);
 }
 
 
@@ -132,6 +134,9 @@ VerseKey::~VerseKey() {
 		delete upperBound;
 	if (lowerBound)
 		delete lowerBound;
+	if (locale)
+		delete [] locale;
+
 	--instance;
 }
 
@@ -163,6 +168,7 @@ void VerseKey::setLocale(const char *name) {
 		setBookAbbrevs(builtin_abbrevs, localeCache.abbrevsCnt);
 		localeCache.abbrevsCnt = abbrevsCnt;
 	}
+	stdstr(&(this->locale), localeCache.name);
 }
 
 
@@ -183,7 +189,15 @@ void VerseKey::setBookAbbrevs(const struct abbrev *bookAbbrevs, unsigned int siz
 			}
 			*/
 		}
-	}
+        for (int t = 0; t < 2; t++) {
+            for (int i = 0; i < BMAX[t]; i++) {
+                int bn = getBookAbbrev(books[t][i].name);
+                if ((bn-1)%39 != i) {
+                    SWLog::systemlog->LogError("Book: %s does not have a matching toupper abbrevs entry! book number returned was: %d", books[t][i].name, bn);
+                }
+            }
+        }
+    }
 	else abbrevsCnt = size;
 }
 
@@ -228,7 +242,7 @@ char VerseKey::parse()
 	if (keytext) {
 		ListKey tmpListKey = VerseKey::ParseVerseList(keytext);
 		if (tmpListKey.Count()) {
-			SWKey::operator =((const char *)tmpListKey);
+			SWKey::setText((const char *)tmpListKey);
 			for (testament = 1; testament < 3; testament++) {
 				for (book = 1; book <= BMAX[testament-1]; book++) {
 					if (!strncmp(keytext, books[testament-1][book-1].name, strlen(books[testament-1][book-1].name)))
@@ -290,14 +304,17 @@ void VerseKey::freshtext() const
  * RET:	book number or < 0 = not valid
  */
 
-int VerseKey::getBookAbbrev(char *abbr)
+int VerseKey::getBookAbbrev(const char *iabbr)
 {
-	int loop, diff, abLen, min, max, target;
+    int loop, diff, abLen, min, max, target, retVal = -1;
 
+    char *abbr = 0;
+
+	stdstr(&abbr, iabbr);
 	strstrip(abbr);
 	abLen = strlen(abbr);
 	for (loop = 0; loop < abLen; loop++)
-		abbr[loop] = toupper(abbr[loop]);
+		abbr[loop] = SW_toupper(abbr[loop]);
 
 	if (abLen) {
 		min = 0;
@@ -312,14 +329,15 @@ int VerseKey::getBookAbbrev(char *abbr)
 				min = target;
 			else	max = target;
 		}
-          for (; target > 0; target--) {
-          	if (strncmp(abbr, abbrevs[target-1].ab, abLen))
-               	break;
-          }
-               
-		return (!diff) ? abbrevs[target].book : -1;
+		for (; target > 0; target--) {
+			if (strncmp(abbr, abbrevs[target-1].ab, abLen))
+				break;
+		}
+			
+		retVal = (!diff) ? abbrevs[target].book : -1;
 	}
-	else	return -1;
+	delete [] abbr;
+	return retVal;
 }
 
 /******************************************************************************
@@ -348,6 +366,8 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 	int chap = -1, verse = -1;
 	int bookno = 0;
 	VerseKey curkey, lBound;
+	curkey.setLocale(getLocale());
+	lBound.setLocale(getLocale());
 	int loop;
 	char comma = 0;
 	char dash = 0;
@@ -391,8 +411,8 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 						continue;
 					}
 					else {
-						if ((toupper(book[loop])=='F')&&(loop)) {
-							if ((isdigit(book[loop-1])) || (book[loop-1] == ' ') || (toupper(book[loop-1]) == 'F')) {
+						if ((SW_toupper(book[loop])=='F')&&(loop)) {
+							if ((isdigit(book[loop-1])) || (book[loop-1] == ' ') || (SW_toupper(book[loop-1]) == 'F')) {
 								book[loop] = 0;
 								continue;
 							}
@@ -403,7 +423,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 
                     for (loop = strlen(book) - 1; loop+1; loop--) {
                          if (book[loop] == ' ') {
-                              if (isroman(&book[loop+1])) {
+						if (isroman(&book[loop+1])) {
                                    if (verse == -1) {
                                         verse = chap;
 								chap = from_rom(&book[loop+1]);
@@ -463,7 +483,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 				if ((*buf == '-') && (expandRange)) {	// if this is a dash save lowerBound and wait for upper
 					VerseKey newElement;
 					newElement.LowerBound(curkey);
-					newElement = TOP;
+					newElement.setPosition(TOP);
 					tmpListKey << newElement;
 				}
 				else {
@@ -472,7 +492,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 							VerseKey newElement;
 							newElement.LowerBound(curkey);
 							if (partial > 1)
-								curkey = MAXCHAPTER;
+								curkey.setPosition(MAXCHAPTER);
 							if (partial > 0)
 								curkey = MAXVERSE;
 							newElement.UpperBound(curkey);
@@ -530,7 +550,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 				}
 			}
 			if (chap == -1)
-				book[tobook++] = toupper(*buf);
+				book[tobook++] = SW_toupper(*buf);
 		}
 		buf++;
 	}
@@ -551,8 +571,8 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 				continue;
 			}
 			else {
-				if ((toupper(book[loop])=='F')&&(loop)) {
-					if ((isdigit(book[loop-1])) || (book[loop-1] == ' ') || (toupper(book[loop-1]) == 'F')) {
+				if ((SW_toupper(book[loop])=='F')&&(loop)) {
+					if ((isdigit(book[loop-1])) || (book[loop-1] == ' ') || (SW_toupper(book[loop-1]) == 'F')) {
 						book[loop] = 0;
 						continue;
 					}
@@ -571,7 +591,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
                          }
                     }
                	break;
-               }
+			}
           }
                
 		if ((!stricmp(book, "V")) || (!stricmp(book, "VER"))) {	// Verse abbrev.
@@ -783,55 +803,72 @@ void VerseKey::initBounds() const
 
 
 /******************************************************************************
- * VerseKey::operator = - Equates this VerseKey to another VerseKey
+ * VerseKey::copyFrom - Equates this VerseKey to another VerseKey
  */
 
-SWKey &VerseKey::operator =(const VerseKey &ikey)
-{
-	SWKey::operator =(ikey);
+void VerseKey::copyFrom(const VerseKey &ikey) {
+	SWKey::copyFrom(ikey);
 
 	parse();
-
-	return *this;
 }
 
 
 /******************************************************************************
- * VerseKey::operator = - Equates this VerseKey to another SWKey
+ * VerseKey::copyFrom - Equates this VerseKey to another SWKey
  */
 
-SWKey &VerseKey::operator =(const SWKey &ikey)
-{
-	SWKey::operator =(ikey);
+void VerseKey::copyFrom(const SWKey &ikey) {
+	SWKey::copyFrom(ikey);
 
 	parse();
-
-	return *this;
 }
 
 
 /******************************************************************************
- * VerseKey::operator char * - refreshes keytext before returning if cast to
+ * VerseKey::getText - refreshes keytext before returning if cast to
  *				a (char *) is requested
  */
 
-VerseKey::operator const char *() const
-{
+const char *VerseKey::getText() const {
 	freshtext();
 	return keytext;
 }
 
 
+const char *VerseKey::getShortText() const {
+	static char *stext = 0;
+	char buf[2047];
+	freshtext();
+	if (book < 1) {
+		if (testament < 1)
+			sprintf(buf, "[ Module Heading ]");
+		else sprintf(buf, "[ Testament %d Heading ]", (int)testament);
+	}
+	else {
+		sprintf(buf, "%s %d:%d", books[testament-1][book-1].prefAbbrev, chapter, verse);
+	}
+	stdstr(&stext, buf);
+	return stext;
+}
+
+
+const char *VerseKey::getBookName() const {
+	return books[testament-1][book-1].name;
+}
+
+
+const char *VerseKey::getBookAbbrev() const {
+	return books[testament-1][book-1].prefAbbrev;
+}
 /******************************************************************************
- * VerseKey::operator =(SW_POSITION)	- Positions this key
+ * VerseKey::setPosition(SW_POSITION)	- Positions this key
  *
  * ENT:	p	- position
  *
  * RET:	*this
  */
 
-SWKey &VerseKey::operator =(SW_POSITION p)
-{
+void VerseKey::setPosition(SW_POSITION p) {
 	switch (p) {
 	case POS_TOP:
 		testament = LowerBound().Testament();
@@ -857,45 +894,41 @@ SWKey &VerseKey::operator =(SW_POSITION p)
 	} 
 	Normalize(1);
 	Error();	// clear error from normalize
-	return *this;
 }
 
 
 /******************************************************************************
- * VerseKey::operator +=	- Increments key a number of verses
+ * VerseKey::increment	- Increments key a number of verses
  *
- * ENT:	increment	- Number of verses to jump forward
+ * ENT:	step	- Number of verses to jump forward
  *
  * RET: *this
  */
 
-SWKey &VerseKey::operator += (int increment)
-{
+void VerseKey::increment(int step) {
 	char ierror = 0;
-	Index(Index() + increment);
+	Index(Index() + step);
 	while ((!verse) && (!headings) && (!ierror)) {
 		Index(Index() + 1);
 		ierror = Error();
 	}
 
 	error = (ierror) ? ierror : error;
-	return *this;
 }
 
 
 /******************************************************************************
- * VerseKey::operator -=	- Decrements key a number of verses
+ * VerseKey::decrement	- Decrements key a number of verses
  *
- * ENT:	decrement	- Number of verses to jump backward
+ * ENT:	step	- Number of verses to jump backward
  *
  * RET: *this
  */
 
-SWKey &VerseKey::operator -= (int decrement)
-{
+void VerseKey::decrement(int step) {
 	char ierror = 0;
 
-	Index(Index() - decrement);
+	Index(Index() - step);
 	while ((!verse) && (!headings) && (!ierror)) {
 		Index(Index() - 1);
 		ierror = Error();
@@ -904,7 +937,6 @@ SWKey &VerseKey::operator -= (int decrement)
 		(*this)++;
 
 	error = (ierror) ? ierror : error;
-	return *this;
 }
 
 
