@@ -2,7 +2,7 @@
  *  filemgr.cpp	- implementation of class FileMgr used for pooling file
  *  					handles
  *
- * $Id: filemgr.cpp,v 1.16 2001/05/11 05:50:24 chrislit Exp $
+ * $Id: filemgr.cpp,v 1.21 2002/03/16 17:34:41 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -41,12 +41,13 @@ FileMgr FileMgr::systemFileMgr;
 // --------------- end statics --------------
 
 
-FileDesc::FileDesc(FileMgr *parent, char *path, int mode, int perms) {
+FileDesc::FileDesc(FileMgr *parent, char *path, int mode, int perms, bool tryDowngrade) {
 	this->parent = parent;
 	this->path = 0;
 	stdstr(&this->path, path);
 	this->mode = mode;
 	this->perms = perms;
+	this->tryDowngrade = tryDowngrade;
 	offset = 0;
 	fd = -77;
 }
@@ -85,7 +86,11 @@ FileMgr::~FileMgr() {
 }
 
 
-FileDesc *FileMgr::open(char *path, int mode, int perms) {
+FileDesc *FileMgr::open(char *path, int mode, bool tryDowngrade) {
+	return open(path, mode, S_IREAD | S_IWRITE, tryDowngrade);
+}
+
+FileDesc *FileMgr::open(char *path, int mode, int perms, bool tryDowngrade) {
 	FileDesc **tmp, *tmp2;
 	
 	for (tmp = &files; *tmp; tmp = &((*tmp)->next)) {
@@ -93,7 +98,7 @@ FileDesc *FileMgr::open(char *path, int mode, int perms) {
 			break;
 	}
 
-	tmp2 = new FileDesc(this, path, mode, perms);
+	tmp2 = new FileDesc(this, path, mode, perms, tryDowngrade);
 	tmp2->next = *tmp;
 	*tmp = tmp2;
 	
@@ -117,7 +122,7 @@ void FileMgr::close(FileDesc *file) {
 // to truncate a file at its current position
 // leaving byte at current possition intact
 // deleting everything afterward.
-char FileMgr::trunc(FileDesc *file) {
+signed char FileMgr::trunc(FileDesc *file) {
 
 	static const char *writeTest = "x";
 	long size = lseek(file->getFd(), 1, SEEK_CUR);
@@ -192,27 +197,35 @@ int FileMgr::sysOpen(FileDesc *file) {
 				file->next = files;
 				files = file;
 			}
-               if ((!access(file->path, 04)) || (file->mode & O_CREAT == O_CREAT)) {	// check for at least file exists / read access before we try to open
-				file->fd = ::open(file->path, file->mode, file->perms);
-			        if (file->fd >= 0)
+			if ((!access(file->path, 04)) || ((file->mode & O_CREAT) == O_CREAT)) {	// check for at least file exists / read access before we try to open
+				char tries = (((file->mode & O_RDWR) == O_RDWR) && (file->tryDowngrade)) ? 2 : 1;  // try read/write if possible
+				for (int i = 0; i < tries; i++) {
+					if (i > 0) {
+						file->mode = (file->mode & ~O_RDWR);	// remove write access
+						file->mode = (file->mode | O_RDONLY);// add read access
+					}
+					file->fd = ::open(file->path, file->mode, file->perms);
+
+					if (file->fd >= 0)
+						break;
+				}
+
+				if (file->fd >= 0)
 					lseek(file->fd, file->offset, SEEK_SET);
-               }
-               else file->fd = -1;
-               if (!*loop)
-                  break;
+			}
+			else file->fd = -1;
+			if (!*loop)
+				break;
 		}
 	}
 	return file->fd;
 }
 
 
-char FileMgr::existsFile(const char *ipath, const char *ifileName)
+signed char FileMgr::existsFile(const char *ipath, const char *ifileName)
 {
-	int len = strlen(ipath) + ((ifileName)?strlen(ifileName):0) + 1;
+	int len = strlen(ipath) + ((ifileName)?strlen(ifileName):0) + 3;
 	char *ch;
-
-	if (ifileName)
-		len +=  strlen(ifileName);
 	char *path = new char [ len ];
 	strcpy(path, ipath);
 	
@@ -223,13 +236,13 @@ char FileMgr::existsFile(const char *ipath, const char *ifileName)
 		ch = path + strlen(path);
 		sprintf(ch, "/%s", ifileName);
 	}
-	char retVal = !access(path, 04);
-    delete [] path;
-    return retVal;
+	signed char retVal = !access(path, 04);
+	delete [] path;
+	return retVal;
 }
 
 
-char FileMgr::existsDir(const char *ipath, const char *idirName)
+signed char FileMgr::existsDir(const char *ipath, const char *idirName)
 {
 	char *ch;
 	int len = strlen(ipath) + ((idirName)?strlen(idirName):0) + 1;
@@ -245,7 +258,7 @@ char FileMgr::existsDir(const char *ipath, const char *idirName)
 		ch = path + strlen(path);
 		sprintf(ch, "/%s", idirName);
 	}
-	char retVal = !access(path, 04);
+	signed char retVal = !access(path, 04);
      delete [] path;
      return retVal;
 }
