@@ -2,7 +2,7 @@
  *  swmgr.cpp   - implementaion of class SWMgr used to interact with an install
  *				base of sword modules.
  *
- * $Id: swmgr.cpp,v 1.41 2001/06/17 21:20:08 scribe Exp $
+ * $Id: swmgr.cpp,v 1.70 2002/03/22 05:26:34 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -20,7 +20,6 @@
  *
  */
 
-#include <dirent.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
@@ -32,12 +31,14 @@
 #include <unixstr.h>
 #endif
 #include <sys/stat.h>
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 #include <iostream.h>
 #endif
+#include <dirent.h>
+
 #include <swmgr.h>
 #include <rawtext.h>
-#include <rawgbf.h>
+#include <rawgenbook.h>
 #include <rawcom.h>
 #include <hrefcom.h>
 #include <rawld.h>
@@ -49,11 +50,29 @@
 #include <gbffootnotes.h>
 #include <gbfheadings.h>
 #include <gbfmorph.h>
+#include <thmlstrongs.h>
+#include <thmlfootnotes.h>
+#include <thmlheadings.h>
+#include <thmlmorph.h>
+#include <thmllemma.h>
+#include <thmlscripref.h>
 #include <cipherfil.h>
 #include <rawfiles.h>
 #include <ztext.h>
+#include <zld.h>
 #include <zcom.h>
 #include <lzsscomprs.h>
+#include <utf8greekaccents.h>
+#include <utf8cantillation.h>
+#include <utf8hebrewpoints.h>
+#include <greeklexattribs.h>
+#include <swfiltermgr.h>
+
+
+
+#ifdef ICU
+#include <utf8transliterator.h>
+#endif
 
 #ifndef EXCLUDEZLIB
 #include <zipcomprs.h>
@@ -61,6 +80,12 @@
 
 bool SWMgr::debug = false;
 
+#ifdef GLOBCONFPATH
+const char *SWMgr::globalConfPath = GLOBCONFPATH;
+#else
+const char *SWMgr::globalConfPath = "/etc/sword.conf:/usr/local/etc/sword.conf";
+#endif
+
 void SWMgr::init() {
 	SWFilter *tmpFilter = 0;
 	configPath  = 0;
@@ -68,6 +93,8 @@ void SWMgr::init() {
 	configType  = 0;
 	myconfig    = 0;
 	mysysconfig = 0;
+	homeConfig = 0;
+
 
 	cipherFilters.clear();
 	optionFilters.clear();
@@ -89,6 +116,53 @@ void SWMgr::init() {
 	optionFilters.insert(FilterMap::value_type("GBFHeadings", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
+	tmpFilter = new ThMLStrongs();
+	optionFilters.insert(FilterMap::value_type("ThMLStrongs", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new ThMLFootnotes();
+	optionFilters.insert(FilterMap::value_type("ThMLFootnotes", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new ThMLMorph();
+	optionFilters.insert(FilterMap::value_type("ThMLMorph", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new ThMLHeadings();
+	optionFilters.insert(FilterMap::value_type("ThMLHeadings", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new ThMLLemma();
+	optionFilters.insert(FilterMap::value_type("ThMLLemma", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new ThMLScripref();
+	optionFilters.insert(FilterMap::value_type("ThMLScripref", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new UTF8GreekAccents();
+	optionFilters.insert(FilterMap::value_type("UTF8GreekAccents", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new UTF8HebrewPoints();
+	optionFilters.insert(FilterMap::value_type("UTF8HebrewPoints", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new UTF8Cantillation();
+	optionFilters.insert(FilterMap::value_type("UTF8Cantillation", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new GreekLexAttribs();
+	optionFilters.insert(FilterMap::value_type("GreekLexAttribs", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+/* UTF8Transliterator needs to be handled differently because it should always available as an option, for all modules
+#ifdef ICU
+	tmpFilter = new UTF8Transliterator();
+	optionFilters.insert(FilterMap::value_type("UTF8Transliterator", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+#endif
+*/
 	gbfplain = new GBFPlain();
 	cleanupFilters.push_back(gbfplain);
 
@@ -97,7 +171,20 @@ void SWMgr::init() {
 }
 
 
-SWMgr::SWMgr(SWConfig *iconfig, SWConfig *isysconfig, bool autoload) {
+SWMgr::SWMgr(SWFilterMgr *filterMgr) {
+	commonInit(0, 0, true, filterMgr);
+}
+
+
+SWMgr::SWMgr(SWConfig *iconfig, SWConfig *isysconfig, bool autoload, SWFilterMgr *filterMgr) {
+	commonInit(iconfig, isysconfig, autoload, filterMgr);
+}
+
+
+void SWMgr::commonInit(SWConfig * iconfig, SWConfig * isysconfig, bool autoload, SWFilterMgr *filterMgr) {
+	this->filterMgr = filterMgr;
+	if (filterMgr)
+		filterMgr->setParentMgr(this);
 
 	init();
 	
@@ -117,10 +204,14 @@ SWMgr::SWMgr(SWConfig *iconfig, SWConfig *isysconfig, bool autoload) {
 }
 
 
-SWMgr::SWMgr(const char *iConfigPath, bool autoload) {
+SWMgr::SWMgr(const char *iConfigPath, bool autoload, SWFilterMgr *filterMgr) {
 
 	string path;
 	
+	this->filterMgr = filterMgr;
+	if (filterMgr)
+		filterMgr->setParentMgr(this);
+
 	init();
 	
 	path = iConfigPath;
@@ -155,6 +246,9 @@ SWMgr::~SWMgr() {
 	for (FilterList::iterator it = cleanupFilters.begin(); it != cleanupFilters.end(); it++)
 		delete (*it);
 			
+	if (homeConfig)
+		delete homeConfig;
+
 	if (myconfig)
 		delete myconfig;
 
@@ -163,6 +257,9 @@ SWMgr::~SWMgr() {
 
 	if (configPath)
 		delete [] configPath;
+
+	if (filterMgr)
+		delete filterMgr;
 }
 
 
@@ -175,7 +272,7 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath) {
 
 	*configType = 0;
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 	// check working directory
 if (debug)
 	cerr << "Checking working directory for mods.conf...";
@@ -183,7 +280,7 @@ if (debug)
 
 	if (FileMgr::existsFile(".", "mods.conf")) {
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "found\n";
 #endif
@@ -193,14 +290,14 @@ if (debug)
 		return;
 	}
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "\nChecking working directory for mods.d...";
 #endif
 
 	if (FileMgr::existsDir(".", "mods.d")) {
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "found\n";
 #endif
@@ -213,14 +310,14 @@ if (debug)
 
 
 	// check environment variable SWORD_PATH
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "\nChecking SWORD_PATH...";
 #endif
 
 	if (envsworddir != NULL) {
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "found (" << envsworddir << ")\n";
 #endif
@@ -229,14 +326,14 @@ if (debug)
 		if ((envsworddir[strlen(envsworddir)-1] != '\\') && (envsworddir[strlen(envsworddir)-1] != '/'))
 			path += "/";
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "\nChecking $SWORD_PATH for mods.conf...";
 #endif
 
 		if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "found\n";
 #endif
@@ -247,14 +344,14 @@ if (debug)
 			return;
 		}
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "\nChecking $SWORD_PATH for mods.d...";
 #endif
 
 		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "found\n";
 #endif
@@ -268,38 +365,52 @@ if (debug)
 	}
 
 
-	// check for systemwide /etc/sword.conf
+	// check for systemwide globalConfPath
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
-	cerr << "\nChecking for /etc/sword.conf...";
+	cerr << "\nParsing " << globalConfPath << "...";
 #endif
 
-	if (!::access("/etc/sword.conf", 04)) {
+	char *globPaths = 0;
+	char *gfp;
+	stdstr(&globPaths, globalConfPath);
+	for (gfp = strtok(globPaths, ":"); gfp; gfp = strtok(0, ":")) {
 
-#ifndef __VISUALC__
+	#ifndef _MSC_VER
+if (debug)
+	cerr << "\nChecking for " << gfp << "...";
+#endif
+
+		if (FileMgr::existsFile(gfp))
+			break;
+	}
+
+	if (gfp) {
+
+#ifndef _MSC_VER
 if (debug)
 	cerr << "found\n";
 #endif
 
-		SWConfig etcconf("/etc/sword.conf");
+		SWConfig etcconf(gfp);
 		if ((entry = etcconf.Sections["Install"].find("DataPath")) != etcconf.Sections["Install"].end()) {
 			path = (*entry).second;
 			if (((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '\\') && ((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '/'))
 				path += "/";
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
-	cerr << "DataPath in /etc/sword.conf is set to: " << path;
+	cerr << "DataPath in " << gfp << " is set to: " << path;
 #endif
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "\nChecking for mods.conf in DataPath ";
 #endif
 			if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "found\n";
 #endif
@@ -307,17 +418,18 @@ if (debug)
 				stdstr(prefixPath, path.c_str());
 				path += "mods.conf";
 				stdstr(configPath, path.c_str());
+				delete [] globPaths;
 				return;
 			}
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "\nChecking for mods.d in DataPath ";
 #endif
 
 			if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "found\n";
 #endif
@@ -326,15 +438,17 @@ if (debug)
 				path += "mods.d";
 				stdstr(configPath, path.c_str());
 				*configType = 1;
+				delete [] globPaths;
 				return;
 			}
 		}
 	}
 
+	delete [] globPaths;
 
 	// check ~/.sword/
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "\nChecking home directory for ~/.sword/mods.conf" << path;
 #endif
@@ -346,30 +460,30 @@ if (debug)
 		path += ".sword/";
 		if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
-	cerr << "found\n";
+	cerr << " found\n";
 #endif
 
-			stdstr(prefixPath, "");
+			stdstr(prefixPath, path.c_str());
 			path += "mods.conf";
 			stdstr(configPath, path.c_str());
 			return;
 		}
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "\nChecking home directory for ~/.sword/mods.d" << path;
 #endif
 
 		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 if (debug)
 	cerr << "found\n";
 #endif
 
-			stdstr(prefixPath, "");
+			stdstr(prefixPath, path.c_str());
 			path += "mods.d";
 			stdstr(configPath, path.c_str());
 			*configType = 2;
@@ -412,7 +526,16 @@ void SWMgr::loadConfigDir(const char *ipath)
 }
 
 
-void SWMgr::Load() {
+/***********************************************************************
+ * SWMgr::Load - loads actual modules
+ *
+ * RET: status - 0 = ok; -1 no config found; 1 = no modules installed
+ *
+ */
+
+signed char SWMgr::Load() {
+	signed char ret = 0;
+
 	if (!config) {	// If we weren't passed a config object at construction, find a config file
 		if (!configPath)	// If we weren't passed a config path at construction...
 			findConfig(&configType, &prefixPath, &configPath);
@@ -469,36 +592,35 @@ void SWMgr::Load() {
 					stdstr(&configPath, saveConfigPath);
 					delete []saveConfigPath;
 					(*saveConfig) += *config;
-					delete myconfig;
+					homeConfig = myconfig;
 					config = myconfig = saveConfig;
 				}
 			}
 // -------------------------------------------------------------------------
+		if ( !Modules.size() ) // config exists, but no modules
+			ret = 1;
 
 	}
 	else {
 		SWLog::systemlog->LogError("SWMgr: Can't find 'mods.conf' or 'mods.d'.  Try setting:\n\tSWORD_PATH=<directory containing mods.conf>\n\tOr see the README file for a full description of setup options (%s)", (configPath) ? configPath : "<configPath is null>");
-#ifndef WIN32
-		throw "SWMgr: Can't find 'mods.conf' or 'mods.d' .  Try setting:\n\tSWORD_PATH=<directory containing mods.conf>\n\tOr see the README file for a full description of setup options";
-#else
-		exit(-1);
-#endif
+		ret = -1;
 	}
-}
 
+	return ret;
+}
 
 SWModule *SWMgr::CreateMod(string name, string driver, ConfigEntMap &section)
 {
 	string description, datapath, misc1;
 	ConfigEntMap::iterator entry;
 	SWModule *newmod = 0;
- 	string sourceformat;
- 	string encoding;
-     bool unicode = false;
+ 	string lang, sourceformat, encoding;
+        signed char direction, enc, markup;
 
-	sourceformat = ((entry = section.find("SourceType"))  != section.end()) ? (*entry).second : (string)"";
-	encoding = ((entry = section.find("Encoding"))  != section.end()) ? (*entry).second : (string)"";
 	description  = ((entry = section.find("Description")) != section.end()) ? (*entry).second : (string)"";
+	lang  = ((entry = section.find("Lang")) != section.end()) ? (*entry).second : (string)"en";
+ 	sourceformat = ((entry = section.find("SourceType"))  != section.end()) ? (*entry).second : (string)"";
+ 	encoding = ((entry = section.find("Encoding"))  != section.end()) ? (*entry).second : (string)"";
 	datapath = prefixPath;
 	if ((prefixPath[strlen(prefixPath)-1] != '\\') && (prefixPath[strlen(prefixPath)-1] != '/'))
 		datapath += "/";
@@ -511,9 +633,36 @@ SWModule *SWMgr::CreateMod(string name, string driver, ConfigEntMap &section)
 	if (*buf2)
 		datapath += buf2;
 	delete [] buf;
-	
-    	if ((!stricmp(sourceformat.c_str(), "PlainUnicode")) || (!stricmp(encoding.c_str(), "UTF-8")))
-     	unicode = true;
+
+	section["AbsoluteDataPath"] = datapath;
+
+        if (!stricmp(sourceformat.c_str(), "GBF"))
+                markup = FMT_GBF;
+        else if (!stricmp(sourceformat.c_str(), "ThML"))
+                markup = FMT_THML;
+        else if (!stricmp(sourceformat.c_str(), "OSIS"))
+                markup = FMT_OSIS;
+        else
+                markup = FMT_PLAIN;
+
+    	if (!stricmp(encoding.c_str(), "SCSU"))
+                enc = ENC_SCSU;
+        else if (!stricmp(encoding.c_str(), "UTF-8"))
+                enc = ENC_UTF8;
+        else enc = ENC_LATIN1;
+
+	if ((entry = section.find("Direction")) == section.end()) {
+                direction = DIRECTION_LTR;
+        }
+        else if (!stricmp((*entry).second.c_str(), "rtol")) {
+                direction = DIRECTION_RTL;
+        }
+        else if (!stricmp((*entry).second.c_str(), "bidi")) {
+                direction = DIRECTION_BIDI;
+        }
+        else {
+                direction = DIRECTION_LTR;
+        }
 
 	if ((!stricmp(driver.c_str(), "zText")) || (!stricmp(driver.c_str(), "zCom"))) {
 		SWCompress *compress = 0;
@@ -534,52 +683,76 @@ SWModule *SWMgr::CreateMod(string name, string driver, ConfigEntMap &section)
 #endif
 		if (!stricmp(misc1.c_str(), "LZSS"))
 			compress = new LZSSCompress();
-		
+
 		if (compress) {
 			if (!stricmp(driver.c_str(), "zText"))
-				newmod = new zText(datapath.c_str(), name.c_str(), description.c_str(), blockType, compress, 0, unicode);
-			else	newmod = new zCom(datapath.c_str(), name.c_str(), description.c_str(), blockType, compress, 0, unicode);
+				newmod = new zText(datapath.c_str(), name.c_str(), description.c_str(), blockType, compress, 0, enc, direction, markup, lang.c_str());
+			else	newmod = new zCom(datapath.c_str(), name.c_str(), description.c_str(), blockType, compress, 0, enc, direction, markup, lang.c_str());
 		}
 	}
-	
+
 	if (!stricmp(driver.c_str(), "RawText")) {
-		newmod = new RawText(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
+		newmod = new RawText(datapath.c_str(), name.c_str(), description.c_str(), 0, enc, direction, markup, lang.c_str());
 	}
-	
+
 	// backward support old drivers
 	if (!stricmp(driver.c_str(), "RawGBF")) {
-		newmod = new RawText(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
+		newmod = new RawText(datapath.c_str(), name.c_str(), description.c_str(), 0, enc, direction, markup, lang.c_str());
 	}
 
 	if (!stricmp(driver.c_str(), "RawCom")) {
-		newmod = new RawCom(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
+		newmod = new RawCom(datapath.c_str(), name.c_str(), description.c_str(), 0, enc, direction, markup, lang.c_str());
 	}
-				
+
 	if (!stricmp(driver.c_str(), "RawFiles")) {
-		newmod = new RawFiles(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
+		newmod = new RawFiles(datapath.c_str(), name.c_str(), description.c_str(), 0, enc, direction, markup, lang.c_str());
 	}
-				
+
 	if (!stricmp(driver.c_str(), "HREFCom")) {
 		misc1 = ((entry = section.find("Prefix")) != section.end()) ? (*entry).second : (string)"";
 		newmod = new HREFCom(datapath.c_str(), misc1.c_str(), name.c_str(), description.c_str());
 	}
-				
+
 	if (!stricmp(driver.c_str(), "RawLD"))
-		newmod = new RawLD(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
+		newmod = new RawLD(datapath.c_str(), name.c_str(), description.c_str(), 0, enc, direction, markup, lang.c_str());
 
 	if (!stricmp(driver.c_str(), "RawLD4"))
-		newmod = new RawLD4(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
+		newmod = new RawLD4(datapath.c_str(), name.c_str(), description.c_str(), 0, enc, direction, markup, lang.c_str());
 
+	if (!stricmp(driver.c_str(), "zLD")) {
+		SWCompress *compress = 0;
+		int blockCount;
+		misc1 = ((entry = section.find("BlockCount")) != section.end()) ? (*entry).second : (string)"200";
+		blockCount = atoi(misc1.c_str());
+		blockCount = (blockCount) ? blockCount : 200;
+
+		misc1 = ((entry = section.find("CompressType")) != section.end()) ? (*entry).second : (string)"LZSS";
+#ifndef EXCLUDEZLIB
+		if (!stricmp(misc1.c_str(), "ZIP"))
+			compress = new ZipCompress();
+		else
+#endif
+		if (!stricmp(misc1.c_str(), "LZSS"))
+			compress = new LZSSCompress();
+
+		if (compress) {
+			newmod = new zLD(datapath.c_str(), name.c_str(), description.c_str(), blockCount, compress, 0, enc, direction, markup, lang.c_str());
+		}
+	}
+
+	if (!stricmp(driver.c_str(), "RawGenBook")) {
+		newmod = new RawGenBook(datapath.c_str(), name.c_str(), description.c_str(), 0, enc, direction, markup, lang.c_str());
+	}
     // if a specific module type is set in the config, use this
-    if ((entry = section.find("Type")) != section.end()) 
+    if ((entry = section.find("Type")) != section.end())
         newmod->Type(entry->second.c_str());
 
+     newmod->setConfig(&section);
 	return newmod;
 }
 
 
-void SWMgr::AddGlobalOptions(SWModule *module, ConfigEntMap &section, ConfigEntMap::iterator start, ConfigEntMap::iterator end)
-{
+void SWMgr::AddGlobalOptions(SWModule *module, ConfigEntMap &section, ConfigEntMap::iterator start, ConfigEntMap::iterator end) {
 	for (;start != end; start++) {
 		FilterMap::iterator it;
 		it = optionFilters.find((*start).second);
@@ -594,14 +767,23 @@ void SWMgr::AddGlobalOptions(SWModule *module, ConfigEntMap &section, ConfigEntM
 				options.push_back((*it).second->getOptionName());
 		}
 	}
+	if (filterMgr)
+		filterMgr->AddGlobalOptions(module, section, start, end);
 }
 
 
 void SWMgr::AddLocalOptions(SWModule *module, ConfigEntMap &section, ConfigEntMap::iterator start, ConfigEntMap::iterator end)
 {
 	for (;start != end; start++) {
-		printf("%s:%s\n", module->Name(), (*start).second.c_str());
+		FilterMap::iterator it;
+		it = optionFilters.find((*start).second);
+		if (it != optionFilters.end()) {
+			module->AddOptionFilter((*it).second);	// add filter to module
+		}
 	}
+
+	if (filterMgr)
+		filterMgr->AddLocalOptions(module, section, start, end);
 }
 
 
@@ -616,6 +798,16 @@ void SWMgr::AddRawFilters(SWModule *module, ConfigEntMap &section) {
 		cleanupFilters.push_back(cipherFilter);
 		module->AddRawFilter(cipherFilter);
 	}
+
+	if (filterMgr)
+		filterMgr->AddRawFilters(module, section);
+}
+
+
+void SWMgr::AddEncodingFilters(SWModule *module, ConfigEntMap &section) {
+
+	if (filterMgr)
+		filterMgr->AddEncodingFilters(module, section);
 }
 
 
@@ -626,6 +818,7 @@ void SWMgr::AddRenderFilters(SWModule *module, ConfigEntMap &section) {
 	sourceformat = ((entry = section.find("SourceType")) != section.end()) ? (*entry).second : (string)"";
 
 	// Temporary: To support old module types
+        // TODO: Remove at 1.6.0 release?
 	if (sourceformat.empty()) {
 		sourceformat = ((entry = section.find("ModDrv")) != section.end()) ? (*entry).second : (string)"";
 		if (!stricmp(sourceformat.c_str(), "RawGBF"))
@@ -638,6 +831,9 @@ void SWMgr::AddRenderFilters(SWModule *module, ConfigEntMap &section) {
 //		module->AddRenderFilter(gbftortf);
 //	}
 
+	if (filterMgr)
+		filterMgr->AddRenderFilters(module, section);
+
 }
 
 
@@ -658,9 +854,13 @@ void SWMgr::AddStripFilters(SWModule *module, ConfigEntMap &section)
 	if (!stricmp(sourceformat.c_str(), "GBF")) {
 		module->AddStripFilter(gbfplain);
 	}
-	if (!stricmp(sourceformat.c_str(), "ThML")) {
+	else if (!stricmp(sourceformat.c_str(), "ThML")) {
 		module->AddStripFilter(thmlplain);
 	}
+
+	if (filterMgr)
+		filterMgr->AddStripFilters(module, section);
+
 }
 
 
@@ -690,6 +890,7 @@ void SWMgr::CreateMods() {
 				AddRawFilters(newmod, section);
 				AddStripFilters(newmod, section);
 				AddRenderFilters(newmod, section);
+				AddEncodingFilters(newmod, section);
 				
 				Modules.insert(ModMap::value_type(newmod->Name(), newmod));
 			}
@@ -705,7 +906,7 @@ void SWMgr::DeleteMods() {
 	for (it = Modules.begin(); it != Modules.end(); it++)
 		delete (*it).second;
 
-	Modules.erase(Modules.begin(), Modules.end());
+	Modules.clear();
 }
 
 
@@ -775,8 +976,10 @@ char SWMgr::AddModToConfig(int conffd, const char *fname)
 void SWMgr::setGlobalOption(const char *option, const char *value)
 {
 	for (FilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
-		if (!stricmp(option, (*it).second->getOptionName()))
-			(*it).second->setOptionValue(value);
+		if ((*it).second->getOptionName()) {
+			if (!stricmp(option, (*it).second->getOptionName()))
+				(*it).second->setOptionValue(value);
+		}
 	}
 }
 
@@ -784,8 +987,10 @@ void SWMgr::setGlobalOption(const char *option, const char *value)
 const char *SWMgr::getGlobalOption(const char *option)
 {
 	for (FilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
-		if (!stricmp(option, (*it).second->getOptionName()))
-			return (*it).second->getOptionValue();
+		if ((*it).second->getOptionName()) {
+			if (!stricmp(option, (*it).second->getOptionName()))
+				return (*it).second->getOptionValue();
+		}
 	}
 	return 0;
 }
@@ -794,8 +999,10 @@ const char *SWMgr::getGlobalOption(const char *option)
 const char *SWMgr::getGlobalOptionTip(const char *option)
 {
 	for (FilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
-		if (!stricmp(option, (*it).second->getOptionName()))
-			return (*it).second->getOptionTip();
+		if ((*it).second->getOptionName()) {
+			if (!stricmp(option, (*it).second->getOptionName()))
+				return (*it).second->getOptionTip();
+		}
 	}
 	return 0;
 }
@@ -811,16 +1018,18 @@ OptionsList SWMgr::getGlobalOptionValues(const char *option)
 {
 	OptionsList options;
 	for (FilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
-		if (!stricmp(option, (*it).second->getOptionName())) {
-			options = (*it).second->getOptionValues();
-			break;	// just find the first one.  All option filters with the same option name should expect the same values
+		if ((*it).second->getOptionName()) {
+			if (!stricmp(option, (*it).second->getOptionName())) {
+				options = (*it).second->getOptionValues();
+				break;	// just find the first one.  All option filters with the same option name should expect the same values
+			}
 		}
 	}
 	return options;
 }
 
 
-char SWMgr::setCipherKey(const char *modName, const char *key) {
+signed char SWMgr::setCipherKey(const char *modName, const char *key) {
 	FilterMap::iterator it;
 	ModMap::iterator it2;
 
