@@ -31,10 +31,9 @@
  *		idisp - Display object to use for displaying
  */
 
-zCom::zCom(const char *ipath, const char *iname, const char *idesc, int iblockType, SWCompress *icomp, SWDisplay *idisp, bool unicode) : zVerse(ipath, -1, iblockType, icomp), SWCom(iname, idesc, idisp, unicode)/*, SWCompress()*/
+zCom::zCom(const char *ipath, const char *iname, const char *idesc, int iblockType, SWCompress *icomp, SWDisplay *idisp, SWTextEncoding enc, SWTextDirection dir, SWTextMarkup mark, const char* ilang) : zVerse(ipath, -1, iblockType, icomp), SWCom(iname, idesc, idisp, enc, dir, mark, ilang)/*, SWCompress()*/
 {
 	blockType = iblockType;
-	versebuf = 0;
 	lastWriteKey = 0;
 }
 
@@ -45,9 +44,6 @@ zCom::zCom(const char *ipath, const char *iname, const char *idesc, int iblockTy
 zCom::~zCom() {
 	flushCache();
 
-	if (versebuf)
-		delete [] versebuf;
-
 	if (lastWriteKey)
 		delete lastWriteKey;
 }
@@ -78,22 +74,26 @@ char *zCom::getRawEntry() {
 	findoffset(key->Testament(), key->Index(), &start, &size);
 	entrySize = size;        // support getEntrySize call
 
-	if (versebuf)
-		delete [] versebuf;
-	versebuf = new char [ (size + 2) * FILTERPAD * ((unicode) ? 9 : 1 ) ];
-	*versebuf = 0;
+	unsigned long newsize = (size + 2) * FILTERPAD;
+	if (newsize > entrybufallocsize) {
+		if (entrybuf)
+			delete [] entrybuf;
+		entrybuf = new char [ newsize ];
+		entrybufallocsize = newsize;
+	}
+	*entrybuf = 0;
 
-	swgettext(key->Testament(), start, (size + 2), versebuf);
+	swgettext(key->Testament(), start, (size + 2), entrybuf);
 
-	rawFilter(versebuf, size, key);
+	rawFilter(entrybuf, size, key);
 
-	if (!unicode)
-		preptext(versebuf);
+	if (!isUnicode())
+		preptext(entrybuf);
 
 	if (this->key != key) // free our key if we created a VerseKey
 		delete key;
 
-	return versebuf;
+	return entrybuf;
 }
 
 
@@ -115,8 +115,7 @@ bool zCom::sameBlock(VerseKey *k1, VerseKey *k2) {
 	return true;
 }
 
-
-SWModule &zCom::operator <<(const char *inbuf) {
+SWModule &zCom::setentry(const char *inbuf, long len) {
 	VerseKey *key = 0;
 	// see if we have a VerseKey * or decendant
 #ifndef _WIN32_WCE
@@ -140,7 +139,7 @@ SWModule &zCom::operator <<(const char *inbuf) {
 		delete lastWriteKey;
 	}
 
-	settext(key->Testament(), key->Index(), inbuf);
+	settext(key->Testament(), key->Index(), inbuf, len);
 
 	lastWriteKey = (VerseKey *)key->clone();	// must delete
 
@@ -150,6 +149,10 @@ SWModule &zCom::operator <<(const char *inbuf) {
 	return *this;
 }
 
+SWModule &zCom::operator <<(const char *inbuf) {
+        return setentry(inbuf, 0);
+}
+
 
 SWModule &zCom::operator <<(const SWKey *inkey) {
 	VerseKey *destkey = 0;
@@ -246,6 +249,7 @@ SWModule &zCom::operator +=(int increment) {
 
 	findoffset(tmpkey->Testament(), tmpkey->Index(), &start, &size);
 
+	SWKey lastgood = *tmpkey;
 	while (increment) {
 		long laststart = start;
 		unsigned short lastsize = size;
@@ -266,12 +270,15 @@ SWModule &zCom::operator +=(int increment) {
 			tmpkey = new VerseKey(key);
 
 		if ((error = key->Error())) {
-			*key = lasttry;
+			*key = lastgood;
 			break;
 		}
-		findoffset(tmpkey->Testament(), tmpkey->Index(), &start, &size);
-		if (((laststart != start) || (lastsize != size)) && (start >= 0) && (size)) 
+		long index = tmpkey->Index();
+		findoffset(tmpkey->Testament(), index, &start, &size);
+		if ((((laststart != start) || (lastsize != size))||(!skipConsecutiveLinks)) && (start >= 0) && (size)) {
 			increment += (increment < 0) ? 1 : -1;
+			lastgood = *tmpkey;
+		}
 	}
 	error = (error) ? KEYERR_OUTOFBOUNDS : 0;
 
