@@ -5,8 +5,6 @@
  *				class StrKey
  */
 
-
-#include <ctype.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -21,14 +19,8 @@
 #include <stdlib.h>
 #include <utilfuns.h>
 #include <rawstr4.h>
+#include <sysdata.h>
 
-#ifdef BIGENDIAN
-#ifndef MACOSX
-#include <sys/pctypes.h>
-#else
-#include <architecture/byte_order.h>
-#endif
-#endif
 /******************************************************************************
  * RawStr Statics
  */
@@ -47,7 +39,6 @@ int RawStr4::instance = 0;
 RawStr4::RawStr4(const char *ipath, int fileMode)
 {
 	char buf[127];
-	char tries = 1;
 
 	nl = '\n';
 	lastoff = -1;
@@ -60,19 +51,13 @@ RawStr4::RawStr4(const char *ipath, int fileMode)
 
 	if (fileMode == -1) { // try read/write if possible
 		fileMode = O_RDWR;
-		tries = 2;
 	}
 		
-	for (int i = 0; i < tries; i++) {
-		sprintf(buf, "%s.idx", path);
-		idxfd = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
+	sprintf(buf, "%s.idx", path);
+	idxfd = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 
-		sprintf(buf, "%s.dat", path);
-		datfd = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
-
-		if (idxfd->getFd() >= 0)
-			break;
-	}
+	sprintf(buf, "%s.dat", path);
+	datfd = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 
 	if (datfd < 0) {
 		sprintf(buf, "Error: %d", errno);
@@ -125,7 +110,7 @@ void RawStr4::getidxbufdat(long ioffset, char **buf)
 		}
 		(*buf)[size] = 0;
 		for (size--; size > 0; size--)
-			(*buf)[size] = toupper((*buf)[size]);
+			(*buf)[size] = SW_toupper((*buf)[size]);
 	}
 	else {
 		*buf = (*buf) ? (char *)realloc(*buf, 1) : (char *)malloc(1);
@@ -151,13 +136,9 @@ void RawStr4::getidxbuf(long ioffset, char **buf)
 	if (idxfd > 0) {
 		lseek(idxfd->getFd(), ioffset, SEEK_SET);
 		read(idxfd->getFd(), &offset, 4);
-#ifdef BIGENDIAN
-	#ifndef MACOSX
-		offset = lelong(offset);
-	#else
-		offset = NXSwapLittleLongToHost(offset);
-	#endif
-#endif
+
+		offset = swordtoarch32(offset);
+
 		getidxbufdat(offset, buf);
 		for (trybuf = targetbuf = *buf; *trybuf; trybuf++, targetbuf++) {
 /*
@@ -166,7 +147,7 @@ void RawStr4::getidxbuf(long ioffset, char **buf)
 				continue;
 			}
 */
-			*targetbuf = toupper(*trybuf);
+			*targetbuf = SW_toupper(*trybuf);
 		}
 		*targetbuf = 0;
 		trybuf = 0;
@@ -186,9 +167,10 @@ void RawStr4::getidxbuf(long ioffset, char **buf)
  * RET: error status
  */
 
-char RawStr4::findoffset(const char *ikey, long *start, unsigned long *size, long away, long *idxoff)
+signed char RawStr4::findoffset(const char *ikey, long *start, unsigned long *size, long away, long *idxoff)
 {
-	char *trybuf, *targetbuf, *key, quitflag = 0, retval = 0;
+	char *trybuf, *targetbuf, *key, quitflag = 0;
+        signed char retval = 0;
 	long headoff, tailoff, tryoff = 0, maxoff = 0;
 
 	if (idxfd->getFd() >=0) {
@@ -206,7 +188,7 @@ char RawStr4::findoffset(const char *ikey, long *start, unsigned long *size, lon
 					continue;
 				}
 	*/
-				*targetbuf = toupper(*trybuf);
+				*targetbuf = SW_toupper(*trybuf);
 			}
 			*targetbuf = 0;
 			trybuf = 0;
@@ -250,23 +232,21 @@ char RawStr4::findoffset(const char *ikey, long *start, unsigned long *size, lon
 		if (idxoff)
 			*idxoff = tryoff;
 
-	#ifdef BIGENDIAN
-		#ifndef MACOSX
-			*start = lelong(*start);
-			*size  = lelong(*size);
-		#else
-			*start = NXSwapLittleLongToHost(*start);
-			*size  = NXSwapLittleLongToHost(*size);
-		#endif
-	#endif
+		*start = swordtoarch32(*start);
+		*size  = swordtoarch32(*size);
 
 		while (away) {
 			long laststart = *start;
 			unsigned long lastsize = *size;
 			long lasttry = tryoff;
 			tryoff += (away > 0) ? 8 : -8;
-		
-			if ((lseek(idxfd->getFd(), tryoff, SEEK_SET) < 0) || ((tryoff + (away*8)) < -8) || (tryoff + (away*8) > (maxoff+8))) {
+
+			bool bad = false;
+			if (((tryoff + (away*8)) < -8) || (tryoff + (away*8) > (maxoff+8)))
+				bad = true;
+			else if (lseek(idxfd->getFd(), tryoff, SEEK_SET) < 0)
+				bad = true;
+			if (bad) {
 				retval = -1;
 				*start = laststart;
 				*size = lastsize;
@@ -280,15 +260,8 @@ char RawStr4::findoffset(const char *ikey, long *start, unsigned long *size, lon
 			if (idxoff)
 				*idxoff = tryoff;
 
-	#ifdef BIGENDIAN
-		#ifndef MACOSX
-			*start = lelong(*start);
-			*size  = lelong(*size);
-		#else
-			*start = NXSwapLittleLongToHost(*start);
-			*size  = NXSwapLittleLongToHost(*size);
-		#endif
-	#endif
+			*start = swordtoarch32(*start);
+			*size  = swordtoarch32(*size);
 
 			if (((laststart != *start) || (lastsize != *size)) && (*start >= 0) && (*size)) 
 				away += (away < 0) ? 1 : -1;
@@ -424,9 +397,10 @@ void RawStr4::gettext(long istart, unsigned long isize, char *idxbuf, char *buf)
  *
  * ENT: key	- key for this entry
  *	buf	- buffer to store
+ *      len     - length of buffer (0 - null terminated)
  */
 
-void RawStr4::settext(const char *ikey, const char *buf)
+void RawStr4::settext(const char *ikey, const char *buf, long len)
 {
 
 	long start, outstart;
@@ -446,7 +420,7 @@ void RawStr4::settext(const char *ikey, const char *buf)
 	findoffset(ikey, &start, &size, 0, &idxoff);
 	stdstr(&key, ikey);
 	for (ch = key; *ch; ch++)
-		*ch = toupper(*ch);
+		*ch = SW_toupper(*ch);
 	ch = 0;
 
 	getidxbufdat(start, &dbKey);
@@ -455,7 +429,7 @@ void RawStr4::settext(const char *ikey, const char *buf)
 	}
 	else if (strcmp(key, dbKey) > 0) {
 		idxoff += 8;
-	} else if ((!strcmp(key, dbKey)) && (strlen(buf) /*we're not deleting*/)) { // got absolute entry
+	} else if ((!strcmp(key, dbKey)) && (len || strlen(buf) /*we're not deleting*/)) { // got absolute entry
 		do {
 			tmpbuf = new char [ size + 2 ];
 			memset(tmpbuf, 0, size + 2);
@@ -471,7 +445,7 @@ void RawStr4::settext(const char *ikey, const char *buf)
 			memmove(tmpbuf, ch, size - (unsigned long)(ch-tmpbuf));
 
 			// resolve link
-			if (!strncmp(tmpbuf, "@LINK", 5) && strlen(buf)) {
+			if (!strncmp(tmpbuf, "@LINK", 5) && (len ? len : strlen(buf))) {
 				for (ch = tmpbuf; *ch; ch++) {		// null before nl
 					if (*ch == 10) {
 						*ch = 0;
@@ -495,22 +469,19 @@ void RawStr4::settext(const char *ikey, const char *buf)
 		read(idxfd->getFd(), idxBytes, shiftSize);
 	}
 
-	outbuf = new char [ strlen(buf) + strlen(key) + 5 ];
-	sprintf(outbuf, "%s%c%c%s", key, 13, 10, buf);
-	size = outsize = strlen(outbuf);
+	outbuf = new char [ (len ? len : strlen(buf)) + strlen(key) + 5 ];
+	sprintf(outbuf, "%s%c%c", key, 13, 10);
+	size = strlen(outbuf);
+	memcpy (outbuf + size, buf, len ? len : strlen(buf));
+	size = outsize = size + (len ? len : strlen(buf));
 
 	start = outstart = lseek(datfd->getFd(), 0, SEEK_END);
-#ifdef BIGENDIAN
-	#ifndef MACOSX
-		outstart = lelong(start);
-		outsize  = lelong(size);
-	#else
-		outstart = NXSwapLittleLongToHost(start);
-		outsize  = NXSwapLittleLongToHost(size);
-	#endif
-#endif
+
+	outstart = archtosword32(start);
+	outsize  = archtosword32(size);
+
 	lseek(idxfd->getFd(), idxoff, SEEK_SET);
-	if (strlen(buf)) {
+	if (len ? len : strlen(buf)) {
 		lseek(datfd->getFd(), start, SEEK_SET);
 		write(datfd->getFd(), outbuf, (long)size);
 
@@ -562,7 +533,7 @@ void RawStr4::linkentry(const char *destkey, const char *srckey) {
  * RET: error status
  */
 
-char RawStr4::createModule(const char *ipath)
+signed char RawStr4::createModule(const char *ipath)
 {
 	char *path = 0;
 	char *buf = new char [ strlen (ipath) + 20 ];
