@@ -22,19 +22,13 @@
 #include <utilfuns.h>
 #include <rawverse.h>
 #include <versekey.h>
-
-#ifdef BIGENDIAN
-#ifndef MACOSX
-#include <sys/pctypes.h>
-#else
-#include <architecture/byte_order.h>
-#endif
-#endif
+#include <sysdata.h>
 
 #ifndef O_BINARY		// O_BINARY is needed in Borland C++ 4.53
 #define O_BINARY 0		// If it hasn't been defined than we probably
 #endif				// don't need it.
 
+
 /******************************************************************************
  * RawVerse Statics
  */
@@ -53,7 +47,6 @@
 RawVerse::RawVerse(const char *ipath, int fileMode)
 {
 	char *buf;
-	int tries = 1;
 
 	nl = '\n';
 	path = 0;
@@ -64,24 +57,20 @@ RawVerse::RawVerse(const char *ipath, int fileMode)
 
 	if (fileMode == -1) { // try read/write if possible
 		fileMode = O_RDWR;
-		tries = 2;
 	}
 		
-	for (int i = 0; i < tries; i++) {
-		sprintf(buf, "%s/ot.vss", path);
-		idxfp[0] = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
+	sprintf(buf, "%s/ot.vss", path);
+	idxfp[0] = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 
-		sprintf(buf, "%s/nt.vss", path);
-		idxfp[1] = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
+	sprintf(buf, "%s/nt.vss", path);
+	idxfp[1] = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 
-		sprintf(buf, "%s/ot", path);
-		textfp[0] = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
+	sprintf(buf, "%s/ot", path);
+	textfp[0] = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
+
+	sprintf(buf, "%s/nt", path);
+	textfp[1] = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 
-		sprintf(buf, "%s/nt", path);
-		textfp[1] = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
-		if ((idxfp[0]->getFd() >= 0) || (idxfp[1]->getFd() >= 0))
-			break;
-	}
 	delete [] buf;
 	instance++;
 }
@@ -125,17 +114,12 @@ void RawVerse::findoffset(char testmt, long idxoff, long *start, unsigned short
 		lseek(idxfp[testmt-1]->getFd(), idxoff, SEEK_SET);
 		read(idxfp[testmt-1]->getFd(), start, 4);
 		long len = read(idxfp[testmt-1]->getFd(), size, 2); 		// read size
-#ifdef BIGENDIAN
-	#ifndef MACOSX
-		*start = lelong(*start);
-		*size  = leshort(*size);
-	#else
-		*start = NXSwapLittleLongToHost(*start);
-		*size  = NXSwapLittleShortToHost(*size);
-	#endif
-#endif
+
+		*start = swordtoarch32(*start);
+		*size  = swordtoarch16(*size);
+
 		if (len < 2) {
-			*size = (unsigned short)(lseek(textfp[testmt-1]->getFd(), 0, SEEK_END) - (long)start);	// if for some reason we get an error reading size, make size to end of file
+			*size = (unsigned short)((*start) ? (lseek(textfp[testmt-1]->getFd(), 0, SEEK_END) - (long)*start) : 0);	// if for some reason we get an error reading size, make size to end of file
 		}
 	}
 	else {
@@ -213,7 +197,7 @@ void RawVerse::preptext(char *buf)
  */
 
 void RawVerse::gettext(char testmt, long start, unsigned short size, char *buf) {
-	memset(buf, 0, size);
+	memset(buf, 0, size+1);
 	if (size) {
 		if (textfp[testmt-1]->getFd() >= 0) {
 			lseek(textfp[testmt-1]->getFd(), start, SEEK_SET);
@@ -229,9 +213,10 @@ void RawVerse::gettext(char testmt, long start, unsigned short size, char *buf)
  * ENT: testmt	- testament to find (0 - Bible/module introduction)
  *	idxoff	- offset into .vss
  *	buf	- buffer to store
+ *      len     - length of buffer (0 - null terminated)
  */
 
-void RawVerse::settext(char testmt, long idxoff, const char *buf)
+void RawVerse::settext(char testmt, long idxoff, const char *buf, long len)
 {
 	long start, outstart;
 	unsigned short size;
@@ -242,19 +227,11 @@ void RawVerse::settext(char testmt, long idxoff, const char *buf)
 	if (!testmt)
 		testmt = ((idxfp[1]) ? 1:2);
 
-	size = outsize = strlen(buf);
+	size = outsize = len ? len : strlen(buf);
 
 	start = outstart = lseek(textfp[testmt-1]->getFd(), 0, SEEK_END);
 	lseek(idxfp[testmt-1]->getFd(), idxoff, SEEK_SET);
-#ifdef BIGENDIAN
-	#ifndef MACOSX
-		outstart = lelong(start);
-		outsize  = leshort(size);
-	#else
-		outstart = NXSwapLittleLongToHost(start);
-		outsize  = NXSwapLittleShortToHost(size);
-	#endif
-#endif
+
 	if (size) {
 		lseek(textfp[testmt-1]->getFd(), start, SEEK_SET);
 		write(textfp[testmt-1]->getFd(), buf, (int)size);
@@ -263,8 +240,12 @@ void RawVerse::settext(char testmt, long idxoff, const char *buf)
 		write(textfp[testmt-1]->getFd(), &nl, 2);
 	}
 	else {
-		outstart = outsize = 0;
+		start = 0;
 	}
+
+	outstart = archtosword32(start);
+	outsize  = archtosword16(size);
+
 	write(idxfp[testmt-1]->getFd(), &outstart, 4);
 	write(idxfp[testmt-1]->getFd(), &outsize, 2);
 
