@@ -22,9 +22,7 @@
 #include <utilfuns.h>
 #include <versekey.h>
 #include <zverse.h>
-
-// remove
-//#include <lzsscomprs.h>
+#include <sysdata.h>
 
 
 #ifndef O_BINARY
@@ -53,7 +51,6 @@ const char zVerse::uniqueIndexID[] = {'X', 'r', 'v', 'c', 'b'};
 zVerse::zVerse(const char *ipath, int fileMode, int blockType, SWCompress *icomp)
 {
 	char buf[127];
-	int tries = 1;
 
 	nl = '\n';
 	path = 0;
@@ -70,30 +67,25 @@ zVerse::zVerse(const char *ipath, int fileMode, int blockType, SWCompress *icomp
 
 	if (fileMode == -1) { // try read/write if possible
 		fileMode = O_RDWR;
-		tries = 2;
 	}
 		
-	for (int i = 0; i < tries; i++) {
-		sprintf(buf, "%s/ot.%czs", path, uniqueIndexID[blockType]);
-		idxfp[0] = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
+	sprintf(buf, "%s/ot.%czs", path, uniqueIndexID[blockType]);
+	idxfp[0] = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 
-		sprintf(buf, "%s/nt.%czs", path, uniqueIndexID[blockType]);
-		idxfp[1] = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
+	sprintf(buf, "%s/nt.%czs", path, uniqueIndexID[blockType]);
+	idxfp[1] = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 
-		sprintf(buf, "%s/ot.%czz", path, uniqueIndexID[blockType]);
-		textfp[0] = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
+	sprintf(buf, "%s/ot.%czz", path, uniqueIndexID[blockType]);
+	textfp[0] = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 
-		sprintf(buf, "%s/nt.%czz", path, uniqueIndexID[blockType]);
-		textfp[1] = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
+	sprintf(buf, "%s/nt.%czz", path, uniqueIndexID[blockType]);
+	textfp[1] = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 
-		sprintf(buf, "%s/ot.%czv", path, uniqueIndexID[blockType]);
-		compfp[0] = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
+	sprintf(buf, "%s/ot.%czv", path, uniqueIndexID[blockType]);
+	compfp[0] = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 
-		sprintf(buf, "%s/nt.%czv", path, uniqueIndexID[blockType]);
-		compfp[1] = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
-		if ((idxfp[0]->getFd() >= 0) || (idxfp[1]->getFd() >= 0))
-			break;
-	}
+	sprintf(buf, "%s/nt.%czv", path, uniqueIndexID[blockType]);
+	compfp[1] = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
 	
 	instance++;
 }
@@ -143,17 +135,6 @@ zVerse::~zVerse()
 
 void zVerse::findoffset(char testmt, long idxoff, long *start, unsigned short *size)
 {
-	/*
-	idxoff *= 6;
-	if (!testmt)
-		testmt = ((idxfp[1]) ? 1:2);
-
-	lseek(idxfp[testmt-1]->getFd(), idxoff, SEEK_SET);
-	read(idxfp[testmt-1]->getFd(), start, 4);
-	if (read(idxfp[testmt-1]->getFd(), size, 2) < 2) { 		// read size
-		*size = (unsigned short)(lseek(textfp[testmt-1]->getFd(), 0, SEEK_END) - (long)start);	// if for some reason we get an error reading size, make size to end of file
-	}
-	 */
 	// set start to offset in
 	// set size to
 	// set
@@ -165,23 +146,27 @@ void zVerse::findoffset(char testmt, long idxoff, long *start, unsigned short *s
 	unsigned long ulUnCompSize=0;	          // buffer size uncompressed
 	char *pcCompText=NULL;					 // compressed text
 
-
+	*start = *size = 0;
 	//printf ("Finding offset %ld\n", idxoff);
 	idxoff *= 10;
 	if (!testmt) {
 		testmt = ((idxfp[0]) ? 1:2);
 	}
-     
-     // assert we have and valid file descriptor
-     if (compfp[testmt-1]->getFd() < 1)
-     	return;
-          
-	lseek(compfp[testmt-1]->getFd(), idxoff, SEEK_SET);
-	if (read(compfp[testmt-1]->getFd(), &ulBuffNum, 4) < 4)
-	{
-		printf ("Error reading ulBuffNum\n");
+	
+	// assert we have and valid file descriptor
+	if (compfp[testmt-1]->getFd() < 1)
 		return;
+		
+	long newOffset = lseek(compfp[testmt-1]->getFd(), idxoff, SEEK_SET);
+	if (newOffset == idxoff) {
+		if (read(compfp[testmt-1]->getFd(), &ulBuffNum, 4) != 4) {
+			printf ("Error reading ulBuffNum\n");
+			return;
+		}
 	}
+	else return;
+
+	ulBuffNum = swordtoarch32(ulBuffNum);
 
 	if (read(compfp[testmt-1]->getFd(), &ulVerseStart, 4) < 2)
 	{
@@ -193,8 +178,10 @@ void zVerse::findoffset(char testmt, long idxoff, long *start, unsigned short *s
 		printf ("Error reading usVerseSize\n");
 		return;
 	}
-	*start = ulVerseStart;
-	*size = usVerseSize;
+
+	*start = swordtoarch32(ulVerseStart);
+	*size = swordtoarch16(usVerseSize);
+
 	if (*size) {
 		if (((long) ulBuffNum == cacheBufIdx) && (testmt == cacheTestament) && (cacheBuf)) {
 			// have the text buffered
@@ -203,6 +190,7 @@ void zVerse::findoffset(char testmt, long idxoff, long *start, unsigned short *s
 
 		//printf ("Got buffer number{%ld} versestart{%ld} versesize{%d}\n", ulBuffNum, ulVerseStart, usVerseSize);
 
+
 		if (lseek(idxfp[testmt-1]->getFd(), ulBuffNum*12, SEEK_SET)!=(long) ulBuffNum*12)
 		{
 			printf ("Error seeking compressed file index\n");
@@ -224,12 +212,17 @@ void zVerse::findoffset(char testmt, long idxoff, long *start, unsigned short *s
 			return;
 		}
 
+		ulCompOffset  = swordtoarch32(ulCompOffset);
+		ulCompSize  = swordtoarch32(ulCompSize);
+		ulUnCompSize  = swordtoarch32(ulUnCompSize);
+
 		if (lseek(textfp[testmt-1]->getFd(), ulCompOffset, SEEK_SET)!=(long)ulCompOffset)
 		{
 			printf ("Error: could not seek to right place in compressed text\n");
 			return;
 		}
 		pcCompText = new char[ulCompSize];
+
 		if (read(textfp[testmt-1]->getFd(), pcCompText, ulCompSize)<(long)ulCompSize)
 		{
 			printf ("Error reading compressed text\n");
@@ -241,8 +234,11 @@ void zVerse::findoffset(char testmt, long idxoff, long *start, unsigned short *s
 			flushCache();
 			free(cacheBuf);
 		}
-		cacheBuf = (char *)calloc(strlen(compressor->Buf()) + 1, 1);
-		strcpy(cacheBuf, compressor->Buf());
+		
+		unsigned long len = 0;
+		compressor->Buf(0, &len);
+		cacheBuf = (char *)calloc(len + 1, 1);
+		memcpy(cacheBuf, compressor->Buf(), len);
 
 		cacheTestament = testmt;
 		cacheBufIdx = ulBuffNum;
@@ -275,18 +271,19 @@ void zVerse::swgettext(char testmt, long start, unsigned short size, char *inbuf
  * ENT: testmt	- testament to find (0 - Bible/module introduction)
  *	idxoff	- offset into .vss
  *	buf	- buffer to store
+ *      len     - length of buffer (0 - null terminated)
  */
 
-void zVerse::settext(char testmt, long idxoff, const char *buf)
+void zVerse::settext(char testmt, long idxoff, const char *buf, long len)
 {
 	if ((!dirtyCache) || (cacheBufIdx < 0)) {
 		cacheBufIdx = lseek(idxfp[testmt-1]->getFd(), 0, SEEK_END) / 12;
 		cacheTestament = testmt;
 		if (cacheBuf)
 			free(cacheBuf);
-		cacheBuf = (char *)calloc(strlen(buf)+1, 1);
+		cacheBuf = (char *)calloc(len ? len : strlen(buf)+1, 1);
 	}
-	else cacheBuf = (char *)((cacheBuf)?realloc(cacheBuf, strlen(cacheBuf)+strlen(buf)+1):calloc(strlen(buf)+1, 1));
+	else cacheBuf = (char *)((cacheBuf)?realloc(cacheBuf, strlen(cacheBuf)+(len ? len : strlen(buf)+1)):calloc((len ? len : strlen(buf)+1), 1));
 
 	dirtyCache = true;
 
@@ -296,23 +293,17 @@ void zVerse::settext(char testmt, long idxoff, const char *buf)
 	unsigned short outsize;
 
 	idxoff *= 10;
-	size = outsize = strlen(buf);
+	size = outsize = len ? len : strlen(buf);
+
+	start = strlen(cacheBuf);
+
+	if (!size)
+		start = outBufIdx = 0;
+
+	outBufIdx = archtosword32(outBufIdx);
+	outstart  = archtosword32(start);
+	outsize   = archtosword16(size);
 
-	start = outstart = strlen(cacheBuf);
-#ifdef BIGENDIAN
-	#ifndef MACOSX
-		outBufIdx = lelong(outBufIdx);
-		outstart  = lelong(start);
-		outsize   = leshort(size);
-	#else
-		outBufIdx = NXSwapLittleLongToHost(outBufIdx);
-		outstart  = NXSwapLittleLongToHost(start);
-		outsize   = NXSwapLittleShortToHost(size);
-	#endif
-#endif
-	if (!size) {
-		outstart = outsize = outBufIdx = 0;
-	}
 	lseek(compfp[testmt-1]->getFd(), idxoff, SEEK_SET);
 	write(compfp[testmt-1]->getFd(), &outBufIdx, 4);
 	write(compfp[testmt-1]->getFd(), &outstart, 4);
@@ -340,17 +331,11 @@ void zVerse::flushCache() {
 			outzsize = zsize;
 
 			start = outstart = lseek(textfp[cacheTestament-1]->getFd(), 0, SEEK_END);
-	#ifdef BIGENDIAN
-		#ifndef MACOSX
-			outstart  = lelong(start);
-			outsize   = lelong(size);
-			outzsize  = lelong(zsize);
-		#else
-			outstart  = NXSwapLittleLongToHost(start);
-			outsize   = NXSwapLittleLongToHost(size);
-			outzsize  = NXSwapLittleLongToHost(zsize);
-		#endif
-	#endif
+
+			outstart  = archtosword32(start);
+			outsize   = archtosword32(size);
+			outzsize  = archtosword32(zsize);
+
 			write(textfp[cacheTestament-1]->getFd(), compressor->zBuf(&zsize), zsize);
 
 			lseek(idxfp[cacheTestament-1]->getFd(), idxoff, SEEK_SET);
