@@ -17,7 +17,7 @@
 const char GBFHeadings::on[] = "On";
 const char GBFHeadings::off[] = "Off";
 const char GBFHeadings::optName[] = "Headings";
-const char GBFHeadings::optTip[] = "Toggles Headings On and Off In Bible Texts If They Exist";
+const char GBFHeadings::optTip[] = "Toggles Headings On and Off if they exist";
 
 
 GBFHeadings::GBFHeadings() {
@@ -40,7 +40,7 @@ const char *GBFHeadings::getOptionValue()
 	return (option) ? on:off;
 }
 
-char GBFHeadings::ProcessText(char *text, int maxlen, const SWKey *key)
+char GBFHeadings::ProcessText(char *text, int maxlen, const SWKey *key, const SWModule *module)
 {
 	if (!option) {	// if we don't want headings
 		char *to, *from, token[2048]; // cheese.  Fix.
@@ -60,7 +60,10 @@ char GBFHeadings::ProcessText(char *text, int maxlen, const SWKey *key)
 			if (*from == '<') {
 				intoken = true;
 				tokpos = 0;
-				memset(token, 0, 2048);
+//				memset(token, 0, 2048);
+				token[0] = 0;
+				token[1] = 0;
+				token[2] = 0;
 				continue;
 			}
 			if (*from == '>') {	// process tokens
@@ -80,15 +83,16 @@ char GBFHeadings::ProcessText(char *text, int maxlen, const SWKey *key)
 				// if not a heading token, keep token in text
 				if (!hide) {
 					*to++ = '<';
-					for (unsigned int i = 0; i < strlen(token); i++)
-						*to++ = token[i];
+					for (char *tok = token; *tok; tok++)
+						*to++ = *tok;
 					*to++ = '>';
 				}
 				continue;
 			}
 			if (intoken) {
-				if (tokpos < 2047)
+				if (tokpos < 2045)
 					token[tokpos++] = *from;
+					token[tokpos+2] = 0;
 			}
 			else	{
 				if (!hide) {
