@@ -17,7 +17,7 @@
 const char GBFMorph::on[] = "On";
 const char GBFMorph::off[] = "Off";
 const char GBFMorph::optName[] = "Morphological Tags";
-const char GBFMorph::optTip[] = "Toggles Morphological Tags On and Off In Bible Texts If They Exist";
+const char GBFMorph::optTip[] = "Toggles Morphological Tags On and Off if they exist";
 
 
 GBFMorph::GBFMorph() {
@@ -40,7 +40,7 @@ const char *GBFMorph::getOptionValue()
 	return (option) ? on:off;
 }
 
-char GBFMorph::ProcessText(char *text, int maxlen, const SWKey *key)
+char GBFMorph::ProcessText(char *text, int maxlen, const SWKey *key, const SWModule *module)
 {
 	if (!option) {	// if we don't want morph tags
 		char *to, *from, token[2048]; // cheese.  Fix.
@@ -60,7 +60,9 @@ char GBFMorph::ProcessText(char *text, int maxlen, const SWKey *key)
 			if (*from == '<') {
 				intoken = true;
 				tokpos = 0;
-				memset(token, 0, 2048);
+				token[0] = 0;
+				token[1] = 0;
+				token[2] = 0;
 				continue;
 			}
 			if (*from == '>') {	// process tokens
@@ -74,14 +76,15 @@ char GBFMorph::ProcessText(char *text, int maxlen, const SWKey *key)
 				}
 				// if not a morph tag token, keep token in text
 				*to++ = '<';
-				for (unsigned int i = 0; i < strlen(token); i++)
-					*to++ = token[i];
+				for (char *tok = token; *tok; tok++)
+					*to++ = *tok;
 				*to++ = '>';
 				continue;
 			}
 			if (intoken) {
-				if (tokpos < 2047)
+				if (tokpos < 2045)
 					token[tokpos++] = *from;
+					token[tokpos+2] = 0;
 			}
 			else	{
 				*to++ = *from;
