@@ -13,14 +13,14 @@ GBFRTF::GBFRTF() {
 }
 
 
-char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
+char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModule *module)
 {
 	unsigned char *to, *from;
 	char token[2048];
 	int tokpos = 0;
 	bool intoken = false;
 	int len;
-	unsigned int i;
+	const char *tok;
 
 	len = strlen(text) + 1;						// shift string to right of buffer
 	if (len < maxlen) {
@@ -32,7 +32,9 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 		if (*from == '<') {
 			intoken = true;
 			tokpos = 0;
-			memset(token, 0, 2048);
+			token[0] = 0;
+			token[1] = 0;
+			token[2] = 0;
 			continue;
 		}
 		if (*from == '>') {
@@ -51,8 +53,8 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 					*to++ = '7';
 					*to++ = ' ';
 					*to++ = '<';
-					for (i = 2; i < strlen(token); i++)
-						*to++ = token[i];
+					for (tok = token + 2; *tok; tok++)
+						*to++ = *tok;
 					*to++ = '>';
 					*to++ = '}';
 					continue;
@@ -67,29 +69,29 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 					*to++ = ' ';
 					*to++ = '(';
 					bool separate = false;
-					for (i = 2; i < strlen(token); i++) {
+					for (tok = token + 2; *tok; tok++) {
 						if (separate) {
 							*to++ = ';';
 							*to++ = ' ';
 							separate = false;
 						}
-						switch (token[i]) {
+						switch (*tok) {
 						case 'G':
 						case 'H':
-							for (i++; i < strlen(token); i++) {
-								if (isdigit(token[i])) {
-									*to++ = token[i];
+							for (tok++; *tok; tok++) {
+								if (isdigit(*tok)) {
+									*to++ = *tok;
 									separate = true;
 								}
 								else {
-									i--;
+									tok--;
 									break;
 								}
 							}
 							break;
 						default:
-							for (; i < strlen(token); i++) {
-							       *to++ = token[i];
+							for (; *tok; tok++) {
+							       *to++ = *tok;
 							}
 						}
 					}
@@ -100,6 +102,12 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 				break;
 			case 'R':
 				switch(token[1]) {
+				case 'X':
+				  *to++ = '#';
+				  continue;
+				case 'x':
+				  *to++ = '|';
+				  continue;
 				case 'F':               // footnote begin
 					*to++ = '{';
 					*to++ = '\\';
@@ -257,8 +265,9 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 			continue;
 		}
 		if (intoken) {
-			if (tokpos < 2047)
+			if (tokpos < 2045)
 				token[tokpos++] = *from;
+				token[tokpos+2] = 0;
 		}
 		else	*to++ = *from;
 	}
