@@ -30,8 +30,8 @@ char GBFThML::ProcessText(char *text, int maxlen)
 	int tokpos = 0;
 	bool intoken 	= false;
 	int len;
-	unsigned int i;
-	
+	const char *tok;
+
 	len = strlen(text) + 1;						// shift string to right of buffer
 	if (len < maxlen) {
 		memmove(&text[maxlen - len], text, len);
@@ -44,7 +44,9 @@ char GBFThML::ProcessText(char *text, int maxlen)
 		if (*from == '<') {
 			intoken = true;
 			tokpos = 0;
-			memset(token, 0, 20);
+			token[0] = 0;
+			token[1] = 0;
+			token[2] = 0;
 			continue;
 		}
 		if (*from == '>')
@@ -84,8 +86,8 @@ char GBFThML::ProcessText(char *text, int maxlen)
 			    *to++ = 'e';
 			    *to++ = '=';
 			    *to++ = '"';
-			    for (i = 1; i < strlen(token); i++)
-			      *to++ = token[i];
+			    for (tok = token + 1; *tok; tok++)
+			      *to++ = *tok;
 			    *to++ = '"';
 			    *to++ = ' ';
 			    *to++ = '/';
@@ -119,8 +121,8 @@ char GBFThML::ProcessText(char *text, int maxlen)
 			    *to++ = 'e';
 			    *to++ = '=';
 			    *to++ = '"';
-			    for (i = 2; i < strlen(token); i++)
-			      *to++ = token[i];
+			    for (tok = token + 2; *tok; tok++)
+			      *to++ = *tok;
 			    *to++ = '"';
 			    *to++ = ' ';
 			    *to++ = '/';
@@ -131,6 +133,33 @@ char GBFThML::ProcessText(char *text, int maxlen)
 			case 'R':
 			  switch(token[1])
 			    {
+			    case 'X':
+			      *to++ = '<';
+			      *to++ = 'a';
+			      *to++ = ' ';
+			      *to++ = 'h';
+			      *to++ = 'r';
+			      *to++ = 'e';
+			      *to++ = 'f';
+			      *to++ = '=';
+			      *to++ = '\"';
+			      for (tok = token + 3; *tok; tok++) {
+				if(*tok != '<' && *tok+1 != 'R' && *tok+2 != 'x') {
+				  *to++ = *tok;
+				}
+				else {
+				  break;
+				}
+			      }
+			      *to++ = '\"';
+			      *to++ = '>';
+			      continue;
+			    case 'x':
+			      *to++ = '<';
+			      *to++ = '/';
+			      *to++ = 'a';
+			      *to++ = '>';
+			      continue;
 			    case 'F':               // footnote begin
 			      *to++ = '<';
 			      *to++ = 'n';
@@ -179,8 +208,8 @@ char GBFThML::ProcessText(char *text, int maxlen)
 			      *to++ = 'e';
 			      *to++ = '=';
 			      *to++ = '"';		
-			      for (i = 2; i < strlen(token); i++)
-				*to++ = token[i];
+			      for (tok = token + 2; *tok; tok++)
+				*to++ = *tok;
 			      *to++ = '"';
 			      *to++ = '>';
 			      continue;
@@ -229,6 +258,7 @@ char GBFThML::ProcessText(char *text, int maxlen)
 			      *to++ = 'o';
 			      *to++ = 'r';
 			      *to++ = '=';
+			      *to++ = '\"';
 			      *to++ = '#';
 			      *to++ = 'f';
 			      *to++ = 'f';
@@ -236,6 +266,7 @@ char GBFThML::ProcessText(char *text, int maxlen)
 			      *to++ = '0';
 			      *to++ = '0';
 			      *to++ = '0';
+			      *to++ = '\"';
 			      *to++ = '>';
 			      continue;
 			    case 'r':		// words of Jesus end
@@ -357,34 +388,34 @@ char GBFThML::ProcessText(char *text, int maxlen)
 			      continue;
 			    case 'S':
 			      *to++ = '<';
-			      *to++ = 'b';
-			      *to++ = 'r';
-			      *to++ = ' ';
-			      *to++ = '/';
-			      *to++ = '>';
-			      *to++ = '<';
-			      *to++ = 'b';
-			      *to++ = '>';
-			      *to++ = '<';
+			      *to++ = 'd';
 			      *to++ = 'i';
+			      *to++ = 'v';
+			      *to++ = ' ';
+			      *to++ = 'c';
+			      *to++ = 'l';
+			      *to++ = 'a';
+			      *to++ = 's';
+			      *to++ = 's';
+			      *to++ = '=';
+			      *to++ = '\"';
+			      *to++ = 's';
+			      *to++ = 'e';
+			      *to++ = 'c';
+			      *to++ = 'h';
+			      *to++ = 'e';
+			      *to++ = 'a';
+			      *to++ = 'd';
+			      *to++ = '\"';
 			      *to++ = '>';
 			      continue;
 			    case 's':
 			      *to++ = '<';
 			      *to++ = '/';
+			      *to++ = 'd';
 			      *to++ = 'i';
+			      *to++ = 'v';
 			      *to++ = '>';
-			      *to++ = '<';
-			      *to++ = '/';
-			      *to++ = 'b';
-			      *to++ = '>';
-			      *to++ = '<';
-			      *to++ = 'b';
-			      *to++ = 'r';
-			      *to++ = ' ';
-			      *to++ = '/';
-			      *to++ = '>';
-			      
 			      continue;
 			    }
 			  break;
@@ -417,8 +448,9 @@ char GBFThML::ProcessText(char *text, int maxlen)
 			continue;
 		}
 		if (intoken) {
-			if (tokpos < 2047)
+			if (tokpos < 2045)
 				token[tokpos++] = *from;
+				token[tokpos+2] = 0;
 		}
 		else	*to++ = *from;
 	}
