@@ -51,7 +51,7 @@ const char *PLAINFootnotes::getOptionValue()
 }
 
 
-char PLAINFootnotes::ProcessText(char *text, int maxlen, const SWKey *key)
+char PLAINFootnotes::ProcessText(char *text, int maxlen, const SWKey *key, const SWModule *module)
 {
 	char token[2048];
 	int tokpos = 0;
@@ -83,8 +83,9 @@ char PLAINFootnotes::ProcessText(char *text, int maxlen, const SWKey *key)
 				continue;
 			}
 			if (intoken) {
-				if (tokpos < 2047)
+				if (tokpos < 2045)
 					token[tokpos++] = *from;
+					token[tokpos+2] = 0;
 			}
 			else	{
 				if (!hide) {
