@@ -14,7 +14,7 @@ RWPRTF::RWPRTF() {
 }
 
 
-char RWPRTF::ProcessText(char *text, int maxlen, const SWKey *key)
+char RWPRTF::ProcessText(char *text, int maxlen, const SWKey *key, const SWModule *module)
 {
 	char *to, *from;
 	bool ingreek = false;
