@@ -14,7 +14,7 @@
  *	idisp	 - Display object to use for displaying
  */
 
-SWLD::SWLD(const char *imodname, const char *imoddesc, SWDisplay *idisp, bool unicode) : SWModule(imodname, imoddesc, idisp, "Lexicons / Dictionaries", unicode)
+SWLD::SWLD(const char *imodname, const char *imoddesc, SWDisplay *idisp, SWTextEncoding enc, SWTextDirection dir, SWTextMarkup mark, const char* ilang) : SWModule(imodname, imoddesc, idisp, "Lexicons / Dictionaries", enc, dir, mark, ilang)
 {
 	delete key;
 	key = CreateKey();
@@ -47,7 +47,7 @@ SWLD::~SWLD()
 const char *SWLD::KeyText(const char *ikeytext)
 {
 	if (key->Persist() && !ikeytext) {
-		(char *) *this;	// force module key to snap to entry
+		getRawEntry();	// force module key to snap to entry
 		return entkeytxt;
 	}
 	else return SWModule::KeyText(ikeytext);
