@@ -10,7 +10,7 @@
 #include <regex.h>	// GNU
 #include <swfilter.h>
 #include <versekey.h>	// KLUDGE for Search
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 #include <iostream.h>
 #endif
 
@@ -25,29 +25,37 @@ void SWModule::nullPercent(char percent, void *percentUserData) {}
  *	idisp	 - Display object to use for displaying
  *	imodtype - Type of Module (All modules will be displayed with
  *			others of same type under their modtype heading
- *	unicode  - if this module is unicode (widechar)
+ *	unicode  - if this module is unicode
  */
 
-SWModule::SWModule(const char *imodname, const char *imoddesc, SWDisplay *idisp, char *imodtype, bool unicode)
+SWModule::SWModule(const char *imodname, const char *imoddesc, SWDisplay *idisp, char *imodtype, SWTextEncoding encoding, SWTextDirection direction, SWTextMarkup markup, const char* imodlang)
 {
-	key      = CreateKey();
-	entrybuf = new char [1];
+	key       = CreateKey();
+	entrybuf  = new char [1];
 	*entrybuf = 0;
-	modname  = 0;
-	error    = 0;
-	moddesc  = 0;
-	modtype  = 0;
-     this->unicode  = unicode;
-     entrySize= -1;
+	config    = &ownConfig;
+	entrybufallocsize = 0;
+	modname   = 0;
+	error     = 0;
+	moddesc   = 0;
+	modtype   = 0;
+	modlang   = 0;
+	this->encoding = encoding;
+	this->direction = direction;
+	this->markup  = markup;
+	entrySize= -1;
 	disp     = (idisp) ? idisp : &rawdisp;
 	stdstr(&modname, imodname);
 	stdstr(&moddesc, imoddesc);
 	stdstr(&modtype, imodtype);
-	render = true;	// for protected method when sometimes need RenderText not to _Render Text_ :)  kludge / rewrite
-     stripFilters = new FilterList();
-     rawFilters = new FilterList();
-     renderFilters = new FilterList();
-     optionFilters = new FilterList();
+	stdstr(&modlang, imodlang);
+	stripFilters = new FilterList();
+	rawFilters = new FilterList();
+	renderFilters = new FilterList();
+	optionFilters = new FilterList();
+	encodingFilters = new FilterList();
+	skipConsecutiveLinks = true;
+	procEntAttr = true;
 }
 
 
@@ -65,19 +73,26 @@ SWModule::~SWModule()
 		delete [] moddesc;
 	if (modtype)
 		delete [] modtype;
+	if (modlang)
+		delete [] modlang;
+
 	if (key) {
 		if (!key->Persist())
 			delete key;
 	}
+
 	stripFilters->clear();
      rawFilters->clear();
      renderFilters->clear();
      optionFilters->clear();
-     
+     encodingFilters->clear();
+	entryAttributes.clear();
+
      delete stripFilters;
      delete rawFilters;
      delete renderFilters;
      delete optionFilters;
+     delete encodingFilters;
 }
 
 
@@ -152,6 +167,63 @@ char *SWModule::Type(const char *imodtype)
 	return stdstr(&modtype, imodtype);
 }
 
+/******************************************************************************
+ * SWModule::Direction - Sets/gets module direction
+ *
+ * ENT:	newdir - value which to set direction
+ *		[-1] - only get
+ *
+ * RET:	char direction
+ */
+char SWModule::Direction(signed char newdir) {
+        if (newdir != -1)
+                direction = newdir;
+        return direction;
+}
+
+/******************************************************************************
+ * SWModule::Encoding - Sets/gets module encoding
+ *
+ * ENT:	newdir - value which to set direction
+ *		[-1] - only get
+ *
+ * RET:	char encoding
+ */
+char SWModule::Encoding(signed char newenc) {
+        if (newenc != -1)
+                encoding = newenc;
+        return encoding;
+}
+
+/******************************************************************************
+ * SWModule::Markup - Sets/gets module markup
+ *
+ * ENT:	newdir - value which to set direction
+ *		[-1] - only get
+ *
+ * RET:	char markup
+ */
+char SWModule::Markup(signed char newmark) {
+        if (newmark != -1)
+                markup = newmark;
+        return markup;
+}
+
+
+/******************************************************************************
+ * SWModule::Lang - Sets/gets module language
+ *
+ * ENT:	imodlang - value which to set modlang
+ *		[0] - only get
+ *
+ * RET:	pointer to modname
+ */
+
+char *SWModule::Lang(const char *imodlang)
+{
+	return stdstr(&modlang, imodlang);
+}
+
 
 /******************************************************************************
  * SWModule::Disp - Sets/gets display driver
@@ -196,11 +268,14 @@ char SWModule::Display()
 char SWModule::SetKey(const SWKey &ikey) {
 	return SetKey(&ikey);
 }
+
 char SWModule::SetKey(const SWKey *ikey)
 {
+	SWKey *oldKey = 0;
+
 	if (key) {
 		if (!key->Persist())	// if we have our own copy
-			delete key;
+			oldKey = key;
 	}
 
 	if (!ikey->Persist()) {		// if we are to keep our own copy
@@ -209,6 +284,9 @@ char SWModule::SetKey(const SWKey *ikey)
 	}
 	else	 key = (SWKey *)ikey;		// if we are to just point to an external key
 
+	if (oldKey)
+		delete oldKey;
+
 	return 0;
 }
 
@@ -242,8 +320,21 @@ const char *SWModule::KeyText(const char *ikeytext)
 SWModule &SWModule::operator =(SW_POSITION p)
 {
 	*key = p;
-	error = key->Error();
+	char saveError = key->Error();
 
+	switch (p) {
+	case POS_TOP:
+		(*this)++;
+		(*this)--;
+		break;
+
+	case POS_BOTTOM:
+		(*this)--;
+		(*this)++;
+		break;
+	}
+
+	error = saveError;
 	return *this;
 }
 
@@ -309,7 +400,9 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 	const char *sres;
 	terminateSearch = false;
 	char perc = 1;
+	bool savePEA = isProcessEntryAttributes();
 
+	processEntryAttributes(false);
 	listkey.ClearList();
 
 	if (!key->Persist()) {
@@ -387,7 +480,7 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 			(*percent)(perc, percentUserData);
 		}
 		else if (newperc < perc) {
-#ifndef __VISUALC__
+#ifndef _MSC_VER
 			cerr << "Serious error: new percentage complete is less than previous value\n";
 			cerr << "using vk? " << ((vkcheck)?"yes":"no") << "\n";
 			cerr << "index: " << ((vkcheck)?vkcheck->NewIndex():key->Index()) << "\n";
@@ -412,8 +505,9 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 			}
 			if (searchType == -2) {
 				int i;
+				const char *stripBuf = StripText();
 				for (i = 0; i < wordCount; i++) {
-					sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(StripText(), words[i]) : strstr(StripText(), words[i]);
+					sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(stripBuf, words[i]) : strstr(stripBuf, words[i]);
 					if (!sres)
 						break;
 				}
@@ -443,7 +537,9 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 		delete searchkey;
 
 	listkey = TOP;
+	processEntryAttributes(savePEA);
 	(*percent)(100, percentUserData);
+
 	return listkey;
 }
 
@@ -459,19 +555,7 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 
 const char *SWModule::StripText(char *buf, int len)
 {
-	SWKey *key = 0;
-
-	if (!buf) {
-		key = (SWKey *)*this;
-		render = false;
-		buf = (char *)*this;
-		render = true;
-	}
-
-	optionFilter(buf, len, key);
-	stripFilter(buf, len, key);
-
-	return buf;
+	return RenderText(buf, len, false);
 }
 
 
@@ -483,22 +567,33 @@ const char *SWModule::StripText(char *buf, int len)
  * RET: listkey set to verses that contain istr
  */
 
- const char *SWModule::RenderText(char *buf, int len)
-{
+ const char *SWModule::RenderText(char *buf, int len, bool render) {
+	entryAttributes.clear();
+	char *tmpbuf = (buf) ? buf : getRawEntry();
 	SWKey *key = 0;
+	static char *null = "";
 
-	if (!buf) {
-		key = (SWKey *)*this;
-		buf = (char *)*this;
-	}
+	if (tmpbuf) {
+		unsigned long size = (len < 0) ? getEntrySize() * FILTERPAD : len;
+          if (size < 0)
+          	size = strlen(tmpbuf);
+		if (size > 0) {
+			key = (SWKey *)*this;
 
-	optionFilter(buf, len, key);
+			optionFilter(tmpbuf, size, key);
 	
-	if (render) {
-		renderFilter(buf, len, key);
+			if (render) {
+				renderFilter(tmpbuf, size, key);
+				encodingFilter(tmpbuf, size, key);
+			}
+			else	stripFilter(tmpbuf, size, key);
+		}
+	}
+	else {
+		tmpbuf = null;
 	}
 
-	return buf;
+	return tmpbuf;
 }
 
 
@@ -542,7 +637,7 @@ const char *SWModule::StripText(char *buf, int len)
  * RET: this module's text at specified key location massaged by Strip filters
  */
 
- const char *SWModule::StripText(SWKey *tmpKey)
+const char *SWModule::StripText(SWKey *tmpKey)
 {
 	SWKey *savekey;
 	const char *retVal;
@@ -566,14 +661,17 @@ const char *SWModule::StripText(char *buf, int len)
 }
 
 
-SWModule::operator char*() {
-	char *versebuf = getRawEntry();
-	if (versebuf) {
-		int size = getEntrySize();
-          if (size == -1)
-          	size = strlen(versebuf);
-		if (size)
-			RenderText(versebuf, size * FILTERPAD * ((unicode) ? 9 : 1));
-	}
-	return versebuf;
+SWModule::operator const char*() {
+	return RenderText();
+}
+
+
+const char *SWModule::getConfigEntry(const char *key) const {
+	ConfigEntMap::iterator it = config->find(key);
+	return (it != config->end()) ? it->second.c_str() : 0;
+}
+
+
+void SWModule::setConfig(ConfigEntMap *config) {
+	this->config = config;
 }
