@@ -4,7 +4,6 @@
  */
 
 
-#include <ctype.h>
 #include <stdio.h>
 #include <fcntl.h>
 
@@ -36,11 +35,10 @@
  *	idisp	 - Display object to use for displaying
  */
 
-RawText::RawText(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp, bool unicode)
-		: SWText(iname, idesc, idisp, unicode),
+RawText::RawText(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp, SWTextEncoding enc, SWTextDirection dir, SWTextMarkup mark, const char* ilang)
+		: SWText(iname, idesc, idisp, enc, dir, mark, ilang),
           RawVerse(ipath) {
           
-	versebuf = 0;
 	string fname;
 	fname = path;
 	char ch = fname.c_str()[strlen(fname.c_str())-1];
@@ -65,9 +63,6 @@ RawText::RawText(const char *ipath, const char *iname, const char *idesc, SWDisp
 
 RawText::~RawText()
 {
-	if (versebuf)
-		delete [] versebuf;
-
 	if (fastSearch[0])
 		delete fastSearch[0];
 
@@ -103,27 +98,31 @@ char *RawText::getRawEntry() {
 
 	findoffset(key->Testament(), key->Index(), &start, &size);
 	entrySize = size;        // support getEntrySize call
-	if (versebuf)
-		delete [] versebuf;
 
-	versebuf = new char [ (size + 2) * FILTERPAD * ((unicode) ? 9 : 1 ) ];
-	*versebuf = 0;
+	unsigned long newsize = (size + 2) * FILTERPAD;
+	if (newsize > entrybufallocsize) {
+		if (entrybuf)
+			delete [] entrybuf;
+		entrybuf = new char [ newsize ];
+		entrybufallocsize = newsize;
+	}
+	*entrybuf = 0;
 
-	gettext(key->Testament(), start, (size + 2), versebuf);
+	gettext(key->Testament(), start, (size + 2), entrybuf);
 
-	rawFilter(versebuf, size, key);
+	rawFilter(entrybuf, size, key);
 
-     if (!unicode)
-		preptext(versebuf);
+        if (!isUnicode())
+		preptext(entrybuf);
 
 	if (this->key != key) // free our key if we created a VerseKey
 		delete key;
 
-	return versebuf;
+	return entrybuf;
 }
 
 
-char RawText::createSearchFramework() {
+signed char RawText::createSearchFramework() {
 	SWKey *savekey = 0;
 	SWKey *searchkey = 0;
 	SWKey textkey;
@@ -167,7 +166,7 @@ char RawText::createSearchFramework() {
 
 			// make work upper case
 			for (unsigned int i = 0; i < strlen(word); i++)
-				word[i] = toupper(word[i]);
+				word[i] = SW_toupper(word[i]);
 
 			// lookup word in dictionary (or make entry in dictionary
 			// for this word) and add this module position (index) to
@@ -327,7 +326,7 @@ ListKey &RawText::Search(const char *istr, int searchType, int flags, SWKey *sco
 			// toupper our copy of search string
 			stdstr(&wordBuf, istr);
 			for (unsigned int i = 0; i < strlen(wordBuf); i++)
-				wordBuf[i] = toupper(wordBuf[i]);
+				wordBuf[i] = SW_toupper(wordBuf[i]);
 
 			// get list of individual words
 			words = (char **)calloc(sizeof(char *), 10);
@@ -459,7 +458,7 @@ ListKey &RawText::Search(const char *istr, int searchType, int flags, SWKey *sco
 	return SWModule::Search(istr, searchType, flags, scope, justCheckIfSupported, percent, percentUserData);
 }
 
-#ifdef __VISUALC__
+#ifdef _MSC_VER
 SWModule &RawText::operator =(SW_POSITION p) {
 #else
 RawText &RawText::operator =(SW_POSITION p) {
@@ -468,8 +467,7 @@ RawText &RawText::operator =(SW_POSITION p) {
 	return *this;
 }
 
-
-SWModule &RawText::operator <<(const char *inbuf) {
+SWModule &RawText::setentry(const char *inbuf, long len) {
 	VerseKey *key = 0;
 	// see if we have a VerseKey * or decendant
 #ifndef _WIN32_WCE
@@ -484,7 +482,7 @@ SWModule &RawText::operator <<(const char *inbuf) {
 	if (!key)
 		key = new VerseKey(this->key);
 
-	settext(key->Testament(), key->Index(), inbuf);
+	settext(key->Testament(), key->Index(), inbuf, len);
 
 	if (this->key != key) // free our key if we created a VerseKey
 		delete key;
@@ -492,6 +490,10 @@ SWModule &RawText::operator <<(const char *inbuf) {
 	return *this;
 }
 
+SWModule &RawText::operator <<(const char *inbuf) {
+        return setentry(inbuf, 0);
+}
+
 
 SWModule &RawText::operator <<(const SWKey *inkey) {
 	VerseKey *destkey = 0;
@@ -535,7 +537,7 @@ SWModule &RawText::operator <<(const SWKey *inkey) {
 
 
 /******************************************************************************
- * RawFiles::deleteEntry	- deletes this entry
+ * RawText::deleteEntry	- deletes this entry
  *
  * RET: *this
  */
@@ -560,3 +562,69 @@ void RawText::deleteEntry() {
 	if (key != this->key)
 		delete key;
 }
+
+/******************************************************************************
+ * RawText::operator +=	- Increments module key a number of entries
+ *
+ * ENT:	increment	- Number of entries to jump forward
+ *
+ * RET: *this
+ */
+
+SWModule &RawText::operator +=(int increment)
+{
+	long  start;
+	unsigned short size;
+	VerseKey *tmpkey = 0;
+
+#ifndef _WIN32_WCE
+	try {
+#endif
+		tmpkey = SWDYNAMIC_CAST(VerseKey, key);
+#ifndef _WIN32_WCE
+	}
+	catch ( ... ) {}
+#endif
+	if (!tmpkey)
+		tmpkey = new VerseKey(key);
+
+	findoffset(tmpkey->Testament(), tmpkey->Index(), &start, &size);
+
+	SWKey lastgood = *tmpkey;
+	while (increment) {
+		long laststart = start;
+		unsigned short lastsize = size;
+		SWKey lasttry = *tmpkey;
+		(increment > 0) ? (*key)++ : (*key)--;
+		if (tmpkey != key)
+			delete tmpkey;
+		tmpkey = 0;
+#ifndef _WIN32_WCE
+		try {
+#endif
+			tmpkey = SWDYNAMIC_CAST(VerseKey, key);
+#ifndef _WIN32_WCE
+		}
+		catch ( ... ) {}
+#endif
+		if (!tmpkey)
+			tmpkey = new VerseKey(key);
+
+		if ((error = key->Error())) {
+			*key = lastgood;
+			break;
+		}
+		long index = tmpkey->Index();
+		findoffset(tmpkey->Testament(), index, &start, &size);
+		if ((((laststart != start) || (lastsize != size))||(!skipConsecutiveLinks)) && (start >= 0) && (size)) {
+			increment += (increment < 0) ? 1 : -1;
+			lastgood = *tmpkey;
+		}
+	}
+	error = (error) ? KEYERR_OUTOFBOUNDS : 0;
+
+	if (tmpkey != key)
+		delete tmpkey;
+
+	return *this;
+}
