@@ -33,10 +33,9 @@
  *		idisp - Display object to use for displaying
  */
 
-zText::zText(const char *ipath, const char *iname, const char *idesc, int iblockType, SWCompress *icomp, SWDisplay *idisp, bool unicode) : zVerse(ipath, -1, iblockType, icomp), SWText(iname, idesc, idisp, unicode)/*, SWCompress()*/
+zText::zText(const char *ipath, const char *iname, const char *idesc, int iblockType, SWCompress *icomp, SWDisplay *idisp, SWTextEncoding enc, SWTextDirection dir, SWTextMarkup mark, const char* ilang) : zVerse(ipath, -1, iblockType, icomp), SWText(iname, idesc, idisp, enc, dir, mark, ilang)/*, SWCompress()*/
 {
 	blockType = iblockType;
-	versebuf = 0;
 	lastWriteKey = 0;
 }
 
@@ -49,9 +48,6 @@ zText::~zText()
 {
 	flushCache();
 
-	if (versebuf)
-		delete [] versebuf;
-
 	if (lastWriteKey)
 		delete lastWriteKey;
 }
@@ -128,27 +124,30 @@ char *zText::getRawEntry()
 	entrySize = size;        // support getEntrySize call
 
 	//printf ("deleting previous buffer\n");
-	if (versebuf)
-		delete [] versebuf;
-
-	versebuf = new char [ (size + 2) * FILTERPAD * ((unicode) ? 9 : 1 ) ];
-	*versebuf = 0;
+	unsigned long newsize = (size + 2) * FILTERPAD;
+	if (newsize > entrybufallocsize) {
+		if (entrybuf)
+			delete [] entrybuf;
+		entrybuf = new char [ newsize ];
+		entrybufallocsize = newsize;
+	}
+	*entrybuf = 0;
 
 	//printf ("getting text\n");
-	swgettext(key->Testament(), start, (size + 2), versebuf);
+	swgettext(key->Testament(), start, (size + 2), entrybuf);
 	//printf ("got text\n");
 
-	rawFilter(versebuf, size, key);
+	rawFilter(entrybuf, size, key);
 
 	//printf ("preparing text\n");
-     if (!unicode)
-		preptext(versebuf);
+        if (!isUnicode())
+		preptext(entrybuf);
 
 	if (this->key != key) // free our key if we created a VerseKey
 		delete key;
 
 	//printf ("returning text\n");
-	return versebuf;
+	return entrybuf;
 
 }
 
@@ -172,7 +171,7 @@ bool zText::sameBlock(VerseKey *k1, VerseKey *k2) {
 }
 
 
-SWModule &zText::operator <<(const char *inbuf) {
+SWModule &zText::setentry(const char *inbuf, long len) {
 	VerseKey *key = 0;
 	// see if we have a VerseKey * or decendant
 #ifndef _WIN32_WCE
@@ -196,7 +195,7 @@ SWModule &zText::operator <<(const char *inbuf) {
 		delete lastWriteKey;
 	}
 
-	settext(key->Testament(), key->Index(), inbuf);
+	settext(key->Testament(), key->Index(), inbuf, len);
 
 	lastWriteKey = (VerseKey *)key->clone();	// must delete
 
@@ -206,6 +205,10 @@ SWModule &zText::operator <<(const char *inbuf) {
 	return *this;
 }
 
+SWModule &zText::operator <<(const char *inbuf) {
+        return setentry(inbuf, 0);
+}
+
 
 SWModule &zText::operator <<(const SWKey *inkey) {
 	VerseKey *destkey = 0;
@@ -275,3 +278,70 @@ void zText::deleteEntry() {
 	if (key != this->key)
 		delete key;
 }
+
+
+/******************************************************************************
+ * zText::operator +=	- Increments module key a number of entries
+ *
+ * ENT:	increment	- Number of entries to jump forward
+ *
+ * RET: *this
+ */
+
+SWModule &zText::operator +=(int increment)
+{
+	long  start;
+	unsigned short size;
+	VerseKey *tmpkey = 0;
+
+#ifndef _WIN32_WCE
+	try {
+#endif
+		tmpkey = SWDYNAMIC_CAST(VerseKey, key);
+#ifndef _WIN32_WCE
+	}
+	catch ( ... ) {}
+#endif
+	if (!tmpkey)
+		tmpkey = new VerseKey(key);
+
+	findoffset(tmpkey->Testament(), tmpkey->Index(), &start, &size);
+
+	SWKey lastgood = *tmpkey;
+	while (increment) {
+		long laststart = start;
+		unsigned short lastsize = size;
+		SWKey lasttry = *tmpkey;
+		(increment > 0) ? (*key)++ : (*key)--;
+		if (tmpkey != key)
+			delete tmpkey;
+		tmpkey = 0;
+#ifndef _WIN32_WCE
+		try {
+#endif
+			tmpkey = SWDYNAMIC_CAST(VerseKey, key);
+#ifndef _WIN32_WCE
+		}
+		catch ( ... ) {}
+#endif
+		if (!tmpkey)
+			tmpkey = new VerseKey(key);
+
+		if ((error = key->Error())) {
+			*key = lastgood;
+			break;
+		}
+		long index = tmpkey->Index();
+		findoffset(tmpkey->Testament(), index, &start, &size);
+		if ((((laststart != start) || (lastsize != size))||(!skipConsecutiveLinks)) && (start >= 0) && (size)) {
+			increment += (increment < 0) ? 1 : -1;
+			lastgood = *tmpkey;
+		}
+	}
+	error = (error) ? KEYERR_OUTOFBOUNDS : 0;
+
+	if (tmpkey != key)
+		delete tmpkey;
+
+	return *this;
+}
