@@ -16,8 +16,9 @@ char *stdstr(char **ipstr, const char *istr) {
 	if (istr) {
 		if (*ipstr)
 			delete [] *ipstr;
-		*ipstr = new char [ strlen(istr) + 1 ];
-		strcpy(*ipstr, istr);
+		int len = strlen(istr) + 1;
+		*ipstr = new char [ len ];
+		memcpy(*ipstr, istr, len);
 	}
 	return *ipstr;
 }
@@ -35,9 +36,10 @@ char *strstrip(char *istr) {
 	char *tmp = istr;
 	char *rtmp;
 
-	if (strlen(istr) < 1)
+	int len = strlen(istr);
+	if (len < 1)
 		return istr;
-	rtmp = istr + (strlen(istr) - 1);
+	rtmp = istr + (len - 1);
 	
 	while (*rtmp == ' ') *(rtmp--) = 0;
 	while (*tmp == ' ') tmp++;
@@ -66,12 +68,12 @@ const char *stristr(const char *s1, const char *s2) {
 
 	strcpy(target, s2);
 	for (i = 0; i < tLen; i++)
-		target[i] = toupper(target[i]);
+		target[i] = SW_toupper(target[i]);
 
 	for (i = 0; i < (cLen - tLen)+1; i++) {
-		if (toupper(s1[i]) == (unsigned char)*target) {
+		if (SW_toupper(s1[i]) == (unsigned char)*target) {
 			for (j = 1; j < tLen; j++) {
-				if (toupper(s1[i+j]) != (unsigned char)target[j])
+				if (SW_toupper(s1[i+j]) != (unsigned char)target[j])
 					break;
 			}
 			if (j == tLen) {
@@ -99,7 +101,7 @@ const char strnicmp(const char *s1, const char *s2, int len) {
      char diff;
      int i;
      for (i = 0; ((i < len) && (i < tLen) && (i < cLen)); i++) {
-     	if ((diff = toupper(*s1) - toupper(*s2)))
+     	if ((diff = SW_toupper(*s1) - SW_toupper(*s2)))
           	return diff;
 	s1++;
 	s2++;
@@ -117,13 +119,34 @@ const char strnicmp(const char *s1, const char *s2, int len) {
  */
 
 unsigned int strlenw(const char *s1) {
+	return strlen(s1);
+// utf8 says no null in string except terminator, so below code is overkill
+/*
 	const char *ch = s1;
-     if (!*ch)
-     	ch++;
-     while (*ch) {
-     	ch++;
-          if (!*ch)
-          	ch++;
-     }
-     return (unsigned int)(ch - s1) - 1;
+	if (!*ch)
+		ch++;
+	while (*ch) {
+		ch++;
+		if (!*ch)
+			ch++;
+	}
+	return (unsigned int)(ch - s1) - 1;
+*/
+}
+
+
+/******************************************************************************
+ * toupperstr - converts a string to uppercase string
+ *
+ * ENT:	target - string to convert
+ *
+ * RET:	target
+ */
+
+char *toupperstr(char *buf) {
+	char *ret = buf;
+	while (*buf)
+		*buf = SW_toupper(*buf++);
+
+	return ret;
 }
