@@ -3,6 +3,7 @@
 #include <string>
 #include <stdio.h>
 
+using namespace std;
 
 void addEntry(EntriesBlock *eb) {
 	string input;
@@ -30,9 +31,17 @@ void printEntry(EntriesBlock *eb, int index) {
 }
 
 
+void printSize(EntriesBlock *eb) {
+	unsigned long size;
+	eb->getRawData(&size);
+	cout << "Size of raw data: " << size << "\n\n";
+}
+
+
 void removeEntry(EntriesBlock *eb, int index) {
 	if (index < eb->getCount()) {
 		cout << "Removing entry [" << index << "]\n";
+		eb->removeEntry(index);
 	}
 	else cout << "Invalid entry number\n\n";
 }
@@ -55,12 +64,14 @@ int main(int argc, char **argv) {
 				case 'a': addEntry(eb); break;
 				case 'p':	printEntry(eb, atoi(input.c_str()+1)); break;
 				case 'r':	removeEntry(eb, atoi(input.c_str()+1)); break;
+				case 's': printSize(eb); break;
 				case 'q': break;
 				case '?':
 				default:
 					cout << "\n a - add a new entry\n";
 					cout << " p <entry_index> - print entry\n";
 					cout << " r <entry_index> - remove entry\n";
+					cout << " s - print size of raw data\n";
 					cout << " q - quit\n\n";
 					break;
 			}
