@@ -76,7 +76,7 @@ int main(int argc, char **argv) {
 			if (size) {
 				tmpbuf = (char *) calloc(size + 2, 1);
 				rawdrv->gettext(key.Testament(), offset, size + 2, tmpbuf);
-				zobj->Buf(tmpbuf);
+				zobj->Buf(tmpbuf, size);
 				zobj->cipherBuf((unsigned int *)&size);
 				free(tmpbuf);
 			}
